/*
 * BBTree methods tests
 * Testing BBTree methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
static gint my_compare(gconstpointer a, gconstpointer b)
{
    const char *cha = a;
    const char *chb = b;

    return *cha - *chb;
}

static gint my_traverse (gpointer key, gpointer value, gpointer data)
{
    char *ch = key;
    if ((*ch) <= 0){
	TEST_FAIL("g_tree_foreach: invalid key in tree", NULL);
    }
    return FALSE;
}


/*
 * Name: g_tree_insert
 * Params: GTree *tree, gpointer key, gpointer value
 * Returns: void
 * Assertion: Inserts a key/value pair into a GTree. If the given key already exists in the GTree its corresponding value is set to the new value. If you supplied a value_destroy_func when creating the GTree, the old value is freed using that function. If you supplied a key_destroy_func when creating the GTree, the passed key is freed using that function.
 * The tree is automatically 'balanced' as new key/value pairs are added, so that the distance from the root to every leaf is as small as possible.
 *            tree : a GTree.
 *            key : the key to insert.
 *            value : the value corresponding to the key. 
 * Params Values: key = '0' + 11, val = 'a'
 * Expected: <%2%>  
 */
static void test_purpose_1()
{
    #define KEY    '0' + 11
    #define VAL    'a'
    #define RETV   <%2%>
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i, j;
    gchar keys[10];
    gchar ikey;
    gchar ival;
    
    GTree *gt = g_tree_new(my_compare);
    i = 0;
    for (j = 0; j < 10; j++, i++){
    	keys[i] = '0' + j;
    	g_tree_insert(gt, &keys[i], &keys[i]);
    }
    ikey = KEY;
    ival = VAL;
    g_tree_insert(gt, &ikey, &ival);
    if (VAL != *((gchar *)g_tree_lookup(gt, &ikey))){
        TEST_FAIL("g_tree_insert: should be %c", VAL);
    }
    g_tree_destroy(gt);
    
    #undef KEY
    #undef VAL
    #undef RETV
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_tree_insert
 * Params: GTree *tree, gpointer key, gpointer value
 * Returns: void
 * Assertion: Inserts a key/value pair into a GTree. If the given key already exists in the GTree its corresponding value is set to the new value. If you supplied a value_destroy_func when creating the GTree, the old value is freed using that function. If you supplied a key_destroy_func when creating the GTree, the passed key is freed using that function.
 * The tree is automatically 'balanced' as new key/value pairs are added, so that the distance from the root to every leaf is as small as possible.
 *            tree : a GTree.
 *            key : the key to insert.
 *            value : the value corresponding to the key. 
 * Params Values: key = '0' + 8, val = 'b'
 * Expected: <%2%>  
 */
static void test_purpose_2()
{
    #define KEY    '0' + 8
    #define VAL    'b'
    #define RETV   <%2%>
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i, j;
    gchar keys[10];
    gchar ikey;
    gchar ival;
    
    GTree *gt = g_tree_new(my_compare);
    i = 0;
    for (j = 0; j < 10; j++, i++){
    	keys[i] = '0' + j;
    	g_tree_insert(gt, &keys[i], &keys[i]);
    }
    ikey = KEY;
    ival = VAL;
    g_tree_insert(gt, &ikey, &ival);
    if (VAL != *((gchar *)g_tree_lookup(gt, &ikey))){
        TEST_FAIL("g_tree_insert: should be %c", VAL);
    }
    g_tree_destroy(gt);
    
    #undef KEY
    #undef VAL
    #undef RETV
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_tree_lookup
 * Params: GTree *tree, gconstpointer key
 * Returns: gpointer
 * Assertion: Gets the value corresponding to the given key. Since a GTree is automatically balanced as key/value pairs are added, key lookup is very fast. 
 *            tree : a GTree.
 *            key : the key to look up.
 *            Returns : the value corresponding to the key.
 * Params Values: key = 3
 * Expected: '0' + 3  
 */
static void test_purpose_3()
{
    #define KEY    3
    #define VAL    '0' + 3
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i, j;
    char chars[KEY < 10 ? 10 : KEY + 1];
    gchar ikey;
    gchar ival;
    
    GTree *gt = g_tree_new(my_compare);
    i = 0;
    for (j = 0; j < 10; j++, i++){
            chars[i] = '0' + j;
            g_tree_insert(gt, &chars[i], &chars[i]);
    }
    // to avoid complaints about uninitialized access,
    if(KEY >= 10) {
    	chars[KEY] = '\0';
    }
    ikey = KEY;
    ival = VAL;
    if (g_tree_lookup(gt, &chars[ikey]) == NULL){
        if (ival != NULL){
            TEST_FAIL("g_tree_lookup: should be NULL", NULL);
        }
    }
    else{
        if (*(gchar *)g_tree_lookup(gt, &chars[ikey]) != VAL){
            TEST_FAIL("g_tree_lookup: should be %c", VAL);
        }
    }
    
    g_tree_destroy(gt);
    
    #undef KEY
    #undef VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_tree_lookup
 * Params: GTree *tree, gconstpointer key
 * Returns: gpointer
 * Assertion: Gets the value corresponding to the given key. Since a GTree is automatically balanced as key/value pairs are added, key lookup is very fast. 
 *            tree : a GTree.
 *            key : the key to look up.
 *            Returns : the value corresponding to the key.
 * Params Values: key = 10
 * Expected: NULL  
 */
static void test_purpose_4()
{
    #define KEY    10
    #define VAL    NULL
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i, j;
    char chars[KEY < 10 ? 10 : KEY + 1];
    gchar ikey;
    gchar ival;
    
    GTree *gt = g_tree_new(my_compare);
    i = 0;
    for (j = 0; j < 10; j++, i++){
            chars[i] = '0' + j;
            g_tree_insert(gt, &chars[i], &chars[i]);
    }
    // to avoid complaints about uninitialized access,
    if(KEY >= 10) {
    	chars[KEY] = '\0';
    }
    ikey = KEY;
    ival = VAL;
    if (g_tree_lookup(gt, &chars[ikey]) == NULL){
        if (ival != NULL){
            TEST_FAIL("g_tree_lookup: should be NULL", NULL);
        }
    }
    else{
        if (*(gchar *)g_tree_lookup(gt, &chars[ikey]) != VAL){
            TEST_FAIL("g_tree_lookup: should be %c", VAL);
        }
    }
    
    g_tree_destroy(gt);
    
    #undef KEY
    #undef VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_tree_foreach
 * Params: GTree *tree, GTraverseFunc func, gpointer user_data
 * Returns: void
 * Assertion: Calls the given function for each of the key/value pairs in the GTree. The function is passed the key and value of each pair, and the given data parameter. The tree is traversed in sorted order.
 * The tree may not be modified while iterating over it (you can't add/remove items). To remove all items matching a predicate, you need to add each item to a list in your GTraverseFunc as you walk over the tree, then walk the list and remove each item.           tree : a GTree.
 *            func : the function to call for each node visited. If this function returns TRUE, the traversal is stopped.
 *            user_data : user data to pass to the function.
 * Params Values: GTree *tree, GTraverseFunc func, gpointer user_data 
 * Expected: void  
 */
static void test_purpose_5()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i, j;
    char chars[62];
    gchar tmp;
    
    GTree *gt = g_tree_new(my_compare);
    i = 0;
    for (j = 0; j < 10; j++, i++){
        chars[i] = '0' + j;
        g_tree_insert(gt, &chars[i], &chars[i]);
    }
    for (j = 0; j < 26; j++, i++){
        chars[i] = 'A' + j;
        g_tree_insert(gt, &chars[i], &chars[i]);
    }
    for (j = 0; j < 26; j++, i++){
        chars[i] = 'a' + j;
        g_tree_insert(gt, &chars[i], &chars[i]);
    }
    
    g_tree_foreach(gt, my_traverse, NULL);
    
    if (g_tree_nnodes (gt) != (10 + 26 + 26)){
        TEST_FAIL("g_tree_foreach: incorrect number of nodes in tree", NULL);
    }
    
    i = 0;
    for (j = 0; j < 10; j++, i++){
        tmp = *(gchar *)g_tree_lookup(gt, &chars[i]);
        if (tmp != ('0' + j)){
    	TEST_FAIL("g_tree_foreach: should be %c, now is %c", tmp, '0' + j);
        }
    }
    for (j = 0; j < 26; j++, i++){
        tmp = *(gchar *)g_tree_lookup(gt, &chars[i]);
        if (tmp != ('A' + j)){
    	TEST_FAIL("g_tree_foreach: should be %c, now is %c", tmp, 'A' + j);
        }
    }
    for (j = 0; j < 26; j++, i++){
        tmp = *(gchar *)g_tree_lookup(gt, &chars[i]);
        if (tmp != ('a' + j)){
    	TEST_FAIL("g_tree_foreach: should be %c, now is %c", tmp, 'a' + j);
        }
    }
    
    for (i = 0; i< 10; i++)
        g_tree_remove (gt, &chars[i]);
    
    g_tree_foreach (gt, my_traverse, NULL);
    
    g_tree_destroy(gt);
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for BBTree ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {NULL,0}
};
