/*
 * GdkPixbufFileLoading methods tests
 * Testing GdkPixbufFileLoading methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
gchar * filename = NULL;

gchar * no_such_file(){
	return "no_such_file";
}

gchar * gen_filename(gchar * fname){
	gchar * tet_root = NULL;
	tet_root = getenv("TET_ROOT");
	filename = (gchar *)malloc(128);
	memset(filename,0,128);
	strcpy(filename,tet_root);
	strcat(filename,"/gtkvts/src/tests/functions/GdkPixbuf/picfile/");
	strcat(filename,fname);
	return filename;
};

gchar * no_data_file(){
	return gen_filename("no_data_file");
}

gchar * exist_ok_file_jpg(){
	return gen_filename("file_ok.jpg");
}

gchar * exist_ok_file_jpeg(){
	return gen_filename("file_ok.jpeg");
}

gchar * exist_ok_file_png(){
	return gen_filename("file_ok.png");
}

gchar * exist_ok_file_gif(){
	return gen_filename("file_ok.gif");
}

gchar * exist_ok_file_bmp(){
	return gen_filename("file_ok.bmp");
}

gchar * exist_err_file_jpg(){
	return gen_filename("file_err.jpg");
}

void free_filename(){
	if(filename)
		free(filename);
	filename = NULL;
}

/*
 * Name: gdk_pixbuf_new_from_file
 * Params: const char *filename, GError **error
 * Returns: GdkPixbuf*
 * Assertion: Creates a new pixbuf by loading an image from a file. The file format is detected automatically. If NULL is returned, then error will be set. Possible errors are in the GDK_PIXBUF_ERROR and G_FILE_ERROR domains.
 * Params Values: filename is the Name of file to load, in the GLib file name encoding  and error is the return location for an error  
 * Expected: A newly-created pixbuf with a reference count of 1, or NULL if any of several error conditions occurred: the file could not be opened, there was no loader for the file's format, there was not enough memory to allocate the image buffer, or the image file contained invalid data.    
 */
static void test_purpose_1()
{
    #define FILENAME 		exist_ok_file_jpg()
    #define EXP_RES			0
    
    GdkPixbuf * pixbuf;
    GError * perrorbuf;
    GQuark domain;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = NULL;
    perrorbuf = NULL;
    
    pixbuf = gdk_pixbuf_new_from_file(FILENAME,&perrorbuf);
    if(EXP_RES == G_FILE_ERROR){
    	if(pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not NULL, that is unimaginable!", NULL); 
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is NULL", NULL); 
    		return;
    	}
    	if(perrorbuf->domain != G_FILE_ERROR){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":gerror domain is not expected domain: G_FILE_ERROR", NULL); 
    		return;
    	}
    }else if(EXP_RES == GDK_PIXBUF_ERROR){
    	if(pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not NULL, that is unimaginable!", NULL); 
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is NULL", NULL); 
    		return;
    	}
    	if(perrorbuf->domain != GDK_PIXBUF_ERROR){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":gerror domain is not expected domain: GDK_PIXBUF_ERROR", NULL); 
    		return;
    	}
    }else{
    	if(!pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is NULL", NULL); 
    		return;
    	}	
    	if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not a valide GdkPixbuf object!", NULL); 
    		return;
    	}
    	if(perrorbuf != NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is not NULL", NULL); 
    		return;
    	}
    }
    if(pixbuf){
    	g_object_unref(pixbuf);
    }
    if(perrorbuf){
    	g_error_free(perrorbuf);
    }
    free_filename();
    #undef FILENAME
    #undef EXP_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_new_from_file
 * Params: const char *filename, GError **error
 * Returns: GdkPixbuf*
 * Assertion: Creates a new pixbuf by loading an image from a file. The file format is detected automatically. If NULL is returned, then error will be set. Possible errors are in the GDK_PIXBUF_ERROR and G_FILE_ERROR domains.
 * Params Values: filename is the Name of file to load, in the GLib file name encoding  and error is the return location for an error  
 * Expected: A newly-created pixbuf with a reference count of 1, or NULL if any of several error conditions occurred: the file could not be opened, there was no loader for the file's format, there was not enough memory to allocate the image buffer, or the image file contained invalid data.    
 */
static void test_purpose_2()
{
    #define FILENAME 		exist_ok_file_jpeg()
    #define EXP_RES			0
    
    GdkPixbuf * pixbuf;
    GError * perrorbuf;
    GQuark domain;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = NULL;
    perrorbuf = NULL;
    
    pixbuf = gdk_pixbuf_new_from_file(FILENAME,&perrorbuf);
    if(EXP_RES == G_FILE_ERROR){
    	if(pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not NULL, that is unimaginable!", NULL); 
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is NULL", NULL); 
    		return;
    	}
    	if(perrorbuf->domain != G_FILE_ERROR){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":gerror domain is not expected domain: G_FILE_ERROR", NULL); 
    		return;
    	}
    }else if(EXP_RES == GDK_PIXBUF_ERROR){
    	if(pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not NULL, that is unimaginable!", NULL); 
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is NULL", NULL); 
    		return;
    	}
    	if(perrorbuf->domain != GDK_PIXBUF_ERROR){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":gerror domain is not expected domain: GDK_PIXBUF_ERROR", NULL); 
    		return;
    	}
    }else{
    	if(!pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is NULL", NULL); 
    		return;
    	}	
    	if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not a valide GdkPixbuf object!", NULL); 
    		return;
    	}
    	if(perrorbuf != NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is not NULL", NULL); 
    		return;
    	}
    }
    if(pixbuf){
    	g_object_unref(pixbuf);
    }
    if(perrorbuf){
    	g_error_free(perrorbuf);
    }
    free_filename();
    #undef FILENAME
    #undef EXP_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_new_from_file
 * Params: const char *filename, GError **error
 * Returns: GdkPixbuf*
 * Assertion: Creates a new pixbuf by loading an image from a file. The file format is detected automatically. If NULL is returned, then error will be set. Possible errors are in the GDK_PIXBUF_ERROR and G_FILE_ERROR domains.
 * Params Values: filename is the Name of file to load, in the GLib file name encoding  and error is the return location for an error  
 * Expected: A newly-created pixbuf with a reference count of 1, or NULL if any of several error conditions occurred: the file could not be opened, there was no loader for the file's format, there was not enough memory to allocate the image buffer, or the image file contained invalid data.    
 */
static void test_purpose_3()
{
    #define FILENAME 		exist_ok_file_png()
    #define EXP_RES			0
    
    GdkPixbuf * pixbuf;
    GError * perrorbuf;
    GQuark domain;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = NULL;
    perrorbuf = NULL;
    
    pixbuf = gdk_pixbuf_new_from_file(FILENAME,&perrorbuf);
    if(EXP_RES == G_FILE_ERROR){
    	if(pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not NULL, that is unimaginable!", NULL); 
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is NULL", NULL); 
    		return;
    	}
    	if(perrorbuf->domain != G_FILE_ERROR){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":gerror domain is not expected domain: G_FILE_ERROR", NULL); 
    		return;
    	}
    }else if(EXP_RES == GDK_PIXBUF_ERROR){
    	if(pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not NULL, that is unimaginable!", NULL); 
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is NULL", NULL); 
    		return;
    	}
    	if(perrorbuf->domain != GDK_PIXBUF_ERROR){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":gerror domain is not expected domain: GDK_PIXBUF_ERROR", NULL); 
    		return;
    	}
    }else{
    	if(!pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is NULL", NULL); 
    		return;
    	}	
    	if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not a valide GdkPixbuf object!", NULL); 
    		return;
    	}
    	if(perrorbuf != NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is not NULL", NULL); 
    		return;
    	}
    }
    if(pixbuf){
    	g_object_unref(pixbuf);
    }
    if(perrorbuf){
    	g_error_free(perrorbuf);
    }
    free_filename();
    #undef FILENAME
    #undef EXP_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_new_from_file
 * Params: const char *filename, GError **error
 * Returns: GdkPixbuf*
 * Assertion: Creates a new pixbuf by loading an image from a file. The file format is detected automatically. If NULL is returned, then error will be set. Possible errors are in the GDK_PIXBUF_ERROR and G_FILE_ERROR domains.
 * Params Values: filename is the Name of file to load, in the GLib file name encoding  and error is the return location for an error  
 * Expected: A newly-created pixbuf with a reference count of 1, or NULL if any of several error conditions occurred: the file could not be opened, there was no loader for the file's format, there was not enough memory to allocate the image buffer, or the image file contained invalid data.    
 */
static void test_purpose_4()
{
    #define FILENAME 		exist_ok_file_gif()
    #define EXP_RES			0
    
    GdkPixbuf * pixbuf;
    GError * perrorbuf;
    GQuark domain;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = NULL;
    perrorbuf = NULL;
    
    pixbuf = gdk_pixbuf_new_from_file(FILENAME,&perrorbuf);
    if(EXP_RES == G_FILE_ERROR){
    	if(pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not NULL, that is unimaginable!", NULL); 
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is NULL", NULL); 
    		return;
    	}
    	if(perrorbuf->domain != G_FILE_ERROR){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":gerror domain is not expected domain: G_FILE_ERROR", NULL); 
    		return;
    	}
    }else if(EXP_RES == GDK_PIXBUF_ERROR){
    	if(pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not NULL, that is unimaginable!", NULL); 
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is NULL", NULL); 
    		return;
    	}
    	if(perrorbuf->domain != GDK_PIXBUF_ERROR){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":gerror domain is not expected domain: GDK_PIXBUF_ERROR", NULL); 
    		return;
    	}
    }else{
    	if(!pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is NULL", NULL); 
    		return;
    	}	
    	if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not a valide GdkPixbuf object!", NULL); 
    		return;
    	}
    	if(perrorbuf != NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is not NULL", NULL); 
    		return;
    	}
    }
    if(pixbuf){
    	g_object_unref(pixbuf);
    }
    if(perrorbuf){
    	g_error_free(perrorbuf);
    }
    free_filename();
    #undef FILENAME
    #undef EXP_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_new_from_file
 * Params: const char *filename, GError **error
 * Returns: GdkPixbuf*
 * Assertion: Creates a new pixbuf by loading an image from a file. The file format is detected automatically. If NULL is returned, then error will be set. Possible errors are in the GDK_PIXBUF_ERROR and G_FILE_ERROR domains.
 * Params Values: filename is the Name of file to load, in the GLib file name encoding  and error is the return location for an error  
 * Expected: A newly-created pixbuf with a reference count of 1, or NULL if any of several error conditions occurred: the file could not be opened, there was no loader for the file's format, there was not enough memory to allocate the image buffer, or the image file contained invalid data.    
 */
static void test_purpose_5()
{
    #define FILENAME 		exist_ok_file_bmp()
    #define EXP_RES			0
    
    GdkPixbuf * pixbuf;
    GError * perrorbuf;
    GQuark domain;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = NULL;
    perrorbuf = NULL;
    
    pixbuf = gdk_pixbuf_new_from_file(FILENAME,&perrorbuf);
    if(EXP_RES == G_FILE_ERROR){
    	if(pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not NULL, that is unimaginable!", NULL); 
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is NULL", NULL); 
    		return;
    	}
    	if(perrorbuf->domain != G_FILE_ERROR){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":gerror domain is not expected domain: G_FILE_ERROR", NULL); 
    		return;
    	}
    }else if(EXP_RES == GDK_PIXBUF_ERROR){
    	if(pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not NULL, that is unimaginable!", NULL); 
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is NULL", NULL); 
    		return;
    	}
    	if(perrorbuf->domain != GDK_PIXBUF_ERROR){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":gerror domain is not expected domain: GDK_PIXBUF_ERROR", NULL); 
    		return;
    	}
    }else{
    	if(!pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is NULL", NULL); 
    		return;
    	}	
    	if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not a valide GdkPixbuf object!", NULL); 
    		return;
    	}
    	if(perrorbuf != NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is not NULL", NULL); 
    		return;
    	}
    }
    if(pixbuf){
    	g_object_unref(pixbuf);
    }
    if(perrorbuf){
    	g_error_free(perrorbuf);
    }
    free_filename();
    #undef FILENAME
    #undef EXP_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_new_from_file
 * Params: const char *filename, GError **error
 * Returns: GdkPixbuf*
 * Assertion: Creates a new pixbuf by loading an image from a file. The file format is detected automatically. If NULL is returned, then error will be set. Possible errors are in the GDK_PIXBUF_ERROR and G_FILE_ERROR domains.
 * Params Values: filename is the Name of file to load, in the GLib file name encoding  and error is the return location for an error  
 * Expected: A newly-created pixbuf with a reference count of 1, or NULL if any of several error conditions occurred: the file could not be opened, there was no loader for the file's format, there was not enough memory to allocate the image buffer, or the image file contained invalid data.    
 */
static void test_purpose_6()
{
    #define FILENAME 		exist_err_file_jpg()
    #define EXP_RES			GDK_PIXBUF_ERROR
    
    GdkPixbuf * pixbuf;
    GError * perrorbuf;
    GQuark domain;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = NULL;
    perrorbuf = NULL;
    
    pixbuf = gdk_pixbuf_new_from_file(FILENAME,&perrorbuf);
    if(EXP_RES == G_FILE_ERROR){
    	if(pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not NULL, that is unimaginable!", NULL); 
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is NULL", NULL); 
    		return;
    	}
    	if(perrorbuf->domain != G_FILE_ERROR){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":gerror domain is not expected domain: G_FILE_ERROR", NULL); 
    		return;
    	}
    }else if(EXP_RES == GDK_PIXBUF_ERROR){
    	if(pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not NULL, that is unimaginable!", NULL); 
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is NULL", NULL); 
    		return;
    	}
    	if(perrorbuf->domain != GDK_PIXBUF_ERROR){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":gerror domain is not expected domain: GDK_PIXBUF_ERROR", NULL); 
    		return;
    	}
    }else{
    	if(!pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is NULL", NULL); 
    		return;
    	}	
    	if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not a valide GdkPixbuf object!", NULL); 
    		return;
    	}
    	if(perrorbuf != NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is not NULL", NULL); 
    		return;
    	}
    }
    if(pixbuf){
    	g_object_unref(pixbuf);
    }
    if(perrorbuf){
    	g_error_free(perrorbuf);
    }
    free_filename();
    #undef FILENAME
    #undef EXP_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_new_from_file
 * Params: const char *filename, GError **error
 * Returns: GdkPixbuf*
 * Assertion: Creates a new pixbuf by loading an image from a file. The file format is detected automatically. If NULL is returned, then error will be set. Possible errors are in the GDK_PIXBUF_ERROR and G_FILE_ERROR domains.
 * Params Values: filename is the Name of file to load, in the GLib file name encoding  and error is the return location for an error  
 * Expected: A newly-created pixbuf with a reference count of 1, or NULL if any of several error conditions occurred: the file could not be opened, there was no loader for the file's format, there was not enough memory to allocate the image buffer, or the image file contained invalid data.    
 */
static void test_purpose_7()
{
    #define FILENAME 		no_data_file()
    #define EXP_RES			GDK_PIXBUF_ERROR
    
    GdkPixbuf * pixbuf;
    GError * perrorbuf;
    GQuark domain;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = NULL;
    perrorbuf = NULL;
    
    pixbuf = gdk_pixbuf_new_from_file(FILENAME,&perrorbuf);
    if(EXP_RES == G_FILE_ERROR){
    	if(pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not NULL, that is unimaginable!", NULL); 
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is NULL", NULL); 
    		return;
    	}
    	if(perrorbuf->domain != G_FILE_ERROR){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":gerror domain is not expected domain: G_FILE_ERROR", NULL); 
    		return;
    	}
    }else if(EXP_RES == GDK_PIXBUF_ERROR){
    	if(pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not NULL, that is unimaginable!", NULL); 
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is NULL", NULL); 
    		return;
    	}
    	if(perrorbuf->domain != GDK_PIXBUF_ERROR){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":gerror domain is not expected domain: GDK_PIXBUF_ERROR", NULL); 
    		return;
    	}
    }else{
    	if(!pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is NULL", NULL); 
    		return;
    	}	
    	if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not a valide GdkPixbuf object!", NULL); 
    		return;
    	}
    	if(perrorbuf != NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is not NULL", NULL); 
    		return;
    	}
    }
    if(pixbuf){
    	g_object_unref(pixbuf);
    }
    if(perrorbuf){
    	g_error_free(perrorbuf);
    }
    free_filename();
    #undef FILENAME
    #undef EXP_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_new_from_file
 * Params: const char *filename, GError **error
 * Returns: GdkPixbuf*
 * Assertion: Creates a new pixbuf by loading an image from a file. The file format is detected automatically. If NULL is returned, then error will be set. Possible errors are in the GDK_PIXBUF_ERROR and G_FILE_ERROR domains.
 * Params Values: filename is the Name of file to load, in the GLib file name encoding  and error is the return location for an error  
 * Expected: A newly-created pixbuf with a reference count of 1, or NULL if any of several error conditions occurred: the file could not be opened, there was no loader for the file's format, there was not enough memory to allocate the image buffer, or the image file contained invalid data.    
 */
static void test_purpose_8()
{
    #define FILENAME 		no_such_file()
    #define EXP_RES			G_FILE_ERROR
    
    GdkPixbuf * pixbuf;
    GError * perrorbuf;
    GQuark domain;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = NULL;
    perrorbuf = NULL;
    
    pixbuf = gdk_pixbuf_new_from_file(FILENAME,&perrorbuf);
    if(EXP_RES == G_FILE_ERROR){
    	if(pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not NULL, that is unimaginable!", NULL); 
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is NULL", NULL); 
    		return;
    	}
    	if(perrorbuf->domain != G_FILE_ERROR){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":gerror domain is not expected domain: G_FILE_ERROR", NULL); 
    		return;
    	}
    }else if(EXP_RES == GDK_PIXBUF_ERROR){
    	if(pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not NULL, that is unimaginable!", NULL); 
    		return;
    	}
    	if(perrorbuf == NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is NULL", NULL); 
    		return;
    	}
    	if(perrorbuf->domain != GDK_PIXBUF_ERROR){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":gerror domain is not expected domain: GDK_PIXBUF_ERROR", NULL); 
    		return;
    	}
    }else{
    	if(!pixbuf){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is NULL", NULL); 
    		return;
    	}	
    	if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":pixbuf is not a valide GdkPixbuf object!", NULL); 
    		return;
    	}
    	if(perrorbuf != NULL){
    		TEST_FAIL ("\"gdk_pixbuf_new_from_file\":error buf is not NULL", NULL); 
    		return;
    	}
    }
    if(pixbuf){
    	g_object_unref(pixbuf);
    }
    if(perrorbuf){
    	g_error_free(perrorbuf);
    }
    free_filename();
    #undef FILENAME
    #undef EXP_RES
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GdkPixbufFileLoading ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {NULL,0}
};
