/*
 * GdkPixbufLoader methods tests
 * Testing GdkPixbufLoader methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;


/*
 * Name: gdk_pixbuf_loader_new
 * Params: 
 * Returns: GdkPixbufLoader*
 * Assertion: Creates a new pixbuf loader object.
 * Params Values:   
 * Expected: A newly-created pixbuf loader  
 */
static void test_purpose_1()
{
    GdkPixbufLoader * pixbufloader = NULL;
    GError *error = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbufloader = gdk_pixbuf_loader_new();
    if (pixbufloader == NULL) {
    	TEST_FAIL("\"gdk_pixbf_loader_new\": pixbufloader is NULL",NULL);
    	return;
    }
    if (GDK_IS_PIXBUF_LOADER(pixbufloader) != TRUE) {
    	TEST_FAIL("gdk_pixbuf_loader_new: not a valid GdkPixbufLoader object",NULL);
    	return;
    };
    
    if(pixbufloader) {
    	gdk_pixbuf_loader_close (pixbufloader, &error);
    	g_object_unref(pixbufloader);
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_loader_write
 * Params: GdkPixbufLoader *loader, const guchar *buf, gsize count, GError **error
 * Returns: gboolean
 * Assertion: This will cause a pixbuf loader to parse the next count bytes of an image. It will return TRUE if the data was loaded successfully, and FALSE if an error occurred. In the latter case, the loader will be closed, and will not accept further writes. If FALSE is returned, error will be set to an error from the GDK_PIXBUF_ERROR or G_FILE_ERROR domains.
 * Params Values:  loader, A pixbuf loader.  buf, Pointer to image data.  count, Length of the buf buffer in bytes. error, return location for errors
 * Expected: TRUE if the write was successful, or FALSE if the loader cannot parse the buffer  
 */
static void test_purpose_2()
{
    #define LOADER			pixbufloader
    #define BUFFER			"1"
    #define BUFLEN			-1
    #define EXP_RES 		FALSE
    
    GdkPixbufLoader * pixbufloader = NULL;
    GError * perrorbuf = NULL;
    gboolean ret = TRUE;
    GError *error = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbufloader = gdk_pixbuf_loader_new();
    if(pixbufloader == NULL){
    	TEST_FAIL("\"gdk_pixbuf_loader_write\":pixbufloader is NULL",NULL);
    	return;
    }
    
    if(GDK_IS_PIXBUF_LOADER(pixbufloader) != TRUE){
    	TEST_FAIL("gdk_pixbuf_loader_write: not a valid GdkPixbufLoader object",NULL);
    	return;
    };
    
    ret = gdk_pixbuf_loader_write(LOADER,BUFFER,BUFLEN,&perrorbuf);
    if(ret != EXP_RES){
    	TEST_FAIL("\"gdk_pixbuf_loader_write\":return value does not match expected value!",NULL);
    	return;
    }
    
    if(pixbufloader) {
    	gdk_pixbuf_loader_close (pixbufloader, &error);
    	g_object_unref(pixbufloader);
    }
    
    #undef LOADER
    #undef BUFFER
    #undef BUFLEN
    #undef EXP_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_loader_write
 * Params: GdkPixbufLoader *loader, const guchar *buf, gsize count, GError **error
 * Returns: gboolean
 * Assertion: This will cause a pixbuf loader to parse the next count bytes of an image. It will return TRUE if the data was loaded successfully, and FALSE if an error occurred. In the latter case, the loader will be closed, and will not accept further writes. If FALSE is returned, error will be set to an error from the GDK_PIXBUF_ERROR or G_FILE_ERROR domains.
 * Params Values:  loader, A pixbuf loader.  buf, Pointer to image data.  count, Length of the buf buffer in bytes. error, return location for errors
 * Expected: TRUE if the write was successful, or FALSE if the loader cannot parse the buffer  
 */
static void test_purpose_3()
{
    #define LOADER			pixbufloader
    #define BUFFER			"1"
    #define BUFLEN			1
    #define EXP_RES 		TRUE
    
    GdkPixbufLoader * pixbufloader = NULL;
    GError * perrorbuf = NULL;
    gboolean ret = TRUE;
    GError *error = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbufloader = gdk_pixbuf_loader_new();
    if(pixbufloader == NULL){
    	TEST_FAIL("\"gdk_pixbuf_loader_write\":pixbufloader is NULL",NULL);
    	return;
    }
    
    if(GDK_IS_PIXBUF_LOADER(pixbufloader) != TRUE){
    	TEST_FAIL("gdk_pixbuf_loader_write: not a valid GdkPixbufLoader object",NULL);
    	return;
    };
    
    ret = gdk_pixbuf_loader_write(LOADER,BUFFER,BUFLEN,&perrorbuf);
    if(ret != EXP_RES){
    	TEST_FAIL("\"gdk_pixbuf_loader_write\":return value does not match expected value!",NULL);
    	return;
    }
    
    if(pixbufloader) {
    	gdk_pixbuf_loader_close (pixbufloader, &error);
    	g_object_unref(pixbufloader);
    }
    
    #undef LOADER
    #undef BUFFER
    #undef BUFLEN
    #undef EXP_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_loader_write
 * Params: GdkPixbufLoader *loader, const guchar *buf, gsize count, GError **error
 * Returns: gboolean
 * Assertion: This will cause a pixbuf loader to parse the next count bytes of an image. It will return TRUE if the data was loaded successfully, and FALSE if an error occurred. In the latter case, the loader will be closed, and will not accept further writes. If FALSE is returned, error will be set to an error from the GDK_PIXBUF_ERROR or G_FILE_ERROR domains.
 * Params Values:  loader, A pixbuf loader.  buf, Pointer to image data.  count, Length of the buf buffer in bytes. error, return location for errors
 * Expected: TRUE if the write was successful, or FALSE if the loader cannot parse the buffer  
 */
static void test_purpose_4()
{
    #define LOADER			pixbufloader
    #define BUFFER			"1"
    #define BUFLEN			10
    #define EXP_RES 		TRUE
    
    GdkPixbufLoader * pixbufloader = NULL;
    GError * perrorbuf = NULL;
    gboolean ret = TRUE;
    GError *error = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbufloader = gdk_pixbuf_loader_new();
    if(pixbufloader == NULL){
    	TEST_FAIL("\"gdk_pixbuf_loader_write\":pixbufloader is NULL",NULL);
    	return;
    }
    
    if(GDK_IS_PIXBUF_LOADER(pixbufloader) != TRUE){
    	TEST_FAIL("gdk_pixbuf_loader_write: not a valid GdkPixbufLoader object",NULL);
    	return;
    };
    
    ret = gdk_pixbuf_loader_write(LOADER,BUFFER,BUFLEN,&perrorbuf);
    if(ret != EXP_RES){
    	TEST_FAIL("\"gdk_pixbuf_loader_write\":return value does not match expected value!",NULL);
    	return;
    }
    
    if(pixbufloader) {
    	gdk_pixbuf_loader_close (pixbufloader, &error);
    	g_object_unref(pixbufloader);
    }
    
    #undef LOADER
    #undef BUFFER
    #undef BUFLEN
    #undef EXP_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_loader_write
 * Params: GdkPixbufLoader *loader, const guchar *buf, gsize count, GError **error
 * Returns: gboolean
 * Assertion: This will cause a pixbuf loader to parse the next count bytes of an image. It will return TRUE if the data was loaded successfully, and FALSE if an error occurred. In the latter case, the loader will be closed, and will not accept further writes. If FALSE is returned, error will be set to an error from the GDK_PIXBUF_ERROR or G_FILE_ERROR domains.
 * Params Values:  loader, A pixbuf loader.  buf, Pointer to image data.  count, Length of the buf buffer in bytes. error, return location for errors
 * Expected: TRUE if the write was successful, or FALSE if the loader cannot parse the buffer  
 */
static void test_purpose_5()
{
    #define LOADER			pixbufloader
    #define BUFFER			"111111111111111111111111111111"
    #define BUFLEN			30
    #define EXP_RES 		TRUE
    
    GdkPixbufLoader * pixbufloader = NULL;
    GError * perrorbuf = NULL;
    gboolean ret = TRUE;
    GError *error = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbufloader = gdk_pixbuf_loader_new();
    if(pixbufloader == NULL){
    	TEST_FAIL("\"gdk_pixbuf_loader_write\":pixbufloader is NULL",NULL);
    	return;
    }
    
    if(GDK_IS_PIXBUF_LOADER(pixbufloader) != TRUE){
    	TEST_FAIL("gdk_pixbuf_loader_write: not a valid GdkPixbufLoader object",NULL);
    	return;
    };
    
    ret = gdk_pixbuf_loader_write(LOADER,BUFFER,BUFLEN,&perrorbuf);
    if(ret != EXP_RES){
    	TEST_FAIL("\"gdk_pixbuf_loader_write\":return value does not match expected value!",NULL);
    	return;
    }
    
    if(pixbufloader) {
    	gdk_pixbuf_loader_close (pixbufloader, &error);
    	g_object_unref(pixbufloader);
    }
    
    #undef LOADER
    #undef BUFFER
    #undef BUFLEN
    #undef EXP_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_loader_write
 * Params: GdkPixbufLoader *loader, const guchar *buf, gsize count, GError **error
 * Returns: gboolean
 * Assertion: This will cause a pixbuf loader to parse the next count bytes of an image. It will return TRUE if the data was loaded successfully, and FALSE if an error occurred. In the latter case, the loader will be closed, and will not accept further writes. If FALSE is returned, error will be set to an error from the GDK_PIXBUF_ERROR or G_FILE_ERROR domains.
 * Params Values:  loader, A pixbuf loader.  buf, Pointer to image data.  count, Length of the buf buffer in bytes. error, return location for errors
 * Expected: TRUE if the write was successful, or FALSE if the loader cannot parse the buffer  
 */
static void test_purpose_6()
{
    #define LOADER			pixbufloader
    #define BUFFER			"qaw12#$%^&*()_+}{?><"
    #define BUFLEN			30
    #define EXP_RES 		TRUE
    
    GdkPixbufLoader * pixbufloader = NULL;
    GError * perrorbuf = NULL;
    gboolean ret = TRUE;
    GError *error = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbufloader = gdk_pixbuf_loader_new();
    if(pixbufloader == NULL){
    	TEST_FAIL("\"gdk_pixbuf_loader_write\":pixbufloader is NULL",NULL);
    	return;
    }
    
    if(GDK_IS_PIXBUF_LOADER(pixbufloader) != TRUE){
    	TEST_FAIL("gdk_pixbuf_loader_write: not a valid GdkPixbufLoader object",NULL);
    	return;
    };
    
    ret = gdk_pixbuf_loader_write(LOADER,BUFFER,BUFLEN,&perrorbuf);
    if(ret != EXP_RES){
    	TEST_FAIL("\"gdk_pixbuf_loader_write\":return value does not match expected value!",NULL);
    	return;
    }
    
    if(pixbufloader) {
    	gdk_pixbuf_loader_close (pixbufloader, &error);
    	g_object_unref(pixbufloader);
    }
    
    #undef LOADER
    #undef BUFFER
    #undef BUFLEN
    #undef EXP_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_loader_write
 * Params: GdkPixbufLoader *loader, const guchar *buf, gsize count, GError **error
 * Returns: gboolean
 * Assertion: This will cause a pixbuf loader to parse the next count bytes of an image. It will return TRUE if the data was loaded successfully, and FALSE if an error occurred. In the latter case, the loader will be closed, and will not accept further writes. If FALSE is returned, error will be set to an error from the GDK_PIXBUF_ERROR or G_FILE_ERROR domains.
 * Params Values:  loader, A pixbuf loader.  buf, Pointer to image data.  count, Length of the buf buffer in bytes. error, return location for errors
 * Expected: TRUE if the write was successful, or FALSE if the loader cannot parse the buffer  
 */
static void test_purpose_7()
{
    #define LOADER			pixbufloader
    #define BUFFER			"1"
    #define BUFLEN			1000000000
    #define EXP_RES 		FALSE
    
    GdkPixbufLoader * pixbufloader = NULL;
    GError * perrorbuf = NULL;
    gboolean ret = TRUE;
    GError *error = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbufloader = gdk_pixbuf_loader_new();
    if(pixbufloader == NULL){
    	TEST_FAIL("\"gdk_pixbuf_loader_write\":pixbufloader is NULL",NULL);
    	return;
    }
    
    if(GDK_IS_PIXBUF_LOADER(pixbufloader) != TRUE){
    	TEST_FAIL("gdk_pixbuf_loader_write: not a valid GdkPixbufLoader object",NULL);
    	return;
    };
    
    ret = gdk_pixbuf_loader_write(LOADER,BUFFER,BUFLEN,&perrorbuf);
    if(ret != EXP_RES){
    	TEST_FAIL("\"gdk_pixbuf_loader_write\":return value does not match expected value!",NULL);
    	return;
    }
    
    if(pixbufloader) {
    	gdk_pixbuf_loader_close (pixbufloader, &error);
    	g_object_unref(pixbufloader);
    }
    
    #undef LOADER
    #undef BUFFER
    #undef BUFLEN
    #undef EXP_RES
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GdkPixbufLoader ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {NULL,0}
};
