/*
 * GdkProperties methods tests
 * Testing GdkProperties methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gdk_atom_name
 * Params: GdkAtom
 * Return: gchar *
 * Assertion: Determines the string corresponding to an atom.
 * Expected: a newly-allocated string containing the string corresponding to atom.  
 */
static void test_purpose_1()
{
    #define ATOM		4
    #define EXPECTED	"ATOM"
    gchar * name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    name = gdk_atom_name(_GDK_MAKE_ATOM(ATOM));
    if(name == NULL){
    	TEST_FAIL("gdk_atom_name: name is NULL",NULL);
    	return;
    }
    if(strcmp(name,EXPECTED) != 0){
    	TEST_FAIL("gdk_atom_name: %s does not match the expected string, %s", name, EXPECTED, NULL);
    	return;
    }
    g_free(name);
    #undef ATOM
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_atom_name
 * Params: GdkAtom
 * Return: gchar *
 * Assertion: Determines the string corresponding to an atom.
 * Expected: a newly-allocated string containing the string corresponding to atom.  
 */
static void test_purpose_2()
{
    #define ATOM		1
    #define EXPECTED	"PRIMARY"
    gchar * name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    name = gdk_atom_name(_GDK_MAKE_ATOM(ATOM));
    if(name == NULL){
    	TEST_FAIL("gdk_atom_name: name is NULL",NULL);
    	return;
    }
    if(strcmp(name,EXPECTED) != 0){
    	TEST_FAIL("gdk_atom_name: %s does not match the expected string, %s", name, EXPECTED, NULL);
    	return;
    }
    g_free(name);
    #undef ATOM
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_atom_name
 * Params: GdkAtom
 * Return: gchar *
 * Assertion: Determines the string corresponding to an atom.
 * Expected: a newly-allocated string containing the string corresponding to atom.  
 */
static void test_purpose_3()
{
    #define ATOM		2
    #define EXPECTED	"SECONDARY"
    gchar * name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    name = gdk_atom_name(_GDK_MAKE_ATOM(ATOM));
    if(name == NULL){
    	TEST_FAIL("gdk_atom_name: name is NULL",NULL);
    	return;
    }
    if(strcmp(name,EXPECTED) != 0){
    	TEST_FAIL("gdk_atom_name: %s does not match the expected string, %s", name, EXPECTED, NULL);
    	return;
    }
    g_free(name);
    #undef ATOM
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_atom_name
 * Params: GdkAtom
 * Return: gchar *
 * Assertion: Determines the string corresponding to an atom.
 * Expected: a newly-allocated string containing the string corresponding to atom.  
 */
static void test_purpose_4()
{
    #define ATOM		10
    #define EXPECTED	"CUT_BUFFER1"
    gchar * name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    name = gdk_atom_name(_GDK_MAKE_ATOM(ATOM));
    if(name == NULL){
    	TEST_FAIL("gdk_atom_name: name is NULL",NULL);
    	return;
    }
    if(strcmp(name,EXPECTED) != 0){
    	TEST_FAIL("gdk_atom_name: %s does not match the expected string, %s", name, EXPECTED, NULL);
    	return;
    }
    g_free(name);
    #undef ATOM
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_atom_name
 * Params: GdkAtom
 * Return: gchar *
 * Assertion: Determines the string corresponding to an atom.
 * Expected: a newly-allocated string containing the string corresponding to atom.  
 */
static void test_purpose_5()
{
    #define ATOM		20
    #define EXPECTED	"PIXMAP"
    gchar * name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    name = gdk_atom_name(_GDK_MAKE_ATOM(ATOM));
    if(name == NULL){
    	TEST_FAIL("gdk_atom_name: name is NULL",NULL);
    	return;
    }
    if(strcmp(name,EXPECTED) != 0){
    	TEST_FAIL("gdk_atom_name: %s does not match the expected string, %s", name, EXPECTED, NULL);
    	return;
    }
    g_free(name);
    #undef ATOM
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_atom_name
 * Params: GdkAtom
 * Return: gchar *
 * Assertion: Determines the string corresponding to an atom.
 * Expected: a newly-allocated string containing the string corresponding to atom.  
 */
static void test_purpose_6()
{
    #define ATOM		5
    #define EXPECTED	"BITMAP"
    gchar * name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    name = gdk_atom_name(_GDK_MAKE_ATOM(ATOM));
    if(name == NULL){
    	TEST_FAIL("gdk_atom_name: name is NULL",NULL);
    	return;
    }
    if(strcmp(name,EXPECTED) != 0){
    	TEST_FAIL("gdk_atom_name: %s does not match the expected string, %s", name, EXPECTED, NULL);
    	return;
    }
    g_free(name);
    #undef ATOM
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_atom_name
 * Params: GdkAtom
 * Return: gchar *
 * Assertion: Determines the string corresponding to an atom.
 * Expected: a newly-allocated string containing the string corresponding to atom.  
 */
static void test_purpose_7()
{
    #define ATOM		62
    #define EXPECTED	"NOTICE"
    gchar * name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    name = gdk_atom_name(_GDK_MAKE_ATOM(ATOM));
    if(name == NULL){
    	TEST_FAIL("gdk_atom_name: name is NULL",NULL);
    	return;
    }
    if(strcmp(name,EXPECTED) != 0){
    	TEST_FAIL("gdk_atom_name: %s does not match the expected string, %s", name, EXPECTED, NULL);
    	return;
    }
    g_free(name);
    #undef ATOM
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_atom_intern
 * Params: gchar *, gboolean
 * Return: GdkAtom
 * Assertion: Finds or creates an atom corresponding to a given string.
 * Expected: the atom corresponding to name of atom.  
 */
static void test_purpose_8()
{
    #define NAME		"PRIMARY"
    #define EXPECTED	1
    GdkAtom atom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    atom = gdk_atom_intern(NAME,TRUE);
    if(atom != (_GDK_MAKE_ATOM(EXPECTED))){
    	TEST_FAIL("gdk_atom_intern: not a expected atom",NULL);
    	return;
    }
    #undef NAME
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_atom_intern
 * Params: gchar *, gboolean
 * Return: GdkAtom
 * Assertion: Finds or creates an atom corresponding to a given string.
 * Expected: the atom corresponding to name of atom.  
 */
static void test_purpose_9()
{
    #define NAME		"SECONDARY"
    #define EXPECTED	2
    GdkAtom atom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    atom = gdk_atom_intern(NAME,TRUE);
    if(atom != (_GDK_MAKE_ATOM(EXPECTED))){
    	TEST_FAIL("gdk_atom_intern: not a expected atom",NULL);
    	return;
    }
    #undef NAME
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_atom_intern
 * Params: gchar *, gboolean
 * Return: GdkAtom
 * Assertion: Finds or creates an atom corresponding to a given string.
 * Expected: the atom corresponding to name of atom.  
 */
static void test_purpose_10()
{
    #define NAME		"CUT_BUFFER1"
    #define EXPECTED	10
    GdkAtom atom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    atom = gdk_atom_intern(NAME,TRUE);
    if(atom != (_GDK_MAKE_ATOM(EXPECTED))){
    	TEST_FAIL("gdk_atom_intern: not a expected atom",NULL);
    	return;
    }
    #undef NAME
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_atom_intern
 * Params: gchar *, gboolean
 * Return: GdkAtom
 * Assertion: Finds or creates an atom corresponding to a given string.
 * Expected: the atom corresponding to name of atom.  
 */
static void test_purpose_11()
{
    #define NAME		"PIXMAP"
    #define EXPECTED	20
    GdkAtom atom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    atom = gdk_atom_intern(NAME,TRUE);
    if(atom != (_GDK_MAKE_ATOM(EXPECTED))){
    	TEST_FAIL("gdk_atom_intern: not a expected atom",NULL);
    	return;
    }
    #undef NAME
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_atom_intern
 * Params: gchar *, gboolean
 * Return: GdkAtom
 * Assertion: Finds or creates an atom corresponding to a given string.
 * Expected: the atom corresponding to name of atom.  
 */
static void test_purpose_12()
{
    #define NAME		"BITMAP"
    #define EXPECTED	5
    GdkAtom atom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    atom = gdk_atom_intern(NAME,TRUE);
    if(atom != (_GDK_MAKE_ATOM(EXPECTED))){
    	TEST_FAIL("gdk_atom_intern: not a expected atom",NULL);
    	return;
    }
    #undef NAME
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_atom_intern
 * Params: gchar *, gboolean
 * Return: GdkAtom
 * Assertion: Finds or creates an atom corresponding to a given string.
 * Expected: the atom corresponding to name of atom.  
 */
static void test_purpose_13()
{
    #define NAME		"NOTICE"
    #define EXPECTED	62
    GdkAtom atom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    atom = gdk_atom_intern(NAME,TRUE);
    if(atom != (_GDK_MAKE_ATOM(EXPECTED))){
    	TEST_FAIL("gdk_atom_intern: not a expected atom",NULL);
    	return;
    }
    #undef NAME
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_property_get
 * Params: GdkWindow *, GdkAtom, GdkAtom,gulong, gint,GdkAtom *,gint *,gint*,guchar **
 * Return: gboolean
 * Assertion: Retrieves a portion of the contents of a property. If the property does not exist, then the function returns FALSE, and GDK_NONE will be stored in actual_property_type.
 * Expected: TRUE if data was sucessfully received and stored in data, otherwise FALSE.  
 */
static void test_purpose_14()
{
    GdkWindow * window = NULL;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    gboolean ret ;
    GdkAtom actual_type;
    gint actual_format = 0;
    gint actual_length = 0;
    guchar *data = NULL;
    guchar *data_str = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_X | GDK_WA_Y);
    if(window == NULL){
    	TEST_FAIL("gdk_property_get: window is NULL!",NULL);
    	return;
    }
    ret = gdk_property_get(window,gdk_atom_intern("_NET_WM_NAME",TRUE),GDK_NONE,0,1,FALSE,&actual_type,&actual_format,&actual_length,&data);
    if(ret == FALSE){
    	TEST_FAIL("gdk_property_get: get property failed!",NULL);
    	return;
    }
    if(actual_type != gdk_atom_intern("UTF8_STRING",TRUE)){
    	TEST_FAIL("gdk_property_get: actual type of the property is not the expected one!",NULL);
    	return;
    }
    if(actual_format != 8){
    	TEST_FAIL("gdk_property_get: actual format of the property is not the expected one!",NULL);
    	return;
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_property_change
 * Params: GdkWindow *window,GdkAtom property,GdkAtom type,gint format,GdkPropMode mode,const guchar *data,gint nelements
 * Return: void
 * Assertion: Changes the contents of a property on a window.
 * Expected:   
 */
static void test_purpose_15()
{
    GdkWindow * window = NULL;
    GdkWindowAttr attributes = {"test", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    gboolean ret ;
    GdkAtom actual_type;
    gint actual_format = 0;
    gint actual_length = 0;
    guchar *data = NULL;
    guchar *data_str = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_X | GDK_WA_Y);
    if(window == NULL){
    	TEST_FAIL("gdk_property_change: window is NULL!",NULL);
    	return;
    }
    gdk_property_change(window,gdk_atom_intern("WM_NAME",TRUE),gdk_atom_intern("STRING",TRUE),8,GDK_PROP_MODE_REPLACE,"foo",sizeof("foo"));
    
    
    ret = gdk_property_get(window,gdk_atom_intern("WM_NAME",TRUE),GDK_NONE,0,1,FALSE,&actual_type,&actual_format,&actual_length,&data);
    
    if(data == NULL){
    	TEST_FAIL("gdk_property_change: data is NULL",NULL);
    	return;
    }
    
    if(strcmp(data,"foo") != 0 || actual_length != sizeof("foo")){
    	TEST_FAIL("gdk_property_change: property change fail, data=%s, actual_length=%d", data, actual_length, NULL);
    	return;
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_utf8_to_string_target
 * Params: const char *
 * Return: gchar *
 * Assertion: Converts an UTF-8 string into the best possible representation as a STRING. The representation of characters not in STRING is not specified; it may be as pseudo-escape sequences \x{ABCD}, or it may be in some other form of approximation.
 * Expected: the newly-allocated string, or NULL if the conversion failed. (It should not fail for any properly formed UTF-8 string unless system limits like memory or file descriptors are exceeded.).  
 */
static void test_purpose_16()
{
    #define STRING_IN		"1234567890"
    #define EXPECTED		"1234567890"
    gchar * str_ret = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    str_ret = gdk_utf8_to_string_target(STRING_IN);
    
    if(str_ret == NULL){
    	TEST_FAIL("gdk_utf8_to_string_target: str_ret is NULL",NULL);
    	return;
    }
    
    if(strcmp(str_ret,EXPECTED) != 0){
    	TEST_FAIL("gdk_utf8_to_string_target: doesnt match the expected string",NULL);
    	return;
    }
    
    free(str_ret);
    
    #undef STRING_IN
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_utf8_to_string_target
 * Params: const char *
 * Return: gchar *
 * Assertion: Converts an UTF-8 string into the best possible representation as a STRING. The representation of characters not in STRING is not specified; it may be as pseudo-escape sequences \x{ABCD}, or it may be in some other form of approximation.
 * Expected: the newly-allocated string, or NULL if the conversion failed. (It should not fail for any properly formed UTF-8 string unless system limits like memory or file descriptors are exceeded.).  
 */
static void test_purpose_17()
{
    #define STRING_IN		"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
    #define EXPECTED		"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
    gchar * str_ret = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    str_ret = gdk_utf8_to_string_target(STRING_IN);
    
    if(str_ret == NULL){
    	TEST_FAIL("gdk_utf8_to_string_target: str_ret is NULL",NULL);
    	return;
    }
    
    if(strcmp(str_ret,EXPECTED) != 0){
    	TEST_FAIL("gdk_utf8_to_string_target: doesnt match the expected string",NULL);
    	return;
    }
    
    free(str_ret);
    
    #undef STRING_IN
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_utf8_to_string_target
 * Params: const char *
 * Return: gchar *
 * Assertion: Converts an UTF-8 string into the best possible representation as a STRING. The representation of characters not in STRING is not specified; it may be as pseudo-escape sequences \x{ABCD}, or it may be in some other form of approximation.
 * Expected: the newly-allocated string, or NULL if the conversion failed. (It should not fail for any properly formed UTF-8 string unless system limits like memory or file descriptors are exceeded.).  
 */
static void test_purpose_18()
{
    #define STRING_IN		"~`!@#$%^&*()_+=-/?{}][|"
    #define EXPECTED		"~`!@#$%^&*()_+=-/?{}][|"
    gchar * str_ret = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    str_ret = gdk_utf8_to_string_target(STRING_IN);
    
    if(str_ret == NULL){
    	TEST_FAIL("gdk_utf8_to_string_target: str_ret is NULL",NULL);
    	return;
    }
    
    if(strcmp(str_ret,EXPECTED) != 0){
    	TEST_FAIL("gdk_utf8_to_string_target: doesnt match the expected string",NULL);
    	return;
    }
    
    free(str_ret);
    
    #undef STRING_IN
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_utf8_to_string_target
 * Params: const char *
 * Return: gchar *
 * Assertion: Converts an UTF-8 string into the best possible representation as a STRING. The representation of characters not in STRING is not specified; it may be as pseudo-escape sequences \x{ABCD}, or it may be in some other form of approximation.
 * Expected: the newly-allocated string, or NULL if the conversion failed. (It should not fail for any properly formed UTF-8 string unless system limits like memory or file descriptors are exceeded.).  
 */
static void test_purpose_19()
{
    #define STRING_IN		"\xc0\xb1\xc0\xb2\xc0\xb3\xc0\xb4\xc0\xb5"
    #define EXPECTED		"\x31\x32\x33\x34\x35"
    gchar * str_ret = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    str_ret = gdk_utf8_to_string_target(STRING_IN);
    
    if(str_ret == NULL){
    	TEST_FAIL("gdk_utf8_to_string_target: str_ret is NULL",NULL);
    	return;
    }
    
    if(strcmp(str_ret,EXPECTED) != 0){
    	TEST_FAIL("gdk_utf8_to_string_target: doesnt match the expected string",NULL);
    	return;
    }
    
    free(str_ret);
    
    #undef STRING_IN
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_utf8_to_string_target
 * Params: const char *
 * Return: gchar *
 * Assertion: Converts an UTF-8 string into the best possible representation as a STRING. The representation of characters not in STRING is not specified; it may be as pseudo-escape sequences \x{ABCD}, or it may be in some other form of approximation.
 * Expected: the newly-allocated string, or NULL if the conversion failed. (It should not fail for any properly formed UTF-8 string unless system limits like memory or file descriptors are exceeded.).  
 */
static void test_purpose_20()
{
    #define STRING_IN		"\xe0\x80\xb1\xe0\x80\xb2\xe0\x80\xb3\xe0\x80\xb4\xe0\x80\xb5"
    #define EXPECTED		"\x31\x32\x33\x34\x35"
    gchar * str_ret = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    str_ret = gdk_utf8_to_string_target(STRING_IN);
    
    if(str_ret == NULL){
    	TEST_FAIL("gdk_utf8_to_string_target: str_ret is NULL",NULL);
    	return;
    }
    
    if(strcmp(str_ret,EXPECTED) != 0){
    	TEST_FAIL("gdk_utf8_to_string_target: doesnt match the expected string",NULL);
    	return;
    }
    
    free(str_ret);
    
    #undef STRING_IN
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_utf8_to_compound_text
 * Params: const gchar *str,GdkAtom *encoding,gint *format,guchar **ctext,gint *length
 * Return: gboolean 
 * Assertion: Convert from UTF-8 to compound text.
 * Expected: TRUE if the conversion succeeded, otherwise false.  
 */
static void test_purpose_21()
{
    #define STRING_INPUT	"\xe0\x80\xb1\xe0\x80\xb2\xe0\x80\xb3\xe0\x80\xb4\xe0\x80\xb5"
    #define EXPECTED	"\x31\x32\x33\x34\x35"
    
    GdkAtom encoding;
    gint format;
    guchar * ctext = NULL;
    gint length;
    gboolean ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_utf8_to_compound_text(STRING_INPUT,&encoding,&format,&ctext,&length);
    
    if(ret == FALSE){
    	TEST_FAIL("gdk_utf8_to_compound_text: conversion failed!",NULL);
    	return;
    }
    
    if(ctext == NULL){
    	TEST_FAIL("gdk_utf8_to_compound_text: return string is NULL",NULL);
    	return;
    }
    
    if(strcmp(ctext,EXPECTED) != 0){
    	TEST_FAIL("gdk_utf8_to_compound_text: doesnt match expected string",NULL);
    	return;
    }
    free(ctext);
    #undef STRING_INPUT
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_utf8_to_compound_text
 * Params: const gchar *str,GdkAtom *encoding,gint *format,guchar **ctext,gint *length
 * Return: gboolean 
 * Assertion: Convert from UTF-8 to compound text.
 * Expected: TRUE if the conversion succeeded, otherwise false.  
 */
static void test_purpose_22()
{
    #define STRING_INPUT	"1234567890"
    #define EXPECTED	"1234567890"
    
    GdkAtom encoding;
    gint format;
    guchar * ctext = NULL;
    gint length;
    gboolean ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_utf8_to_compound_text(STRING_INPUT,&encoding,&format,&ctext,&length);
    
    if(ret == FALSE){
    	TEST_FAIL("gdk_utf8_to_compound_text: conversion failed!",NULL);
    	return;
    }
    
    if(ctext == NULL){
    	TEST_FAIL("gdk_utf8_to_compound_text: return string is NULL",NULL);
    	return;
    }
    
    if(strcmp(ctext,EXPECTED) != 0){
    	TEST_FAIL("gdk_utf8_to_compound_text: doesnt match expected string",NULL);
    	return;
    }
    free(ctext);
    #undef STRING_INPUT
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_utf8_to_compound_text
 * Params: const gchar *str,GdkAtom *encoding,gint *format,guchar **ctext,gint *length
 * Return: gboolean 
 * Assertion: Convert from UTF-8 to compound text.
 * Expected: TRUE if the conversion succeeded, otherwise false.  
 */
static void test_purpose_23()
{
    #define STRING_INPUT	"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
    #define EXPECTED	"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
    
    GdkAtom encoding;
    gint format;
    guchar * ctext = NULL;
    gint length;
    gboolean ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_utf8_to_compound_text(STRING_INPUT,&encoding,&format,&ctext,&length);
    
    if(ret == FALSE){
    	TEST_FAIL("gdk_utf8_to_compound_text: conversion failed!",NULL);
    	return;
    }
    
    if(ctext == NULL){
    	TEST_FAIL("gdk_utf8_to_compound_text: return string is NULL",NULL);
    	return;
    }
    
    if(strcmp(ctext,EXPECTED) != 0){
    	TEST_FAIL("gdk_utf8_to_compound_text: doesnt match expected string",NULL);
    	return;
    }
    free(ctext);
    #undef STRING_INPUT
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_utf8_to_compound_text
 * Params: const gchar *str,GdkAtom *encoding,gint *format,guchar **ctext,gint *length
 * Return: gboolean 
 * Assertion: Convert from UTF-8 to compound text.
 * Expected: TRUE if the conversion succeeded, otherwise false.  
 */
static void test_purpose_24()
{
    #define STRING_INPUT	"~`!@#$%^&*()_+=-/?{}][|"
    #define EXPECTED	"~`!@#$%^&*()_+=-/?{}][|"
    
    GdkAtom encoding;
    gint format;
    guchar * ctext = NULL;
    gint length;
    gboolean ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_utf8_to_compound_text(STRING_INPUT,&encoding,&format,&ctext,&length);
    
    if(ret == FALSE){
    	TEST_FAIL("gdk_utf8_to_compound_text: conversion failed!",NULL);
    	return;
    }
    
    if(ctext == NULL){
    	TEST_FAIL("gdk_utf8_to_compound_text: return string is NULL",NULL);
    	return;
    }
    
    if(strcmp(ctext,EXPECTED) != 0){
    	TEST_FAIL("gdk_utf8_to_compound_text: doesnt match expected string",NULL);
    	return;
    }
    free(ctext);
    #undef STRING_INPUT
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_utf8_to_compound_text
 * Params: const gchar *str,GdkAtom *encoding,gint *format,guchar **ctext,gint *length
 * Return: gboolean 
 * Assertion: Convert from UTF-8 to compound text.
 * Expected: TRUE if the conversion succeeded, otherwise false.  
 */
static void test_purpose_25()
{
    #define STRING_INPUT	"\xc0\xb1\xc0\xb2\xc0\xb3\xc0\xb4\xc0\xb5"
    #define EXPECTED	"\x31\x32\x33\x34\x35"
    
    GdkAtom encoding;
    gint format;
    guchar * ctext = NULL;
    gint length;
    gboolean ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_utf8_to_compound_text(STRING_INPUT,&encoding,&format,&ctext,&length);
    
    if(ret == FALSE){
    	TEST_FAIL("gdk_utf8_to_compound_text: conversion failed!",NULL);
    	return;
    }
    
    if(ctext == NULL){
    	TEST_FAIL("gdk_utf8_to_compound_text: return string is NULL",NULL);
    	return;
    }
    
    if(strcmp(ctext,EXPECTED) != 0){
    	TEST_FAIL("gdk_utf8_to_compound_text: doesnt match expected string",NULL);
    	return;
    }
    free(ctext);
    #undef STRING_INPUT
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GdkProperties ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {NULL,0}
};
