/*
 * GtkColorSelection methods tests
 * Testing GtkColorSelection methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
void global_change_palette_hook_1 (const GdkColor *colors, gint n_colors)
{
}

void global_change_palette_hook_2 (const GdkColor *colors, gint n_colors)
{
}

void global_change_palette_with_screen_hook_1 (GdkScreen *screen, const GdkColor *colors, gint n_colors)
{
}

void global_change_palette_with_screen_hook_2 (GdkScreen *screen, const GdkColor *colors, gint n_colors)
{
}

/*
 * Name: gtk_color_selection_new
 * Params: void
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkColorSelection.
 * Params Values: void
 * Expected: GtkColorSelection*  
 */
static void test_purpose_1()
{
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_has_opacity_control
 * Params: GtkColorSelection *colorsel, gboolean has_opacity
 * Returns: void
 * Assertion: Sets the colorsel to use or not use opacity.
 * Params Values: a newly created GtkColorSelection*, TRUE
 * Expected: void
 * 
 * Name: gtk_color_selection_get_has_opacity_control
 * Params: GtkColorSelection *colorsel
 * Returns: gboolean
 * Assertion: Determines whether the colorsel has an opacity control.
 * Params Values: a newly created GtkColorSelection*
 * Expected: gboolean  
 */
static void test_purpose_2()
{
    #define HAS_OPACITY TRUE
    
    GtkWidget *widget;
    gboolean has_opacity;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_has_opacity_control (GTK_COLOR_SELECTION (widget), HAS_OPACITY);
    has_opacity = gtk_color_selection_get_has_opacity_control(GTK_COLOR_SELECTION (widget));
    if (has_opacity != HAS_OPACITY)
    {
        TEST_FAIL ("has_opacity = %d, should be %d", has_opacity, HAS_OPACITY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HAS_OPACITY 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_has_opacity_control
 * Params: GtkColorSelection *colorsel, gboolean has_opacity
 * Returns: void
 * Assertion: Sets the colorsel to use or not use opacity.
 * Params Values: a newly created GtkColorSelection*, FALSE
 * Expected: void
 * 
 * Name: gtk_color_selection_get_has_opacity_control
 * Params: GtkColorSelection *colorsel
 * Returns: gboolean
 * Assertion: Determines whether the colorsel has an opacity control.
 * Params Values: a newly created GtkColorSelection*
 * Expected: gboolean  
 */
static void test_purpose_3()
{
    #define HAS_OPACITY FALSE
    
    GtkWidget *widget;
    gboolean has_opacity;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_has_opacity_control (GTK_COLOR_SELECTION (widget), HAS_OPACITY);
    has_opacity = gtk_color_selection_get_has_opacity_control(GTK_COLOR_SELECTION (widget));
    if (has_opacity != HAS_OPACITY)
    {
        TEST_FAIL ("has_opacity = %d, should be %d", has_opacity, HAS_OPACITY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HAS_OPACITY 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_has_palette
 * Params: GtkColorSelection *colorsel, gboolean has_palette
 * Returns: void
 * Assertion: Shows and hides the palette based upon the value of has_palette.
 * Params Values: a newly created GtkColorSelection*, TRUE
 * Expected: void
 * 
 * Name: gtk_color_selection_get_has_palette
 * Params: GtkColorSelection *colorsel
 * Returns: gboolean
 * Assertion: Determines whether the color selector has a color palette.
 * Params Values: a newly created GtkColorSelection*
 * Expected: gboolean  
 */
static void test_purpose_4()
{
    #define HAS_PALETTE TRUE
    
    GtkWidget *widget;
    gboolean has_palette;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_has_palette (GTK_COLOR_SELECTION (widget), HAS_PALETTE);
    has_palette = gtk_color_selection_get_has_palette (GTK_COLOR_SELECTION (widget));
    if (has_palette != HAS_PALETTE)
    {
        TEST_FAIL ("has_palette = %d, should be %d", has_palette, HAS_PALETTE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HAS_PALETTE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_has_palette
 * Params: GtkColorSelection *colorsel, gboolean has_palette
 * Returns: void
 * Assertion: Shows and hides the palette based upon the value of has_palette.
 * Params Values: a newly created GtkColorSelection*, FALSE
 * Expected: void
 * 
 * Name: gtk_color_selection_get_has_palette
 * Params: GtkColorSelection *colorsel
 * Returns: gboolean
 * Assertion: Determines whether the color selector has a color palette.
 * Params Values: a newly created GtkColorSelection*
 * Expected: gboolean  
 */
static void test_purpose_5()
{
    #define HAS_PALETTE FALSE
    
    GtkWidget *widget;
    gboolean has_palette;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_has_palette (GTK_COLOR_SELECTION (widget), HAS_PALETTE);
    has_palette = gtk_color_selection_get_has_palette (GTK_COLOR_SELECTION (widget));
    if (has_palette != HAS_PALETTE)
    {
        TEST_FAIL ("has_palette = %d, should be %d", has_palette, HAS_PALETTE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HAS_PALETTE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_current_alpha
 * Params: GtkColorSelection *colorsel, guint16 alpha
 * Returns: void
 * Assertion: Sets the current opacity to be alpha.
 * Params Values: a newly created GtkColorSelection*, 0
 * Expected: void
 * 
 * Name: gtk_color_selection_get_current_alpha
 * Params: GtkColorSelection *colorsel
 * Returns: guint16
 * Assertion:  Returns the current alpha value.
 * Params Values: a newly created GtkColorSelection*
 * Expected: guint16   
 */
static void test_purpose_6()
{
    #define ALPHA 0
    
    GtkWidget *widget;
    guint16 alpha;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_current_alpha (GTK_COLOR_SELECTION (widget), ALPHA);
    alpha = gtk_color_selection_get_current_alpha (GTK_COLOR_SELECTION (widget));
    if (alpha != ALPHA)
    {
        TEST_FAIL ("alpha = %d, should be %d", alpha, ALPHA);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_current_alpha
 * Params: GtkColorSelection *colorsel, guint16 alpha
 * Returns: void
 * Assertion: Sets the current opacity to be alpha.
 * Params Values: a newly created GtkColorSelection*, 5
 * Expected: void
 * 
 * Name: gtk_color_selection_get_current_alpha
 * Params: GtkColorSelection *colorsel
 * Returns: guint16
 * Assertion:  Returns the current alpha value.
 * Params Values: a newly created GtkColorSelection*
 * Expected: guint16   
 */
static void test_purpose_7()
{
    #define ALPHA 5
    
    GtkWidget *widget;
    guint16 alpha;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_current_alpha (GTK_COLOR_SELECTION (widget), ALPHA);
    alpha = gtk_color_selection_get_current_alpha (GTK_COLOR_SELECTION (widget));
    if (alpha != ALPHA)
    {
        TEST_FAIL ("alpha = %d, should be %d", alpha, ALPHA);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_current_alpha
 * Params: GtkColorSelection *colorsel, guint16 alpha
 * Returns: void
 * Assertion: Sets the current opacity to be alpha.
 * Params Values: a newly created GtkColorSelection*, 20001
 * Expected: void
 * 
 * Name: gtk_color_selection_get_current_alpha
 * Params: GtkColorSelection *colorsel
 * Returns: guint16
 * Assertion:  Returns the current alpha value.
 * Params Values: a newly created GtkColorSelection*
 * Expected: guint16   
 */
static void test_purpose_8()
{
    #define ALPHA 20001
    
    GtkWidget *widget;
    guint16 alpha;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_current_alpha (GTK_COLOR_SELECTION (widget), ALPHA);
    alpha = gtk_color_selection_get_current_alpha (GTK_COLOR_SELECTION (widget));
    if (alpha != ALPHA)
    {
        TEST_FAIL ("alpha = %d, should be %d", alpha, ALPHA);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_current_alpha
 * Params: GtkColorSelection *colorsel, guint16 alpha
 * Returns: void
 * Assertion: Sets the current opacity to be alpha.
 * Params Values: a newly created GtkColorSelection*, 30001
 * Expected: void
 * 
 * Name: gtk_color_selection_get_current_alpha
 * Params: GtkColorSelection *colorsel
 * Returns: guint16
 * Assertion:  Returns the current alpha value.
 * Params Values: a newly created GtkColorSelection*
 * Expected: guint16   
 */
static void test_purpose_9()
{
    #define ALPHA 30001
    
    GtkWidget *widget;
    guint16 alpha;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_current_alpha (GTK_COLOR_SELECTION (widget), ALPHA);
    alpha = gtk_color_selection_get_current_alpha (GTK_COLOR_SELECTION (widget));
    if (alpha != ALPHA)
    {
        TEST_FAIL ("alpha = %d, should be %d", alpha, ALPHA);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_current_alpha
 * Params: GtkColorSelection *colorsel, guint16 alpha
 * Returns: void
 * Assertion: Sets the current opacity to be alpha.
 * Params Values: a newly created GtkColorSelection*, 65535
 * Expected: void
 * 
 * Name: gtk_color_selection_get_current_alpha
 * Params: GtkColorSelection *colorsel
 * Returns: guint16
 * Assertion:  Returns the current alpha value.
 * Params Values: a newly created GtkColorSelection*
 * Expected: guint16   
 */
static void test_purpose_10()
{
    #define ALPHA 65535
    
    GtkWidget *widget;
    guint16 alpha;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_current_alpha (GTK_COLOR_SELECTION (widget), ALPHA);
    alpha = gtk_color_selection_get_current_alpha (GTK_COLOR_SELECTION (widget));
    if (alpha != ALPHA)
    {
        TEST_FAIL ("alpha = %d, should be %d", alpha, ALPHA);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_current_alpha
 * Params: GtkColorSelection *colorsel, guint16 alpha
 * Returns: void
 * Assertion: The first time this is called, it will also set the original opacity to be alpha too.
 * Params Values: a newly created GtkColorSelection*, 0
 * Expected: void  
 */
static void test_purpose_11()
{
    #define ALPHA 0
    
    GtkWidget *widget;
    guint16 alpha;
    guint16 prev_alpha;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_current_alpha (GTK_COLOR_SELECTION (widget), ALPHA);
    alpha = gtk_color_selection_get_current_alpha (GTK_COLOR_SELECTION (widget));
    if (alpha != ALPHA)
    {
        TEST_FAIL ("alpha = %d, should be %d", alpha, ALPHA);
    }
    
    prev_alpha = gtk_color_selection_get_previous_alpha (GTK_COLOR_SELECTION (widget));
    if (prev_alpha != ALPHA)
    {
        TEST_FAIL ("prev_alpha = %d, should be %d", prev_alpha, ALPHA);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_current_alpha
 * Params: GtkColorSelection *colorsel, guint16 alpha
 * Returns: void
 * Assertion: The first time this is called, it will also set the original opacity to be alpha too.
 * Params Values: a newly created GtkColorSelection*, 5
 * Expected: void  
 */
static void test_purpose_12()
{
    #define ALPHA 5
    
    GtkWidget *widget;
    guint16 alpha;
    guint16 prev_alpha;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_current_alpha (GTK_COLOR_SELECTION (widget), ALPHA);
    alpha = gtk_color_selection_get_current_alpha (GTK_COLOR_SELECTION (widget));
    if (alpha != ALPHA)
    {
        TEST_FAIL ("alpha = %d, should be %d", alpha, ALPHA);
    }
    
    prev_alpha = gtk_color_selection_get_previous_alpha (GTK_COLOR_SELECTION (widget));
    if (prev_alpha != ALPHA)
    {
        TEST_FAIL ("prev_alpha = %d, should be %d", prev_alpha, ALPHA);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_current_alpha
 * Params: GtkColorSelection *colorsel, guint16 alpha
 * Returns: void
 * Assertion: The first time this is called, it will also set the original opacity to be alpha too.
 * Params Values: a newly created GtkColorSelection*, 20001
 * Expected: void  
 */
static void test_purpose_13()
{
    #define ALPHA 20001
    
    GtkWidget *widget;
    guint16 alpha;
    guint16 prev_alpha;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_current_alpha (GTK_COLOR_SELECTION (widget), ALPHA);
    alpha = gtk_color_selection_get_current_alpha (GTK_COLOR_SELECTION (widget));
    if (alpha != ALPHA)
    {
        TEST_FAIL ("alpha = %d, should be %d", alpha, ALPHA);
    }
    
    prev_alpha = gtk_color_selection_get_previous_alpha (GTK_COLOR_SELECTION (widget));
    if (prev_alpha != ALPHA)
    {
        TEST_FAIL ("prev_alpha = %d, should be %d", prev_alpha, ALPHA);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_current_alpha
 * Params: GtkColorSelection *colorsel, guint16 alpha
 * Returns: void
 * Assertion: The first time this is called, it will also set the original opacity to be alpha too.
 * Params Values: a newly created GtkColorSelection*, 30001
 * Expected: void  
 */
static void test_purpose_14()
{
    #define ALPHA 30001
    
    GtkWidget *widget;
    guint16 alpha;
    guint16 prev_alpha;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_current_alpha (GTK_COLOR_SELECTION (widget), ALPHA);
    alpha = gtk_color_selection_get_current_alpha (GTK_COLOR_SELECTION (widget));
    if (alpha != ALPHA)
    {
        TEST_FAIL ("alpha = %d, should be %d", alpha, ALPHA);
    }
    
    prev_alpha = gtk_color_selection_get_previous_alpha (GTK_COLOR_SELECTION (widget));
    if (prev_alpha != ALPHA)
    {
        TEST_FAIL ("prev_alpha = %d, should be %d", prev_alpha, ALPHA);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_current_alpha
 * Params: GtkColorSelection *colorsel, guint16 alpha
 * Returns: void
 * Assertion: The first time this is called, it will also set the original opacity to be alpha too.
 * Params Values: a newly created GtkColorSelection*, 65535
 * Expected: void  
 */
static void test_purpose_15()
{
    #define ALPHA 65535
    
    GtkWidget *widget;
    guint16 alpha;
    guint16 prev_alpha;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_current_alpha (GTK_COLOR_SELECTION (widget), ALPHA);
    alpha = gtk_color_selection_get_current_alpha (GTK_COLOR_SELECTION (widget));
    if (alpha != ALPHA)
    {
        TEST_FAIL ("alpha = %d, should be %d", alpha, ALPHA);
    }
    
    prev_alpha = gtk_color_selection_get_previous_alpha (GTK_COLOR_SELECTION (widget));
    if (prev_alpha != ALPHA)
    {
        TEST_FAIL ("prev_alpha = %d, should be %d", prev_alpha, ALPHA);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_previous_alpha
 * Params: GtkColorSelection *colorsel, guint16 alpha
 * Returns: void
 * Assertion: Sets the 'previous' alpha to be alpha.
 * Params Values: a newly created GtkColorSelection*, 0
 * Expected: void
 * 
 * Name: gtk_color_selection_get_previous_alpha
 * Params: GtkColorSelection *colorsel
 * Returns: guint16 
 * Assertion: Returns the previous alpha value
 * Params Values: a newly created GtkColorSelection*
 * Expected: guint16   
 */
static void test_purpose_16()
{
    #define ALPHA 0
    
    GtkWidget *widget;
    guint16 alpha;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_previous_alpha (GTK_COLOR_SELECTION (widget), ALPHA);
    alpha = gtk_color_selection_get_previous_alpha (GTK_COLOR_SELECTION (widget));
    if (alpha != ALPHA)
    {
        TEST_FAIL ("alpha = %d, should be %d", alpha, ALPHA);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_previous_alpha
 * Params: GtkColorSelection *colorsel, guint16 alpha
 * Returns: void
 * Assertion: Sets the 'previous' alpha to be alpha.
 * Params Values: a newly created GtkColorSelection*, 1
 * Expected: void
 * 
 * Name: gtk_color_selection_get_previous_alpha
 * Params: GtkColorSelection *colorsel
 * Returns: guint16 
 * Assertion: Returns the previous alpha value
 * Params Values: a newly created GtkColorSelection*
 * Expected: guint16   
 */
static void test_purpose_17()
{
    #define ALPHA 1
    
    GtkWidget *widget;
    guint16 alpha;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_previous_alpha (GTK_COLOR_SELECTION (widget), ALPHA);
    alpha = gtk_color_selection_get_previous_alpha (GTK_COLOR_SELECTION (widget));
    if (alpha != ALPHA)
    {
        TEST_FAIL ("alpha = %d, should be %d", alpha, ALPHA);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_previous_alpha
 * Params: GtkColorSelection *colorsel, guint16 alpha
 * Returns: void
 * Assertion: Sets the 'previous' alpha to be alpha.
 * Params Values: a newly created GtkColorSelection*, 20001
 * Expected: void
 * 
 * Name: gtk_color_selection_get_previous_alpha
 * Params: GtkColorSelection *colorsel
 * Returns: guint16 
 * Assertion: Returns the previous alpha value
 * Params Values: a newly created GtkColorSelection*
 * Expected: guint16   
 */
static void test_purpose_18()
{
    #define ALPHA 20001
    
    GtkWidget *widget;
    guint16 alpha;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_previous_alpha (GTK_COLOR_SELECTION (widget), ALPHA);
    alpha = gtk_color_selection_get_previous_alpha (GTK_COLOR_SELECTION (widget));
    if (alpha != ALPHA)
    {
        TEST_FAIL ("alpha = %d, should be %d", alpha, ALPHA);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_previous_alpha
 * Params: GtkColorSelection *colorsel, guint16 alpha
 * Returns: void
 * Assertion: Sets the 'previous' alpha to be alpha.
 * Params Values: a newly created GtkColorSelection*, 30001
 * Expected: void
 * 
 * Name: gtk_color_selection_get_previous_alpha
 * Params: GtkColorSelection *colorsel
 * Returns: guint16 
 * Assertion: Returns the previous alpha value
 * Params Values: a newly created GtkColorSelection*
 * Expected: guint16   
 */
static void test_purpose_19()
{
    #define ALPHA 30001
    
    GtkWidget *widget;
    guint16 alpha;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_previous_alpha (GTK_COLOR_SELECTION (widget), ALPHA);
    alpha = gtk_color_selection_get_previous_alpha (GTK_COLOR_SELECTION (widget));
    if (alpha != ALPHA)
    {
        TEST_FAIL ("alpha = %d, should be %d", alpha, ALPHA);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_previous_alpha
 * Params: GtkColorSelection *colorsel, guint16 alpha
 * Returns: void
 * Assertion: Sets the 'previous' alpha to be alpha.
 * Params Values: a newly created GtkColorSelection*, 65535
 * Expected: void
 * 
 * Name: gtk_color_selection_get_previous_alpha
 * Params: GtkColorSelection *colorsel
 * Returns: guint16 
 * Assertion: Returns the previous alpha value
 * Params Values: a newly created GtkColorSelection*
 * Expected: guint16   
 */
static void test_purpose_20()
{
    #define ALPHA 65535
    
    GtkWidget *widget;
    guint16 alpha;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_previous_alpha (GTK_COLOR_SELECTION (widget), ALPHA);
    alpha = gtk_color_selection_get_previous_alpha (GTK_COLOR_SELECTION (widget));
    if (alpha != ALPHA)
    {
        TEST_FAIL ("alpha = %d, should be %d", alpha, ALPHA);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_current_color
 * Params: GtkColorSelection *colorsel, GdkColor *color 
 * Returns: void
 * Assertion: Sets the current color to be color.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void
 * 
 * Name: gtk_color_selection_get_current_color
 * Params: GtkColorSelection *colorsel, GdkColor *color
 * Returns: void
 * Assertion: Sets color to be the current color in the GtkColorSelection widget.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void  
 */
static void test_purpose_21()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor real_color;
    
    #define RED 0
    #define GREEN 0
    #define BLUE 0
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    
    gtk_color_selection_set_current_color (GTK_COLOR_SELECTION (widget), &color);
    
    gtk_color_selection_get_current_color (GTK_COLOR_SELECTION (widget), &real_color);
    if (real_color.red != color.red)
    {
        TEST_FAIL ("real_color.red = %d, should be %d", real_color.red, color.red);
    }
    if (real_color.green != color.green)
    {
        TEST_FAIL ("real_color.green = %d, should be %d", real_color.green, color.green);
    }
    if (real_color.blue != color.blue)
    {
        TEST_FAIL ("real_color.blue = %d, should be %d", real_color.blue, color.blue);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_current_color
 * Params: GtkColorSelection *colorsel, GdkColor *color 
 * Returns: void
 * Assertion: Sets the current color to be color.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void
 * 
 * Name: gtk_color_selection_get_current_color
 * Params: GtkColorSelection *colorsel, GdkColor *color
 * Returns: void
 * Assertion: Sets color to be the current color in the GtkColorSelection widget.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void  
 */
static void test_purpose_22()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor real_color;
    
    #define RED 1
    #define GREEN 1
    #define BLUE 1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    
    gtk_color_selection_set_current_color (GTK_COLOR_SELECTION (widget), &color);
    
    gtk_color_selection_get_current_color (GTK_COLOR_SELECTION (widget), &real_color);
    if (real_color.red != color.red)
    {
        TEST_FAIL ("real_color.red = %d, should be %d", real_color.red, color.red);
    }
    if (real_color.green != color.green)
    {
        TEST_FAIL ("real_color.green = %d, should be %d", real_color.green, color.green);
    }
    if (real_color.blue != color.blue)
    {
        TEST_FAIL ("real_color.blue = %d, should be %d", real_color.blue, color.blue);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_current_color
 * Params: GtkColorSelection *colorsel, GdkColor *color 
 * Returns: void
 * Assertion: Sets the current color to be color.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void
 * 
 * Name: gtk_color_selection_get_current_color
 * Params: GtkColorSelection *colorsel, GdkColor *color
 * Returns: void
 * Assertion: Sets color to be the current color in the GtkColorSelection widget.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void  
 */
static void test_purpose_23()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor real_color;
    
    #define RED 20001
    #define GREEN 20001
    #define BLUE 20001
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    
    gtk_color_selection_set_current_color (GTK_COLOR_SELECTION (widget), &color);
    
    gtk_color_selection_get_current_color (GTK_COLOR_SELECTION (widget), &real_color);
    if (real_color.red != color.red)
    {
        TEST_FAIL ("real_color.red = %d, should be %d", real_color.red, color.red);
    }
    if (real_color.green != color.green)
    {
        TEST_FAIL ("real_color.green = %d, should be %d", real_color.green, color.green);
    }
    if (real_color.blue != color.blue)
    {
        TEST_FAIL ("real_color.blue = %d, should be %d", real_color.blue, color.blue);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_current_color
 * Params: GtkColorSelection *colorsel, GdkColor *color 
 * Returns: void
 * Assertion: Sets the current color to be color.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void
 * 
 * Name: gtk_color_selection_get_current_color
 * Params: GtkColorSelection *colorsel, GdkColor *color
 * Returns: void
 * Assertion: Sets color to be the current color in the GtkColorSelection widget.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void  
 */
static void test_purpose_24()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor real_color;
    
    #define RED 30001
    #define GREEN 30001
    #define BLUE 30001
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    
    gtk_color_selection_set_current_color (GTK_COLOR_SELECTION (widget), &color);
    
    gtk_color_selection_get_current_color (GTK_COLOR_SELECTION (widget), &real_color);
    if (real_color.red != color.red)
    {
        TEST_FAIL ("real_color.red = %d, should be %d", real_color.red, color.red);
    }
    if (real_color.green != color.green)
    {
        TEST_FAIL ("real_color.green = %d, should be %d", real_color.green, color.green);
    }
    if (real_color.blue != color.blue)
    {
        TEST_FAIL ("real_color.blue = %d, should be %d", real_color.blue, color.blue);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_current_color
 * Params: GtkColorSelection *colorsel, GdkColor *color 
 * Returns: void
 * Assertion: Sets the current color to be color.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void
 * 
 * Name: gtk_color_selection_get_current_color
 * Params: GtkColorSelection *colorsel, GdkColor *color
 * Returns: void
 * Assertion: Sets color to be the current color in the GtkColorSelection widget.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void  
 */
static void test_purpose_25()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor real_color;
    
    #define RED 65535
    #define GREEN 65535
    #define BLUE 65535
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    
    gtk_color_selection_set_current_color (GTK_COLOR_SELECTION (widget), &color);
    
    gtk_color_selection_get_current_color (GTK_COLOR_SELECTION (widget), &real_color);
    if (real_color.red != color.red)
    {
        TEST_FAIL ("real_color.red = %d, should be %d", real_color.red, color.red);
    }
    if (real_color.green != color.green)
    {
        TEST_FAIL ("real_color.green = %d, should be %d", real_color.green, color.green);
    }
    if (real_color.blue != color.blue)
    {
        TEST_FAIL ("real_color.blue = %d, should be %d", real_color.blue, color.blue);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_current_color
 * Params: GtkColorSelection *colorsel, GdkColor *color 
 * Returns: void
 * Assertion: The first time this is called, it will also set the original color to be color too.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void
 * 
 * Name: gtk_color_selection_set_previous_color
 * Params: GtkColorSelection *colorsel, GdkColor *color 
 * Returns: void
 * Assertion: Calling gtk_color_selection_set_current_color() will also set this color the first time it is called.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void  
 */
static void test_purpose_26()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor real_color;
    GdkColor real_prev_color;
    
    #define RED 0
    #define GREEN 0
    #define BLUE 0
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    
    gtk_color_selection_set_current_color (GTK_COLOR_SELECTION (widget), &color);
    
    gtk_color_selection_get_current_color (GTK_COLOR_SELECTION (widget), &real_color);
    if (real_color.red != color.red)
    {
        TEST_FAIL ("real_color.red = %d, should be %d", real_color.red, color.red);
    }
    if (real_color.green != color.green)
    {
        TEST_FAIL ("real_color.green = %d, should be %d", real_color.green, color.green);
    }
    if (real_color.blue != color.blue)
    {
        TEST_FAIL ("real_color.blue = %d, should be %d", real_color.blue, color.blue);
    }
    
    gtk_color_selection_get_previous_color (GTK_COLOR_SELECTION (widget), 
                                            &real_prev_color);
    if (real_prev_color.red != color.red)
    {
        TEST_FAIL ("real_prev_color.red = %d, should be %d", 
                   real_prev_color.red, color.red);
    }
    if (real_prev_color.green != color.green)
    {
        TEST_FAIL ("real_prev_color.green = %d, should be %d", 
                   real_prev_color.green, color.green);
    }
    if (real_prev_color.blue != color.blue)
    {
        TEST_FAIL ("real_prev_color.blue = %d, should be %d", 
                   real_prev_color.blue, color.blue);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_current_color
 * Params: GtkColorSelection *colorsel, GdkColor *color 
 * Returns: void
 * Assertion: The first time this is called, it will also set the original color to be color too.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void
 * 
 * Name: gtk_color_selection_set_previous_color
 * Params: GtkColorSelection *colorsel, GdkColor *color 
 * Returns: void
 * Assertion: Calling gtk_color_selection_set_current_color() will also set this color the first time it is called.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void  
 */
static void test_purpose_27()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor real_color;
    GdkColor real_prev_color;
    
    #define RED 1
    #define GREEN 1
    #define BLUE 1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    
    gtk_color_selection_set_current_color (GTK_COLOR_SELECTION (widget), &color);
    
    gtk_color_selection_get_current_color (GTK_COLOR_SELECTION (widget), &real_color);
    if (real_color.red != color.red)
    {
        TEST_FAIL ("real_color.red = %d, should be %d", real_color.red, color.red);
    }
    if (real_color.green != color.green)
    {
        TEST_FAIL ("real_color.green = %d, should be %d", real_color.green, color.green);
    }
    if (real_color.blue != color.blue)
    {
        TEST_FAIL ("real_color.blue = %d, should be %d", real_color.blue, color.blue);
    }
    
    gtk_color_selection_get_previous_color (GTK_COLOR_SELECTION (widget), 
                                            &real_prev_color);
    if (real_prev_color.red != color.red)
    {
        TEST_FAIL ("real_prev_color.red = %d, should be %d", 
                   real_prev_color.red, color.red);
    }
    if (real_prev_color.green != color.green)
    {
        TEST_FAIL ("real_prev_color.green = %d, should be %d", 
                   real_prev_color.green, color.green);
    }
    if (real_prev_color.blue != color.blue)
    {
        TEST_FAIL ("real_prev_color.blue = %d, should be %d", 
                   real_prev_color.blue, color.blue);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_current_color
 * Params: GtkColorSelection *colorsel, GdkColor *color 
 * Returns: void
 * Assertion: The first time this is called, it will also set the original color to be color too.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void
 * 
 * Name: gtk_color_selection_set_previous_color
 * Params: GtkColorSelection *colorsel, GdkColor *color 
 * Returns: void
 * Assertion: Calling gtk_color_selection_set_current_color() will also set this color the first time it is called.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void  
 */
static void test_purpose_28()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor real_color;
    GdkColor real_prev_color;
    
    #define RED 20001
    #define GREEN 20001
    #define BLUE 20001
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    
    gtk_color_selection_set_current_color (GTK_COLOR_SELECTION (widget), &color);
    
    gtk_color_selection_get_current_color (GTK_COLOR_SELECTION (widget), &real_color);
    if (real_color.red != color.red)
    {
        TEST_FAIL ("real_color.red = %d, should be %d", real_color.red, color.red);
    }
    if (real_color.green != color.green)
    {
        TEST_FAIL ("real_color.green = %d, should be %d", real_color.green, color.green);
    }
    if (real_color.blue != color.blue)
    {
        TEST_FAIL ("real_color.blue = %d, should be %d", real_color.blue, color.blue);
    }
    
    gtk_color_selection_get_previous_color (GTK_COLOR_SELECTION (widget), 
                                            &real_prev_color);
    if (real_prev_color.red != color.red)
    {
        TEST_FAIL ("real_prev_color.red = %d, should be %d", 
                   real_prev_color.red, color.red);
    }
    if (real_prev_color.green != color.green)
    {
        TEST_FAIL ("real_prev_color.green = %d, should be %d", 
                   real_prev_color.green, color.green);
    }
    if (real_prev_color.blue != color.blue)
    {
        TEST_FAIL ("real_prev_color.blue = %d, should be %d", 
                   real_prev_color.blue, color.blue);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_current_color
 * Params: GtkColorSelection *colorsel, GdkColor *color 
 * Returns: void
 * Assertion: The first time this is called, it will also set the original color to be color too.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void
 * 
 * Name: gtk_color_selection_set_previous_color
 * Params: GtkColorSelection *colorsel, GdkColor *color 
 * Returns: void
 * Assertion: Calling gtk_color_selection_set_current_color() will also set this color the first time it is called.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void  
 */
static void test_purpose_29()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor real_color;
    GdkColor real_prev_color;
    
    #define RED 30001
    #define GREEN 30001
    #define BLUE 30001
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    
    gtk_color_selection_set_current_color (GTK_COLOR_SELECTION (widget), &color);
    
    gtk_color_selection_get_current_color (GTK_COLOR_SELECTION (widget), &real_color);
    if (real_color.red != color.red)
    {
        TEST_FAIL ("real_color.red = %d, should be %d", real_color.red, color.red);
    }
    if (real_color.green != color.green)
    {
        TEST_FAIL ("real_color.green = %d, should be %d", real_color.green, color.green);
    }
    if (real_color.blue != color.blue)
    {
        TEST_FAIL ("real_color.blue = %d, should be %d", real_color.blue, color.blue);
    }
    
    gtk_color_selection_get_previous_color (GTK_COLOR_SELECTION (widget), 
                                            &real_prev_color);
    if (real_prev_color.red != color.red)
    {
        TEST_FAIL ("real_prev_color.red = %d, should be %d", 
                   real_prev_color.red, color.red);
    }
    if (real_prev_color.green != color.green)
    {
        TEST_FAIL ("real_prev_color.green = %d, should be %d", 
                   real_prev_color.green, color.green);
    }
    if (real_prev_color.blue != color.blue)
    {
        TEST_FAIL ("real_prev_color.blue = %d, should be %d", 
                   real_prev_color.blue, color.blue);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_current_color
 * Params: GtkColorSelection *colorsel, GdkColor *color 
 * Returns: void
 * Assertion: The first time this is called, it will also set the original color to be color too.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void
 * 
 * Name: gtk_color_selection_set_previous_color
 * Params: GtkColorSelection *colorsel, GdkColor *color 
 * Returns: void
 * Assertion: Calling gtk_color_selection_set_current_color() will also set this color the first time it is called.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void  
 */
static void test_purpose_30()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor real_color;
    GdkColor real_prev_color;
    
    #define RED 65535
    #define GREEN 65535
    #define BLUE 65535
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    
    gtk_color_selection_set_current_color (GTK_COLOR_SELECTION (widget), &color);
    
    gtk_color_selection_get_current_color (GTK_COLOR_SELECTION (widget), &real_color);
    if (real_color.red != color.red)
    {
        TEST_FAIL ("real_color.red = %d, should be %d", real_color.red, color.red);
    }
    if (real_color.green != color.green)
    {
        TEST_FAIL ("real_color.green = %d, should be %d", real_color.green, color.green);
    }
    if (real_color.blue != color.blue)
    {
        TEST_FAIL ("real_color.blue = %d, should be %d", real_color.blue, color.blue);
    }
    
    gtk_color_selection_get_previous_color (GTK_COLOR_SELECTION (widget), 
                                            &real_prev_color);
    if (real_prev_color.red != color.red)
    {
        TEST_FAIL ("real_prev_color.red = %d, should be %d", 
                   real_prev_color.red, color.red);
    }
    if (real_prev_color.green != color.green)
    {
        TEST_FAIL ("real_prev_color.green = %d, should be %d", 
                   real_prev_color.green, color.green);
    }
    if (real_prev_color.blue != color.blue)
    {
        TEST_FAIL ("real_prev_color.blue = %d, should be %d", 
                   real_prev_color.blue, color.blue);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_previous_color
 * Params: GtkColorSelection *colorsel, GdkColor *color 
 * Returns: void
 * Assertion: Sets the 'previous' color to be color.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void
 * 
 * Name: gtk_color_selection_get_previous_color
 * Params: GtkColorSelection *colorsel, GdkColor *color
 * Returns: void
 * Assertion: Fills color in with the original color value.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void  
 */
static void test_purpose_31()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor real_color;
    
    #define RED 0
    #define GREEN 0
    #define BLUE 0
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    
    gtk_color_selection_set_previous_color (GTK_COLOR_SELECTION (widget), &color);
    
    gtk_color_selection_get_previous_color (GTK_COLOR_SELECTION (widget), &real_color);
    if (real_color.red != color.red)
    {
        TEST_FAIL ("real_color.red = %d, should be %d", real_color.red, color.red);
    }
    if (real_color.green != color.green)
    {
        TEST_FAIL ("real_color.green = %d, should be %d", real_color.green, color.green);
    }
    if (real_color.blue != color.blue)
    {
        TEST_FAIL ("real_color.blue = %d, should be %d", real_color.blue, color.blue);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_previous_color
 * Params: GtkColorSelection *colorsel, GdkColor *color 
 * Returns: void
 * Assertion: Sets the 'previous' color to be color.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void
 * 
 * Name: gtk_color_selection_get_previous_color
 * Params: GtkColorSelection *colorsel, GdkColor *color
 * Returns: void
 * Assertion: Fills color in with the original color value.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void  
 */
static void test_purpose_32()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor real_color;
    
    #define RED 1
    #define GREEN 1
    #define BLUE 1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    
    gtk_color_selection_set_previous_color (GTK_COLOR_SELECTION (widget), &color);
    
    gtk_color_selection_get_previous_color (GTK_COLOR_SELECTION (widget), &real_color);
    if (real_color.red != color.red)
    {
        TEST_FAIL ("real_color.red = %d, should be %d", real_color.red, color.red);
    }
    if (real_color.green != color.green)
    {
        TEST_FAIL ("real_color.green = %d, should be %d", real_color.green, color.green);
    }
    if (real_color.blue != color.blue)
    {
        TEST_FAIL ("real_color.blue = %d, should be %d", real_color.blue, color.blue);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_previous_color
 * Params: GtkColorSelection *colorsel, GdkColor *color 
 * Returns: void
 * Assertion: Sets the 'previous' color to be color.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void
 * 
 * Name: gtk_color_selection_get_previous_color
 * Params: GtkColorSelection *colorsel, GdkColor *color
 * Returns: void
 * Assertion: Fills color in with the original color value.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void  
 */
static void test_purpose_33()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor real_color;
    
    #define RED 20001
    #define GREEN 20001
    #define BLUE 20001
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    
    gtk_color_selection_set_previous_color (GTK_COLOR_SELECTION (widget), &color);
    
    gtk_color_selection_get_previous_color (GTK_COLOR_SELECTION (widget), &real_color);
    if (real_color.red != color.red)
    {
        TEST_FAIL ("real_color.red = %d, should be %d", real_color.red, color.red);
    }
    if (real_color.green != color.green)
    {
        TEST_FAIL ("real_color.green = %d, should be %d", real_color.green, color.green);
    }
    if (real_color.blue != color.blue)
    {
        TEST_FAIL ("real_color.blue = %d, should be %d", real_color.blue, color.blue);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_previous_color
 * Params: GtkColorSelection *colorsel, GdkColor *color 
 * Returns: void
 * Assertion: Sets the 'previous' color to be color.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void
 * 
 * Name: gtk_color_selection_get_previous_color
 * Params: GtkColorSelection *colorsel, GdkColor *color
 * Returns: void
 * Assertion: Fills color in with the original color value.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void  
 */
static void test_purpose_34()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor real_color;
    
    #define RED 30001
    #define GREEN 30001
    #define BLUE 30001
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    
    gtk_color_selection_set_previous_color (GTK_COLOR_SELECTION (widget), &color);
    
    gtk_color_selection_get_previous_color (GTK_COLOR_SELECTION (widget), &real_color);
    if (real_color.red != color.red)
    {
        TEST_FAIL ("real_color.red = %d, should be %d", real_color.red, color.red);
    }
    if (real_color.green != color.green)
    {
        TEST_FAIL ("real_color.green = %d, should be %d", real_color.green, color.green);
    }
    if (real_color.blue != color.blue)
    {
        TEST_FAIL ("real_color.blue = %d, should be %d", real_color.blue, color.blue);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_previous_color
 * Params: GtkColorSelection *colorsel, GdkColor *color 
 * Returns: void
 * Assertion: Sets the 'previous' color to be color.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void
 * 
 * Name: gtk_color_selection_get_previous_color
 * Params: GtkColorSelection *colorsel, GdkColor *color
 * Returns: void
 * Assertion: Fills color in with the original color value.
 * Params Values: a newly created GtkColorSelection*, GdkColor*
 * Expected: void  
 */
static void test_purpose_35()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor real_color;
    
    #define RED 65535
    #define GREEN 65535
    #define BLUE 65535
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    
    gtk_color_selection_set_previous_color (GTK_COLOR_SELECTION (widget), &color);
    
    gtk_color_selection_get_previous_color (GTK_COLOR_SELECTION (widget), &real_color);
    if (real_color.red != color.red)
    {
        TEST_FAIL ("real_color.red = %d, should be %d", real_color.red, color.red);
    }
    if (real_color.green != color.green)
    {
        TEST_FAIL ("real_color.green = %d, should be %d", real_color.green, color.green);
    }
    if (real_color.blue != color.blue)
    {
        TEST_FAIL ("real_color.blue = %d, should be %d", real_color.blue, color.blue);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_palette_from_string 
 * Params: const gchar *str,GdkColor **colors,gint *n_colors
 * Returns: gboolean
 * Assertion: Parses a color palette string; the string is a colon-separated list of color names readable by gdk_color_parse().
 * Params Values: gchar*,GdkColor**,gint*
 * Expected: gboolean
 * 
 * Name: gtk_color_selection_palette_to_string 
 * Params: const GdkColor *colors,gint n_colors
 * Returns: gchar*
 * Assertion: Encodes a palette as a string, useful for persistent storage.
 * Params Values: GdkColor*,1
 * Expected: gchar*  
 */
static void test_purpose_36()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor* col;
    gchar* str;
    gint num;
    gboolean res = FALSE;
    
    #define RED 0
    #define GREEN 0
    #define BLUE 0
    #define NUM 1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    num = NUM;
    
    str = gtk_color_selection_palette_to_string (&color,num);
    col = &color;
    res = gtk_color_selection_palette_from_string (str,&col,&num);
    if (!res) 
    {
        TEST_FAIL ("Palette wasn't successfully parsed",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_palette_from_string 
 * Params: const gchar *str,GdkColor **colors,gint *n_colors
 * Returns: gboolean
 * Assertion: Parses a color palette string; the string is a colon-separated list of color names readable by gdk_color_parse().
 * Params Values: gchar*,GdkColor**,gint*
 * Expected: gboolean
 * 
 * Name: gtk_color_selection_palette_to_string 
 * Params: const GdkColor *colors,gint n_colors
 * Returns: gchar*
 * Assertion: Encodes a palette as a string, useful for persistent storage.
 * Params Values: GdkColor*,100
 * Expected: gchar*  
 */
static void test_purpose_37()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor* col;
    gchar* str;
    gint num;
    gboolean res = FALSE;
    
    #define RED 0
    #define GREEN 0
    #define BLUE 0
    #define NUM 100
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    num = NUM;
    
    str = gtk_color_selection_palette_to_string (&color,num);
    col = &color;
    res = gtk_color_selection_palette_from_string (str,&col,&num);
    if (!res) 
    {
        TEST_FAIL ("Palette wasn't successfully parsed",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_palette_from_string 
 * Params: const gchar *str,GdkColor **colors,gint *n_colors
 * Returns: gboolean
 * Assertion: Parses a color palette string; the string is a colon-separated list of color names readable by gdk_color_parse().
 * Params Values: gchar*,GdkColor**,gint*
 * Expected: gboolean
 * 
 * Name: gtk_color_selection_palette_to_string 
 * Params: const GdkColor *colors,gint n_colors
 * Returns: gchar*
 * Assertion: Encodes a palette as a string, useful for persistent storage.
 * Params Values: GdkColor*,1
 * Expected: gchar*  
 */
static void test_purpose_38()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor* col;
    gchar* str;
    gint num;
    gboolean res = FALSE;
    
    #define RED 1
    #define GREEN 1
    #define BLUE 1
    #define NUM 1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    num = NUM;
    
    str = gtk_color_selection_palette_to_string (&color,num);
    col = &color;
    res = gtk_color_selection_palette_from_string (str,&col,&num);
    if (!res) 
    {
        TEST_FAIL ("Palette wasn't successfully parsed",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_palette_from_string 
 * Params: const gchar *str,GdkColor **colors,gint *n_colors
 * Returns: gboolean
 * Assertion: Parses a color palette string; the string is a colon-separated list of color names readable by gdk_color_parse().
 * Params Values: gchar*,GdkColor**,gint*
 * Expected: gboolean
 * 
 * Name: gtk_color_selection_palette_to_string 
 * Params: const GdkColor *colors,gint n_colors
 * Returns: gchar*
 * Assertion: Encodes a palette as a string, useful for persistent storage.
 * Params Values: GdkColor*,100
 * Expected: gchar*  
 */
static void test_purpose_39()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor* col;
    gchar* str;
    gint num;
    gboolean res = FALSE;
    
    #define RED 1
    #define GREEN 1
    #define BLUE 1
    #define NUM 100
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    num = NUM;
    
    str = gtk_color_selection_palette_to_string (&color,num);
    col = &color;
    res = gtk_color_selection_palette_from_string (str,&col,&num);
    if (!res) 
    {
        TEST_FAIL ("Palette wasn't successfully parsed",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_palette_from_string 
 * Params: const gchar *str,GdkColor **colors,gint *n_colors
 * Returns: gboolean
 * Assertion: Parses a color palette string; the string is a colon-separated list of color names readable by gdk_color_parse().
 * Params Values: gchar*,GdkColor**,gint*
 * Expected: gboolean
 * 
 * Name: gtk_color_selection_palette_to_string 
 * Params: const GdkColor *colors,gint n_colors
 * Returns: gchar*
 * Assertion: Encodes a palette as a string, useful for persistent storage.
 * Params Values: GdkColor*,1
 * Expected: gchar*  
 */
static void test_purpose_40()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor* col;
    gchar* str;
    gint num;
    gboolean res = FALSE;
    
    #define RED 20001
    #define GREEN 20001
    #define BLUE 20001
    #define NUM 1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    num = NUM;
    
    str = gtk_color_selection_palette_to_string (&color,num);
    col = &color;
    res = gtk_color_selection_palette_from_string (str,&col,&num);
    if (!res) 
    {
        TEST_FAIL ("Palette wasn't successfully parsed",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_palette_from_string 
 * Params: const gchar *str,GdkColor **colors,gint *n_colors
 * Returns: gboolean
 * Assertion: Parses a color palette string; the string is a colon-separated list of color names readable by gdk_color_parse().
 * Params Values: gchar*,GdkColor**,gint*
 * Expected: gboolean
 * 
 * Name: gtk_color_selection_palette_to_string 
 * Params: const GdkColor *colors,gint n_colors
 * Returns: gchar*
 * Assertion: Encodes a palette as a string, useful for persistent storage.
 * Params Values: GdkColor*,100
 * Expected: gchar*  
 */
static void test_purpose_41()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor* col;
    gchar* str;
    gint num;
    gboolean res = FALSE;
    
    #define RED 20001
    #define GREEN 20001
    #define BLUE 20001
    #define NUM 100
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    num = NUM;
    
    str = gtk_color_selection_palette_to_string (&color,num);
    col = &color;
    res = gtk_color_selection_palette_from_string (str,&col,&num);
    if (!res) 
    {
        TEST_FAIL ("Palette wasn't successfully parsed",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_palette_from_string 
 * Params: const gchar *str,GdkColor **colors,gint *n_colors
 * Returns: gboolean
 * Assertion: Parses a color palette string; the string is a colon-separated list of color names readable by gdk_color_parse().
 * Params Values: gchar*,GdkColor**,gint*
 * Expected: gboolean
 * 
 * Name: gtk_color_selection_palette_to_string 
 * Params: const GdkColor *colors,gint n_colors
 * Returns: gchar*
 * Assertion: Encodes a palette as a string, useful for persistent storage.
 * Params Values: GdkColor*,1
 * Expected: gchar*  
 */
static void test_purpose_42()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor* col;
    gchar* str;
    gint num;
    gboolean res = FALSE;
    
    #define RED 30001
    #define GREEN 30001
    #define BLUE 30001
    #define NUM 1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    num = NUM;
    
    str = gtk_color_selection_palette_to_string (&color,num);
    col = &color;
    res = gtk_color_selection_palette_from_string (str,&col,&num);
    if (!res) 
    {
        TEST_FAIL ("Palette wasn't successfully parsed",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_palette_from_string 
 * Params: const gchar *str,GdkColor **colors,gint *n_colors
 * Returns: gboolean
 * Assertion: Parses a color palette string; the string is a colon-separated list of color names readable by gdk_color_parse().
 * Params Values: gchar*,GdkColor**,gint*
 * Expected: gboolean
 * 
 * Name: gtk_color_selection_palette_to_string 
 * Params: const GdkColor *colors,gint n_colors
 * Returns: gchar*
 * Assertion: Encodes a palette as a string, useful for persistent storage.
 * Params Values: GdkColor*,100
 * Expected: gchar*  
 */
static void test_purpose_43()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor* col;
    gchar* str;
    gint num;
    gboolean res = FALSE;
    
    #define RED 30001
    #define GREEN 30001
    #define BLUE 30001
    #define NUM 100
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    num = NUM;
    
    str = gtk_color_selection_palette_to_string (&color,num);
    col = &color;
    res = gtk_color_selection_palette_from_string (str,&col,&num);
    if (!res) 
    {
        TEST_FAIL ("Palette wasn't successfully parsed",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_palette_from_string 
 * Params: const gchar *str,GdkColor **colors,gint *n_colors
 * Returns: gboolean
 * Assertion: Parses a color palette string; the string is a colon-separated list of color names readable by gdk_color_parse().
 * Params Values: gchar*,GdkColor**,gint*
 * Expected: gboolean
 * 
 * Name: gtk_color_selection_palette_to_string 
 * Params: const GdkColor *colors,gint n_colors
 * Returns: gchar*
 * Assertion: Encodes a palette as a string, useful for persistent storage.
 * Params Values: GdkColor*,1
 * Expected: gchar*  
 */
static void test_purpose_44()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor* col;
    gchar* str;
    gint num;
    gboolean res = FALSE;
    
    #define RED 65535
    #define GREEN 65535
    #define BLUE 65535
    #define NUM 1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    num = NUM;
    
    str = gtk_color_selection_palette_to_string (&color,num);
    col = &color;
    res = gtk_color_selection_palette_from_string (str,&col,&num);
    if (!res) 
    {
        TEST_FAIL ("Palette wasn't successfully parsed",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_palette_from_string 
 * Params: const gchar *str,GdkColor **colors,gint *n_colors
 * Returns: gboolean
 * Assertion: Parses a color palette string; the string is a colon-separated list of color names readable by gdk_color_parse().
 * Params Values: gchar*,GdkColor**,gint*
 * Expected: gboolean
 * 
 * Name: gtk_color_selection_palette_to_string 
 * Params: const GdkColor *colors,gint n_colors
 * Returns: gchar*
 * Assertion: Encodes a palette as a string, useful for persistent storage.
 * Params Values: GdkColor*,100
 * Expected: gchar*  
 */
static void test_purpose_45()
{
    GtkWidget *widget;
    GdkColor color;
    GdkColor* col;
    gchar* str;
    gint num;
    gboolean res = FALSE;
    
    #define RED 65535
    #define GREEN 65535
    #define BLUE 65535
    #define NUM 100
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    color.pixel = 0;
    color.red = RED;
    color.green = GREEN;
    color.blue = BLUE;
    num = NUM;
    
    str = gtk_color_selection_palette_to_string (&color,num);
    col = &color;
    res = gtk_color_selection_palette_from_string (str,&col,&num);
    if (!res) 
    {
        TEST_FAIL ("Palette wasn't successfully parsed",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RED
    #undef GREEN
    #undef BLUE
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_is_adjusting
 * Params: void
 * Returns: GtkWidget*
 * Assertion: Gets the current state of the colorsel.
 * Params Values: void
 * Expected: FALSE  
 */
static void test_purpose_46()
{
    GtkWidget *widget;
    gboolean is_adjusting;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    is_adjusting = gtk_color_selection_is_adjusting (GTK_COLOR_SELECTION (widget));
    if (is_adjusting)
    {
        TEST_FAIL ("is_adjusting is TRUE, should be FALSE", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_change_palette_with_screen_hook
 * Params: GtkColorSelectionChangePaletteFunc func
 * Returns: GtkColorSelectionChangePaletteFunc
 * Assertion: Installs a global function to be called whenever the user tries to modify the palette in a color selection. 
 * Params Values: &global_change_palette_hook_1 in the first call, global_change_palette_hook_2 in the second call
 * Expected: global_change_palette_hook_1 in the second call  
 */
static void test_purpose_47()
{
    GtkWidget *widget;
    GtkColorSelectionChangePaletteFunc old_func;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_change_palette_with_screen_hook (global_change_palette_hook_1);
    old_func = gtk_color_selection_set_change_palette_with_screen_hook (global_change_palette_hook_2);
    
    if (old_func != global_change_palette_hook_1)
    {
        TEST_FAIL ("old_func != global_change_palette_hook_1", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_color_selection_set_change_palette_with_screen_hook
 * Params: GtkColorSelectionChangePaletteWithScreenFunc func
 * Returns: GtkColorSelectionChangePaletteFunc func
 * Assertion: Installs a global function to be called whenever the user tries to modify the palette in a color selection.
 * Params Values: &global_change_palette_with_screen_hook_1 in the first call, global_change_palette_with_screen_hook_2 in the second call
 * Expected: global_change_palette_with_screen_hook_1 in the second call  
 */
static void test_purpose_48()
{
    GtkWidget *widget;
    GtkColorSelectionChangePaletteWithScreenFunc old_func;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_color_selection_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_COLOR_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_color_selection_set_change_palette_with_screen_hook 
        (global_change_palette_with_screen_hook_1);
    old_func = gtk_color_selection_set_change_palette_with_screen_hook 
        (global_change_palette_with_screen_hook_2);
    
    if (old_func != global_change_palette_with_screen_hook_1)
    {
        TEST_FAIL ("old_func != global_change_palette_with_screen_hook_1", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkColorSelection ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {NULL,0}
};
