/*
 * GtkDialog methods tests
 * Testing GtkDialog methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
#include "librobot.h"

static gboolean result;
static gint response_id;


void  
global_result (GtkWidget *widget, GdkEvent *event, gpointer data)
{
    result = TRUE;
}

void  
global_delete_event (GtkWidget *widget, GdkEvent *event, gpointer data)
{
    if (!GTK_WIDGET_REALIZED (widget)) return;
    robot_delete_event (GTK_WIDGET (data));
}  

void  
global_response (GtkWidget *widget, gint arg1, gpointer data)
{
    if (arg1 == response_id)
    {
        result = TRUE;
    }
}  

void  
global_activate (GtkWidget *widget, GdkEvent *event, gpointer data)
{
    if (!GTK_WIDGET_REALIZED (widget)) return;
    robot_activate (GTK_WIDGET (data));
}  

void  
global_click (GtkWidget *widget, GdkEvent *event, gpointer data)
{
    if (!GTK_WIDGET_REALIZED (widget)) return;
    robot_activate (GTK_WIDGET (data));
}

void  
global_check_response (GtkWidget *widget, gpointer data)
{
    gint* p = g_object_get_data (GTK_OBJECT (widget), "gtk-dialog-response-data");

    if (!p)
    {
        p = g_new (gint, 1);
        g_object_set_data_full (GTK_OBJECT (widget), "gtk-dialog-response-data", p, g_free);
    }
    if (p && *p == response_id)
    {
        *((GtkWidget**)data) = widget;
    }
}  

void  
global_check_sensitive (GtkWidget *widget, gpointer data)
{
    gint* count = data;
    gint* p = g_object_get_data (GTK_OBJECT (widget), "gtk-dialog-response-data");

    if (!p)
    {
        p = g_new (gint, 1);
        g_object_set_data_full (GTK_OBJECT (widget), "gtk-dialog-response-data", p, g_free);
    }
    if (p && *p == response_id)
    {
        if (GTK_WIDGET_IS_SENSITIVE (widget) == result)
        {
            (*count)++;
        }
    }
}  

void  
global_press_return (GtkWidget *widget, GdkEvent *event, gpointer data)
{
    if (!GTK_WIDGET_REALIZED (widget)) return;
    
    robot_key_press_event (widget, GDK_Return, 0);
    robot_key_release_event (widget, GDK_Return, 0);
}  

void  
global_destroy_widget (GtkWidget *widget, GdkEvent *event, gpointer data)
{
    if (!GTK_WIDGET_REALIZED (widget) ) return;
    robot_destroy_event (GTK_WIDGET (data));
}  


/*
 * Name:   gtk_dialog_new
 * Params: void
 * Returns: GtkDialog* 
 * Assertion: Creates a new dialog box.
 * Params Values: void
 * Expected: GtkDialog*  
 */
static void test_purpose_1()
{
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_dialog_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_dialog_new_with_buttons
 * Params: const gchar *title, GtkWindow *parent, GtkDialogFlags flags, const gchar *first_button_text
 * Returns: GtkDialog* 
 * Assertion: Creates a new GtkDialog with title title (or NULL for the default title; see gtk_window_set_title()) and transient parent parent (or NULL for none; see gtk_window_set_transient_for()). 
 * Params Values: void
 * Expected: GtkDialog*
 * 
 * Name:   gtk_dialog_new_with_buttons
 * Params: const gchar *title, GtkWindow *parent, GtkDialogFlags flags, const gchar *first_button_text
 * Returns: GtkDialog* 
 * Assertion:If the user clicks one of these dialog buttons, GtkDialog will emit the "response" signal with the corresponding response ID. 
 * Params Values: void
 * Expected: GtkDialog*  
 */
static void test_purpose_2()
{
    #define  TITLE    "" 
    #define  PARENT   NULL 
    #define  FLAGS    GTK_DIALOG_DESTROY_WITH_PARENT 
    #define  BUTTONS  "Button 1", 1000, "Button 2", 1001, "Button 3", 1002
    #define  RESPONSE_ID  1000
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    response_id = RESPONSE_ID;
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    
    } else {
    
        parent_window = NULL;
    }
    
    widget = gtk_dialog_new_with_buttons (TITLE, parent_window, FLAGS, BUTTONS, NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_container_foreach (GTK_CONTAINER (GTK_DIALOG (widget)->action_area), global_check_response, &button);
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_click), button);
    
    if (gtk_dialog_run (GTK_DIALOG (widget)) != RESPONSE_ID)
    {
        TEST_FAIL ("gtk_dialog_run () should return %i", RESPONSE_ID);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  TITLE    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  RESPONSE_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_dialog_new_with_buttons
 * Params: const gchar *title, GtkWindow *parent, GtkDialogFlags flags, const gchar *first_button_text
 * Returns: GtkDialog* 
 * Assertion: Creates a new GtkDialog with title title (or NULL for the default title; see gtk_window_set_title()) and transient parent parent (or NULL for none; see gtk_window_set_transient_for()). 
 * Params Values: void
 * Expected: GtkDialog*
 * 
 * Name:   gtk_dialog_new_with_buttons
 * Params: const gchar *title, GtkWindow *parent, GtkDialogFlags flags, const gchar *first_button_text
 * Returns: GtkDialog* 
 * Assertion:If the user clicks one of these dialog buttons, GtkDialog will emit the "response" signal with the corresponding response ID. 
 * Params Values: void
 * Expected: GtkDialog*  
 */
static void test_purpose_3()
{
    #define  TITLE    "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890" 
    #define  PARENT   gtk_window_new (GTK_WINDOW_TOPLEVEL) 
    #define  FLAGS    GTK_DIALOG_DESTROY_WITH_PARENT  
    #define  BUTTONS  "B1", 1000, "B2", 10, "B3", 20
    #define  RESPONSE_ID  10
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    response_id = RESPONSE_ID;
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    
    } else {
    
        parent_window = NULL;
    }
    
    widget = gtk_dialog_new_with_buttons (TITLE, parent_window, FLAGS, BUTTONS, NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_container_foreach (GTK_CONTAINER (GTK_DIALOG (widget)->action_area), global_check_response, &button);
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_click), button);
    
    if (gtk_dialog_run (GTK_DIALOG (widget)) != RESPONSE_ID)
    {
        TEST_FAIL ("gtk_dialog_run () should return %i", RESPONSE_ID);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  TITLE    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  RESPONSE_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_dialog_new_with_buttons
 * Params: const gchar *title, GtkWindow *parent, GtkDialogFlags flags, const gchar *first_button_text
 * Returns: GtkDialog* 
 * Assertion: Creates a new GtkDialog with title title (or NULL for the default title; see gtk_window_set_title()) and transient parent parent (or NULL for none; see gtk_window_set_transient_for()). 
 * Params Values: void
 * Expected: GtkDialog*
 * 
 * Name:   gtk_dialog_new_with_buttons
 * Params: const gchar *title, GtkWindow *parent, GtkDialogFlags flags, const gchar *first_button_text
 * Returns: GtkDialog* 
 * Assertion:If the user clicks one of these dialog buttons, GtkDialog will emit the "response" signal with the corresponding response ID. 
 * Params Values: void
 * Expected: GtkDialog*  
 */
static void test_purpose_4()
{
    #define  TITLE    "Title" 
    #define  PARENT   gtk_window_new (GTK_WINDOW_TOPLEVEL) 
    #define  FLAGS    GTK_DIALOG_DESTROY_WITH_PARENT 
    #define  BUTTONS  "B1", 1001, "\t\n", 1001, "B3", 1002
    #define  RESPONSE_ID  1001
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    response_id = RESPONSE_ID;
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    
    } else {
    
        parent_window = NULL;
    }
    
    widget = gtk_dialog_new_with_buttons (TITLE, parent_window, FLAGS, BUTTONS, NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_container_foreach (GTK_CONTAINER (GTK_DIALOG (widget)->action_area), global_check_response, &button);
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_click), button);
    
    if (gtk_dialog_run (GTK_DIALOG (widget)) != RESPONSE_ID)
    {
        TEST_FAIL ("gtk_dialog_run () should return %i", RESPONSE_ID);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  TITLE    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  RESPONSE_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_dialog_new_with_buttons
 * Params: const gchar *title, GtkWindow *parent, GtkDialogFlags flags, const gchar *first_button_text
 * Returns: GtkDialog* 
 * Assertion: Creates a new GtkDialog with title title (or NULL for the default title; see gtk_window_set_title()) and transient parent parent (or NULL for none; see gtk_window_set_transient_for()). 
 * Params Values: void
 * Expected: GtkDialog*
 * 
 * Name:   gtk_dialog_new_with_buttons
 * Params: const gchar *title, GtkWindow *parent, GtkDialogFlags flags, const gchar *first_button_text
 * Returns: GtkDialog* 
 * Assertion:If the user clicks one of these dialog buttons, GtkDialog will emit the "response" signal with the corresponding response ID. 
 * Params Values: void
 * Expected: GtkDialog*  
 */
static void test_purpose_5()
{
    #define  TITLE    "Title"  
    #define  PARENT   gtk_window_new (GTK_WINDOW_TOPLEVEL) 
    #define  FLAGS    GTK_DIALOG_DESTROY_WITH_PARENT 
    #define  BUTTONS  "B1", 100, "B2", 101, "!@#$%^&*()_+|~=\";:'?<>`/" , 102
    #define  RESPONSE_ID  102
    
    GtkWidget* widget;
    GtkWidget* button;
    GtkWindow* real_parent = NULL;
    GtkWindow* parent_window = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    response_id = RESPONSE_ID;
    if (PARENT)
    {
        parent_window = GTK_WINDOW(PARENT);
    
    } else {
    
        parent_window = NULL;
    }
    
    widget = gtk_dialog_new_with_buttons (TITLE, parent_window, FLAGS, BUTTONS, NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_DIALOG (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_container_foreach (GTK_CONTAINER (GTK_DIALOG (widget)->action_area), global_check_response, &button);
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_click), button);
    
    if (gtk_dialog_run (GTK_DIALOG (widget)) != RESPONSE_ID)
    {
        TEST_FAIL ("gtk_dialog_run () should return %i", RESPONSE_ID);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  TITLE    
    #undef  PARENT  
    #undef  FLAGS   
    #undef  BUTTONS 
    #undef  RESPONSE_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_dialog_get_has_separator
 * Params:  GtkDialog* 
 * Returns: gboolean
 * Assertion: Accessor for whether the dialog has a separator.
 * Params Values: GtkDialog* 
 * Expected: FALSE  
 */
static void test_purpose_6()
{
    #define HAS_SEPARATOR FALSE
    
    GtkWidget* widget;
    gboolean has_separator;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_dialog_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "has-separator", (gboolean) HAS_SEPARATOR, NULL);
    if (HAS_SEPARATOR != gtk_dialog_get_has_separator (GTK_DIALOG (widget)))
    {
        TEST_FAIL ("'has-separator' arg not set correctly", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef HAS_SEPARATOR 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_dialog_get_has_separator
 * Params:  GtkDialog* 
 * Returns: gboolean
 * Assertion: Accessor for whether the dialog has a separator.
 * Params Values: GtkDialog* 
 * Expected: TRUE  
 */
static void test_purpose_7()
{
    #define HAS_SEPARATOR TRUE
    
    GtkWidget* widget;
    gboolean has_separator;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_dialog_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "has-separator", (gboolean) HAS_SEPARATOR, NULL);
    if (HAS_SEPARATOR != gtk_dialog_get_has_separator (GTK_DIALOG (widget)))
    {
        TEST_FAIL ("'has-separator' arg not set correctly", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef HAS_SEPARATOR 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_dialog_set_has_separator
 * Params:  GtkDialog*, gboolean setting
 * Returns: void
 * Assertion: Sets whether the dialog has a separator above the buttons.
 * Params Values: GtkDialog* , FALSE
 * Expected: void
 * 
 * Name:  gtk_dialog_set_has_separator
 * Params:  GtkDialog*, gboolean setting
 * Returns: void
 * Assertion: TRUE by default.
 * Params Values: GtkDialog* , FALSE
 * Expected: void  
 */
static void test_purpose_8()
{
    #define HAS_SEPARATOR FALSE
    
    GtkWidget* widget;
    gboolean has_separator;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_dialog_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    /* see LSB bug 3044 - default has changed to FALSE
    g_object_get (GTK_OBJECT (widget), "has-separator", &has_separator, NULL);
    if (!has_separator)
    {
        TEST_FAIL ("'has-separator' is FALSE", NULL);
    }
    */
    
    gtk_dialog_set_has_separator (GTK_DIALOG (widget), HAS_SEPARATOR);
    g_object_get (GTK_OBJECT (widget), "has-separator", &has_separator, NULL);
    if (HAS_SEPARATOR != has_separator)
    {
        TEST_FAIL ("'has-separator' arg not got correctly", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef HAS_SEPARATOR 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_dialog_set_has_separator
 * Params:  GtkDialog*, gboolean setting
 * Returns: void
 * Assertion: Sets whether the dialog has a separator above the buttons.
 * Params Values: GtkDialog* , TRUE
 * Expected: void
 * 
 * Name:  gtk_dialog_set_has_separator
 * Params:  GtkDialog*, gboolean setting
 * Returns: void
 * Assertion: TRUE by default.
 * Params Values: GtkDialog* , TRUE
 * Expected: void  
 */
static void test_purpose_9()
{
    #define HAS_SEPARATOR TRUE
    
    GtkWidget* widget;
    gboolean has_separator;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_dialog_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    /* see LSB bug 3044 - default has changed to FALSE
    g_object_get (GTK_OBJECT (widget), "has-separator", &has_separator, NULL);
    if (!has_separator)
    {
        TEST_FAIL ("'has-separator' is FALSE", NULL);
    }
    */
    
    gtk_dialog_set_has_separator (GTK_DIALOG (widget), HAS_SEPARATOR);
    g_object_get (GTK_OBJECT (widget), "has-separator", &has_separator, NULL);
    if (HAS_SEPARATOR != has_separator)
    {
        TEST_FAIL ("'has-separator' arg not got correctly", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef HAS_SEPARATOR 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_dialog_set_response_sensitive
 * Params:  GtkDialog *dialog, gint response_id, gboolean setting
 * Returns: void
 * Assertion: Calls gtk_widget_set_sensitive (widget, setting) for each widget in the dialog's action area with the given response_id.'
 * Params Values: GtkDialog *dialog, gint response_id, gboolean setting
 * Expected: void  
 */
static void test_purpose_10()
{
    #define BUTTONS "Button 1", 1, "Button 2", 1, "Button 3", 2, "Button 4", 2, "Button 5", 1
    #define SENSITIVE FALSE
    #define RESPONSE_ID 1
    #define COUNT 3
    
    GtkWidget* widget;
    gboolean sensitive;
    gint count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    response_id = RESPONSE_ID;
    result = SENSITIVE;
    count = 0;
    
    widget = gtk_dialog_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_dialog_add_buttons (GTK_DIALOG (widget), BUTTONS, NULL);
    
    gtk_dialog_set_response_sensitive (GTK_DIALOG (widget), RESPONSE_ID, SENSITIVE);
    
    gtk_container_foreach (GTK_CONTAINER (GTK_DIALOG (widget)->action_area), global_check_sensitive, &count);
    
    if (count != COUNT)
    {
        TEST_FAIL ("Test fails count = %i", count);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef BUTTONS 
    #undef SENSITIVE 
    #undef RESPONSE_ID
    #undef COUNT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_dialog_set_response_sensitive
 * Params:  GtkDialog *dialog, gint response_id, gboolean setting
 * Returns: void
 * Assertion: Calls gtk_widget_set_sensitive (widget, setting) for each widget in the dialog's action area with the given response_id.'
 * Params Values: GtkDialog *dialog, gint response_id, gboolean setting
 * Expected: void  
 */
static void test_purpose_11()
{
    #define BUTTONS "Button 1", 1, "Button 2", 1, "Button 3", 2, "Button 4", 2, "Button 5", 5
    #define SENSITIVE TRUE
    #define RESPONSE_ID 1
    #define COUNT 2
    
    GtkWidget* widget;
    gboolean sensitive;
    gint count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    response_id = RESPONSE_ID;
    result = SENSITIVE;
    count = 0;
    
    widget = gtk_dialog_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_dialog_add_buttons (GTK_DIALOG (widget), BUTTONS, NULL);
    
    gtk_dialog_set_response_sensitive (GTK_DIALOG (widget), RESPONSE_ID, SENSITIVE);
    
    gtk_container_foreach (GTK_CONTAINER (GTK_DIALOG (widget)->action_area), global_check_sensitive, &count);
    
    if (count != COUNT)
    {
        TEST_FAIL ("Test fails count = %i", count);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef BUTTONS 
    #undef SENSITIVE 
    #undef RESPONSE_ID
    #undef COUNT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_dialog_set_default_response
 * Params:  GtkDialog *dialog, gint response_id
 * Returns: void
 * Assertion: Sets the last widget in the dialog's action area with the given response_id as the default widget for the dialog.'
 * Params Values: GtkDialog *dialog, gint response_id
 * Expected: void
 * 
 * Name:  gtk_dialog_set_default_response
 * Params:  GtkDialog *dialog, gint response_id
 * Returns: void
 * Assertion: Pressing "Enter" normally activates the default widget.
 * Params Values: GtkDialog *dialog, gint response_id
 * Expected: void  
 */
static void test_purpose_12()
{
    #define BUTTONS "Button 1", 1000, "Button 2", 1001, "Button 3", 1002
    #define RESPONSE_ID 1000
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    response_id = RESPONSE_ID;
    
    widget = gtk_dialog_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_dialog_add_buttons (GTK_DIALOG (widget), BUTTONS, NULL);
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_press_return), NULL);
    
    gtk_dialog_set_default_response (GTK_DIALOG (widget), RESPONSE_ID);
    
    gtk_dialog_run (GTK_DIALOG (widget));
    
    if (!result)
    {
        TEST_FAIL ("'response' signal not catched", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef BUTTONS 
    #undef RESPONSE_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_dialog_set_default_response
 * Params:  GtkDialog *dialog, gint response_id
 * Returns: void
 * Assertion: Sets the last widget in the dialog's action area with the given response_id as the default widget for the dialog.'
 * Params Values: GtkDialog *dialog, gint response_id
 * Expected: void
 * 
 * Name:  gtk_dialog_set_default_response
 * Params:  GtkDialog *dialog, gint response_id
 * Returns: void
 * Assertion: Pressing "Enter" normally activates the default widget.
 * Params Values: GtkDialog *dialog, gint response_id
 * Expected: void  
 */
static void test_purpose_13()
{
    #define BUTTONS "Button 1", 1000, "Button 2", 1001, "Button 3", G_MAXINT
    #define RESPONSE_ID G_MAXINT
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    response_id = RESPONSE_ID;
    
    widget = gtk_dialog_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_dialog_add_buttons (GTK_DIALOG (widget), BUTTONS, NULL);
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_press_return), NULL);
    
    gtk_dialog_set_default_response (GTK_DIALOG (widget), RESPONSE_ID);
    
    gtk_dialog_run (GTK_DIALOG (widget));
    
    if (!result)
    {
        TEST_FAIL ("'response' signal not catched", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef BUTTONS 
    #undef RESPONSE_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_dialog_response
 * Params:  GtkDialog *dialog, gint response_id
 * Returns: void
 * Assertion: Emits the "response" signal with the given response ID.
 * Params Values: GtkDialog *dialog, gint response_id
 * Expected: void  
 */
static void test_purpose_14()
{
    #define BUTTONS "Button 1", 1000, "Button 2", 1001, "Button 3", 1002
    #define RESPONSE_ID 1000
    
    GtkWidget* widget;
    GtkWidget* b1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    response_id = RESPONSE_ID;
    result = FALSE;
    
    widget = gtk_dialog_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_dialog_add_buttons (GTK_DIALOG (widget), BUTTONS, NULL);
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);
    
    gtk_dialog_response (GTK_DIALOG (widget), RESPONSE_ID);
    
    if (!result)
    {
        TEST_FAIL ("'response' signal not catched", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef BUTTONS 
    #undef RESPONSE_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_dialog_response
 * Params:  GtkDialog *dialog, gint response_id
 * Returns: void
 * Assertion: Emits the "response" signal with the given response ID.
 * Params Values: GtkDialog *dialog, gint response_id
 * Expected: void  
 */
static void test_purpose_15()
{
    #define BUTTONS "Button 1", 1000, "Button 2", 1001, "Button 3", G_MAXINT
    #define RESPONSE_ID G_MAXINT
    
    GtkWidget* widget;
    GtkWidget* b1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    response_id = RESPONSE_ID;
    result = FALSE;
    
    widget = gtk_dialog_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_dialog_add_buttons (GTK_DIALOG (widget), BUTTONS, NULL);
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);
    
    gtk_dialog_response (GTK_DIALOG (widget), RESPONSE_ID);
    
    if (!result)
    {
        TEST_FAIL ("'response' signal not catched", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef BUTTONS 
    #undef RESPONSE_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_dialog_add_button
 * Params:  GtkDialog *dialog, const gchar *button_text, gint response_id
 * Returns: GtkWidget*
 * Assertion: Adds a button with the given text (or a stock button, if button_text is a stock ID) and sets things up so that clicking the button will emit the "response" signal with the given response_id.
 * Params Values:  GtkDialog *dialog, const gchar *button_text, gint response_id
 * Expected: GtkWidget*
 * 
 * Name:  gtk_dialog_add_button
 * Params:  GtkDialog *dialog, const gchar *button_text, gint response_id
 * Returns: GtkWidget*
 * Assertion: The button widget is returned, but usually you don't need it.'
 * Params Values:  GtkDialog *dialog, const gchar *button_text, gint response_id
 * Expected: GtkWidget*  
 */
static void test_purpose_16()
{
    #define TEXT "Button 1"
    #define RESPONSE_ID 1000
    
    GtkWidget* widget;
    GtkWidget* button;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    response_id = RESPONSE_ID;
    
    widget = gtk_dialog_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    /* gtk_widget_set_uposition (widget, 0, 0); */
    button = gtk_dialog_add_button (GTK_DIALOG (widget), TEXT, RESPONSE_ID);
    if (!GTK_IS_BUTTON (button))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), button);
    
    gtk_dialog_run (GTK_DIALOG (widget));
    
    if (!result)
    {
        TEST_FAIL ("'response' signal not catched", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef TEXT
    #undef RESPONSE_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_dialog_add_button
 * Params:  GtkDialog *dialog, const gchar *button_text, gint response_id
 * Returns: GtkWidget*
 * Assertion: Adds a button with the given text (or a stock button, if button_text is a stock ID) and sets things up so that clicking the button will emit the "response" signal with the given response_id.
 * Params Values:  GtkDialog *dialog, const gchar *button_text, gint response_id
 * Expected: GtkWidget*
 * 
 * Name:  gtk_dialog_add_button
 * Params:  GtkDialog *dialog, const gchar *button_text, gint response_id
 * Returns: GtkWidget*
 * Assertion: The button widget is returned, but usually you don't need it.'
 * Params Values:  GtkDialog *dialog, const gchar *button_text, gint response_id
 * Expected: GtkWidget*  
 */
static void test_purpose_17()
{
    #define TEXT "Button 2"
    #define RESPONSE_ID G_MAXINT
    
    GtkWidget* widget;
    GtkWidget* button;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    response_id = RESPONSE_ID;
    
    widget = gtk_dialog_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    /* gtk_widget_set_uposition (widget, 0, 0); */
    button = gtk_dialog_add_button (GTK_DIALOG (widget), TEXT, RESPONSE_ID);
    if (!GTK_IS_BUTTON (button))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), button);
    
    gtk_dialog_run (GTK_DIALOG (widget));
    
    if (!result)
    {
        TEST_FAIL ("'response' signal not catched", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef TEXT
    #undef RESPONSE_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_dialog_add_buttons
 * Params:  GtkDialog *dialog, const gchar *button_text, gint response_id
 * Returns: GtkWidget*
 * Assertion: Adds more buttons, same as calling gtk_dialog_add_button() repeatedly.
 * Params Values:  GtkDialog *dialog, const gchar *button_text, gint response_id
 * Expected: GtkWidget*  
 */
static void test_purpose_18()
{
    #define BUTTONS "Button 1", 1000, "Button 2", 1001, "Button 3", 1002
    #define RESPONSE_ID 1000
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    response_id = RESPONSE_ID;
    
    widget = gtk_dialog_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_dialog_add_buttons (GTK_DIALOG (widget), BUTTONS, NULL);
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);
    
    gtk_dialog_response (GTK_DIALOG (widget), RESPONSE_ID);
    
    if (!result)
    {
        TEST_FAIL ("'response' signal not catched", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef BUTTONS
    #undef RESPONSE_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_dialog_add_buttons
 * Params:  GtkDialog *dialog, const gchar *button_text, gint response_id
 * Returns: GtkWidget*
 * Assertion: Adds more buttons, same as calling gtk_dialog_add_button() repeatedly.
 * Params Values:  GtkDialog *dialog, const gchar *button_text, gint response_id
 * Expected: GtkWidget*  
 */
static void test_purpose_19()
{
    #define BUTTONS "Button 1", 1000, "Button 2", 1001, "Button 3", G_MAXINT
    #define RESPONSE_ID G_MAXINT
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    response_id = RESPONSE_ID;
    
    widget = gtk_dialog_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_dialog_add_buttons (GTK_DIALOG (widget), BUTTONS, NULL);
    
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);
    
    gtk_dialog_response (GTK_DIALOG (widget), RESPONSE_ID);
    
    if (!result)
    {
        TEST_FAIL ("'response' signal not catched", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (widget);
    
    #undef BUTTONS
    #undef RESPONSE_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_dialog_add_action_widget
 * Params:   GtkDialog *dialog, const gchar *button_text, gint response_id
 * Returns: void
 * Assertion: Adds an activatable widget to the action area of a GtkDialog, connecting a signal handler that will emit the "response" signal on the dialog when the widget is activated.
 * Params Values: GtkDialog *dialog, GtkWidget *child, gint response_id
 * Expected: void  
 */
static void test_purpose_20()
{
    #define CHILD gtk_button_new_with_label ("Button")
    #define RESPONSE_ID 1
    
    GtkWidget* widget;
    GtkWidget* child;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    response_id = RESPONSE_ID;
    child = CHILD;
    
    widget = gtk_dialog_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_dialog_add_action_widget (GTK_DIALOG (widget), child, RESPONSE_ID);
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), child);
    
    gtk_widget_show_all (widget);
    
    if (!gtk_widget_activate (child))
    {
        TEST_FAIL ("widget '%s' is not activatable", CHILD);
    }
    
    gtk_dialog_run (GTK_DIALOG (widget));
       
    if (!result)
    {
        TEST_FAIL ("'response' signal not catched", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef CHILD
    #undef RESPONSE_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_dialog_add_action_widget
 * Params:   GtkDialog *dialog, const gchar *button_text, gint response_id
 * Returns: void
 * Assertion: Adds an activatable widget to the action area of a GtkDialog, connecting a signal handler that will emit the "response" signal on the dialog when the widget is activated.
 * Params Values: GtkDialog *dialog, GtkWidget *child, gint response_id
 * Expected: void  
 */
static void test_purpose_21()
{
    #define CHILD gtk_check_button_new_with_label ("Check Button")
    #define RESPONSE_ID G_MAXINT
    
    GtkWidget* widget;
    GtkWidget* child;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    response_id = RESPONSE_ID;
    child = CHILD;
    
    widget = gtk_dialog_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_dialog_add_action_widget (GTK_DIALOG (widget), child, RESPONSE_ID);
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), child);
    
    gtk_widget_show_all (widget);
    
    if (!gtk_widget_activate (child))
    {
        TEST_FAIL ("widget '%s' is not activatable", CHILD);
    }
    
    gtk_dialog_run (GTK_DIALOG (widget));
       
    if (!result)
    {
        TEST_FAIL ("'response' signal not catched", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef CHILD
    #undef RESPONSE_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_dialog_run
 * Params:   GtkDialog *dialog
 * Returns: gint
 * Assertion: Otherwise, it returns the response ID from the "response" signal emission.
 * Params Values: GtkDialog *dialog
 * Expected: gint
 * 
 * Name:  gtk_dialog_run
 * Params:   GtkDialog *dialog
 * Returns: gint
 * Assertion: You can force gtk_dialog_run() to return at any time by calling gtk_dialog_response() to emit the "response" signal.
 * Params Values: GtkDialog *dialog
 * Expected: gint  
 */
static void test_purpose_22()
{
    #define BUTTONS "Button 1", 1000, "Button 2", 1001, "Button 3", 1002
    #define RESPONSE_ID 1000
    
    GtkWidget* widget;
    GtkWidget* button;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    response_id = RESPONSE_ID;
    result = FALSE;
    
    widget = gtk_dialog_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_dialog_add_buttons (GTK_DIALOG (widget), BUTTONS, NULL);
    gtk_container_foreach (GTK_CONTAINER (GTK_DIALOG (widget)->action_area), global_check_response, &button);
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), button);
    
    if (gtk_dialog_run (GTK_DIALOG (widget)) != RESPONSE_ID)
    {
        TEST_FAIL ("gtk_dialog_run () should return %i", RESPONSE_ID);
    }
    
    gtk_widget_destroy (widget);
    
    #undef BUTTONS
    #undef RESPONSE_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_dialog_run
 * Params:   GtkDialog *dialog
 * Returns: gint
 * Assertion: Otherwise, it returns the response ID from the "response" signal emission.
 * Params Values: GtkDialog *dialog
 * Expected: gint
 * 
 * Name:  gtk_dialog_run
 * Params:   GtkDialog *dialog
 * Returns: gint
 * Assertion: You can force gtk_dialog_run() to return at any time by calling gtk_dialog_response() to emit the "response" signal.
 * Params Values: GtkDialog *dialog
 * Expected: gint  
 */
static void test_purpose_23()
{
    #define BUTTONS "Button 1", 1000, "Button 2", 1001, "Button 3", G_MAXINT
    #define RESPONSE_ID G_MAXINT
    
    GtkWidget* widget;
    GtkWidget* button;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    response_id = RESPONSE_ID;
    result = FALSE;
    
    widget = gtk_dialog_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_dialog_add_buttons (GTK_DIALOG (widget), BUTTONS, NULL);
    gtk_container_foreach (GTK_CONTAINER (GTK_DIALOG (widget)->action_area), global_check_response, &button);
    g_signal_connect (G_OBJECT (widget), "response", GTK_SIGNAL_FUNC (global_response), NULL);
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_activate), button);
    
    if (gtk_dialog_run (GTK_DIALOG (widget)) != RESPONSE_ID)
    {
        TEST_FAIL ("gtk_dialog_run () should return %i", RESPONSE_ID);
    }
    
    gtk_widget_destroy (widget);
    
    #undef BUTTONS
    #undef RESPONSE_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_dialog_run
 * Params:   GtkDialog *dialog
 * Returns: gint
 * Assertion: During gtk_dialog_run(), the default behavior of "delete_event" is disabled; if the dialog receives "delete_event", it will not be destroyed as windows usually are, and gtk_dialog_run() will return GTK_RESPONSE_DELETE_EVENT.
 * Params Values: GtkDialog *dialog
 * Expected: gint  
 */
static void test_purpose_24()
{
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = gtk_dialog_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_dialog_add_buttons (GTK_DIALOG (widget), "Button 1", 1, "Button 2", 2, NULL);
    g_signal_connect (G_OBJECT (widget), "delete-event", GTK_SIGNAL_FUNC (global_result), NULL);
    g_signal_connect (G_OBJECT (widget), "event", GTK_SIGNAL_FUNC (global_delete_event), widget);
    
    if (!g_signal_lookup ("delete-event", GTK_TYPE_DIALOG))
    {
        TEST_FAIL ("g_signal_lookup ('delete-event', GTK_TYPE_DIALOG) returns 0", NULL);
    }
    
    if (gtk_dialog_run (GTK_DIALOG (widget)) != GTK_RESPONSE_DELETE_EVENT)
    {
        TEST_FAIL ("gtk_dialog_run () should return GTK_RESPONSE_DELETE_EVENT", NULL);
    }
    
    if (!result)
    {
       TEST_FAIL ("'delete' signal not catched", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_dialog_run
 * Params:   GtkDialog *dialog
 * Returns: gint
 * Assertion: Blocks in a recursive main loop until the dialog either emits the response signal, or is destroyed.
 * Params Values: GtkDialog *dialog
 * Expected: gint  
 */
static void test_purpose_25()
{
    GtkDialog* dialog;
    GtkWidget* button;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    dialog = GTK_DIALOG (gtk_dialog_new ());
    
    if (!dialog)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_dialog_add_buttons (dialog, "Button 1", 1, "Button 2", 2, NULL);
    g_signal_connect (G_OBJECT (dialog), "event", GTK_SIGNAL_FUNC (global_destroy_widget), dialog);
    
    gtk_widget_destroy (GTK_WIDGET (dialog));
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkDialog ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {NULL,0}
};
