/*
 * GtkFontSelection methods tests
 * Testing GtkFontSelection methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_font_selection_new 
 * Params: void
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkFontSelection.
 * Params Values: void
 * Expected: GtkFontSelection*  
 */
static void test_purpose_1()
{
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_get_font_name
 * Params: GtkFontSelection *fontsel
 * Returns: gchar*
 * Assertion: Gets the currently-selected font name.
 * Params Values:  GtkFontSelection *fontsel
 * Expected: gchar*  
 */
static void test_purpose_2()
{
    char **p;
    char *fonts[] = {"Courier 10", 	    "Sans 10", 	    "Fixed 10", NULL};
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    for(p=fonts;*p != NULL; p++) {
    
        gtk_font_selection_set_font_name (GTK_FONT_SELECTION (widget), *p);
    
        if  (!g_ascii_strcasecmp(*p, gtk_font_selection_get_font_name (GTK_FONT_SELECTION (widget))))
        {
    	break;
        }
    }
    if(*p == NULL)
    {
        --p;
        TEST_FAIL ("font_name = %s %s", *p, gtk_font_selection_get_font_name(GTK_FONT_SELECTION (widget)));
        return;
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_set_font_name
 * Params: GtkFontSelection *fontsel, const gchar *fontname
 * Returns: boolean
 * Assertion: Sets the currently-selected font.
 * Params Values:  GtkFontSelection *fontsel, "Courier 12", 	    "Sans 10", 	    "Fixed 10"
 * Expected: boolean   
 */
static void test_purpose_3()
{
    char *fonts[] = {"Courier 12", 	    "Sans 10", 	    "Fixed 10", NULL};
    char **p;
    int status=1;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    for(p=fonts;*p != NULL && status != 0; ++p) {
        widget =  gtk_font_selection_new ();
    
        if (!widget)
        {
    	TEST_FAIL (get_not_created_msg(), NULL); 
    	return;
        } 
    
        if (!GTK_IS_FONT_SELECTION (widget))
        {
    	TEST_FAIL (get_wrong_type_msg(), NULL); 
    	return;
        }
    
        /******* VISUALISATION *******/
        TEST_VISUALIZE (widget);   
        /******* -------------  *******/ 
    
        if (!gtk_font_selection_set_font_name (GTK_FONT_SELECTION (widget), *p))
        {
    	status = 1;
        } else if (g_ascii_strcasecmp (*p, gtk_font_selection_get_font_name (GTK_FONT_SELECTION (widget))))
        {
    	status = 2;
        } else {
    	status = 0;
        }
        gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    }
    --p;
    if(status == 1) {
    	TEST_FAIL ("Missing Font %s", *p);;
    	return;
    } else if (status == 2) {
    	TEST_FAIL("Selected font %s differed from requested font", *p);
    	return;
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_get_preview_text
 * Params: GtkFontSelection *fontsel
 * Returns: G_CONST_RETURN  gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_4()
{
    #define PREVIEW_TEXT ""
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "preview-text", preview_text, NULL);
    
    if (strcmp(preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget)));
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_get_preview_text
 * Params: GtkFontSelection *fontsel
 * Returns: G_CONST_RETURN  gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_5()
{
    #define PREVIEW_TEXT " "
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "preview-text", preview_text, NULL);
    
    if (strcmp(preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget)));
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_get_preview_text
 * Params: GtkFontSelection *fontsel
 * Returns: G_CONST_RETURN  gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_6()
{
    #define PREVIEW_TEXT "   "
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "preview-text", preview_text, NULL);
    
    if (strcmp(preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget)));
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_get_preview_text
 * Params: GtkFontSelection *fontsel
 * Returns: G_CONST_RETURN  gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_7()
{
    #define PREVIEW_TEXT "Label String"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "preview-text", preview_text, NULL);
    
    if (strcmp(preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget)));
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_get_preview_text
 * Params: GtkFontSelection *fontsel
 * Returns: G_CONST_RETURN  gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_8()
{
    #define PREVIEW_TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "preview-text", preview_text, NULL);
    
    if (strcmp(preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget)));
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_get_preview_text
 * Params: GtkFontSelection *fontsel
 * Returns: G_CONST_RETURN  gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_9()
{
    #define PREVIEW_TEXT "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "preview-text", preview_text, NULL);
    
    if (strcmp(preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget)));
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_get_preview_text
 * Params: GtkFontSelection *fontsel
 * Returns: G_CONST_RETURN  gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_10()
{
    #define PREVIEW_TEXT "_a_b"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "preview-text", preview_text, NULL);
    
    if (strcmp(preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget)));
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_get_preview_text
 * Params: GtkFontSelection *fontsel
 * Returns: G_CONST_RETURN  gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_11()
{
    #define PREVIEW_TEXT "\n\t\""
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "preview-text", preview_text, NULL);
    
    if (strcmp(preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget)));
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_get_preview_text
 * Params: GtkFontSelection *fontsel
 * Returns: G_CONST_RETURN  gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_12()
{
    #define PREVIEW_TEXT "_\n\t\""
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "preview-text", preview_text, NULL);
    
    if (strcmp(preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget)));
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_get_preview_text
 * Params: GtkFontSelection *fontsel
 * Returns: G_CONST_RETURN  gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_13()
{
    #define PREVIEW_TEXT "\b"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "preview-text", preview_text, NULL);
    
    if (strcmp(preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget)));
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_get_preview_text
 * Params: GtkFontSelection *fontsel
 * Returns: G_CONST_RETURN  gchar*
 * Assertion: Gets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel
 * Expected: G_CONST_RETURN gchar*  
 */
static void test_purpose_14()
{
    #define PREVIEW_TEXT "_\b"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    preview_text = PREVIEW_TEXT;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "preview-text", preview_text, NULL);
    
    if (strcmp(preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget))))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, gtk_font_selection_get_preview_text(GTK_FONT_SELECTION (widget)));
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_set_preview_text
 * Params: GtkFontSelection *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel, ""
 * Expected: void  
 */
static void test_purpose_15()
{
    #define PREVIEW_TEXT ""
    
    GtkWidget* widget;
    gchararray preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_set_preview_text(GTK_FONT_SELECTION (widget), PREVIEW_TEXT);
    g_object_get (GTK_OBJECT (widget), "preview-text", &preview_text, NULL);
    
    if (strcmp(preview_text, PREVIEW_TEXT))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, PREVIEW_TEXT);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_set_preview_text
 * Params: GtkFontSelection *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel, " "
 * Expected: void  
 */
static void test_purpose_16()
{
    #define PREVIEW_TEXT " "
    
    GtkWidget* widget;
    gchararray preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_set_preview_text(GTK_FONT_SELECTION (widget), PREVIEW_TEXT);
    g_object_get (GTK_OBJECT (widget), "preview-text", &preview_text, NULL);
    
    if (strcmp(preview_text, PREVIEW_TEXT))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, PREVIEW_TEXT);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_set_preview_text
 * Params: GtkFontSelection *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel, "   "
 * Expected: void  
 */
static void test_purpose_17()
{
    #define PREVIEW_TEXT "   "
    
    GtkWidget* widget;
    gchararray preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_set_preview_text(GTK_FONT_SELECTION (widget), PREVIEW_TEXT);
    g_object_get (GTK_OBJECT (widget), "preview-text", &preview_text, NULL);
    
    if (strcmp(preview_text, PREVIEW_TEXT))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, PREVIEW_TEXT);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_set_preview_text
 * Params: GtkFontSelection *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel, "Label String"
 * Expected: void  
 */
static void test_purpose_18()
{
    #define PREVIEW_TEXT "Label String"
    
    GtkWidget* widget;
    gchararray preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_set_preview_text(GTK_FONT_SELECTION (widget), PREVIEW_TEXT);
    g_object_get (GTK_OBJECT (widget), "preview-text", &preview_text, NULL);
    
    if (strcmp(preview_text, PREVIEW_TEXT))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, PREVIEW_TEXT);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_set_preview_text
 * Params: GtkFontSelection *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: void  
 */
static void test_purpose_19()
{
    #define PREVIEW_TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget* widget;
    gchararray preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_set_preview_text(GTK_FONT_SELECTION (widget), PREVIEW_TEXT);
    g_object_get (GTK_OBJECT (widget), "preview-text", &preview_text, NULL);
    
    if (strcmp(preview_text, PREVIEW_TEXT))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, PREVIEW_TEXT);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_set_preview_text
 * Params: GtkFontSelection *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel, "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: void  
 */
static void test_purpose_20()
{
    #define PREVIEW_TEXT "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GtkWidget* widget;
    gchararray preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_set_preview_text(GTK_FONT_SELECTION (widget), PREVIEW_TEXT);
    g_object_get (GTK_OBJECT (widget), "preview-text", &preview_text, NULL);
    
    if (strcmp(preview_text, PREVIEW_TEXT))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, PREVIEW_TEXT);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_set_preview_text
 * Params: GtkFontSelection *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel, "_a_b"
 * Expected: void  
 */
static void test_purpose_21()
{
    #define PREVIEW_TEXT "_a_b"
    
    GtkWidget* widget;
    gchararray preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_set_preview_text(GTK_FONT_SELECTION (widget), PREVIEW_TEXT);
    g_object_get (GTK_OBJECT (widget), "preview-text", &preview_text, NULL);
    
    if (strcmp(preview_text, PREVIEW_TEXT))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, PREVIEW_TEXT);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_set_preview_text
 * Params: GtkFontSelection *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel, "\n\t\""
 * Expected: void  
 */
static void test_purpose_22()
{
    #define PREVIEW_TEXT "\n\t\""
    
    GtkWidget* widget;
    gchararray preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_set_preview_text(GTK_FONT_SELECTION (widget), PREVIEW_TEXT);
    g_object_get (GTK_OBJECT (widget), "preview-text", &preview_text, NULL);
    
    if (strcmp(preview_text, PREVIEW_TEXT))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, PREVIEW_TEXT);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_set_preview_text
 * Params: GtkFontSelection *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel, "_\n\t\""
 * Expected: void  
 */
static void test_purpose_23()
{
    #define PREVIEW_TEXT "_\n\t\""
    
    GtkWidget* widget;
    gchararray preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_set_preview_text(GTK_FONT_SELECTION (widget), PREVIEW_TEXT);
    g_object_get (GTK_OBJECT (widget), "preview-text", &preview_text, NULL);
    
    if (strcmp(preview_text, PREVIEW_TEXT))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, PREVIEW_TEXT);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_set_preview_text
 * Params: GtkFontSelection *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel, "\b"
 * Expected: void  
 */
static void test_purpose_24()
{
    #define PREVIEW_TEXT "\b"
    
    GtkWidget* widget;
    gchararray preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_set_preview_text(GTK_FONT_SELECTION (widget), PREVIEW_TEXT);
    g_object_get (GTK_OBJECT (widget), "preview-text", &preview_text, NULL);
    
    if (strcmp(preview_text, PREVIEW_TEXT))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, PREVIEW_TEXT);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_font_selection_set_preview_text
 * Params: GtkFontSelection *fontsel, const gchar *text
 * Returns: void
 * Assertion: Sets the text displayed in the preview area.
 * Params Values:  GtkFontSelection *fontsel, "_\b"
 * Expected: void  
 */
static void test_purpose_25()
{
    #define PREVIEW_TEXT "_\b"
    
    GtkWidget* widget;
    gchararray preview_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget =  gtk_font_selection_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_FONT_SELECTION (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_font_selection_set_preview_text(GTK_FONT_SELECTION (widget), PREVIEW_TEXT);
    g_object_get (GTK_OBJECT (widget), "preview-text", &preview_text, NULL);
    
    if (strcmp(preview_text, PREVIEW_TEXT))
    {
        TEST_FAIL ("preview_text = %s %s", preview_text, PREVIEW_TEXT);
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PREVIEW_TEXT
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkFontSelection ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {NULL,0}
};
