/*
 * GtkImageMenuItem methods tests
 * Testing GtkImageMenuItem methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_image_menu_item_new
 * Params: void
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem with an empty label.
 * Params Values: void
 * Expected: GtkWidget*  
 */
static void test_purpose_1()
{
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_2()
{
    #define STOCK_ID ""
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_3()
{
    #define STOCK_ID "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_4()
{
    #define STOCK_ID "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_5()
{
    #define STOCK_ID "_a_b"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_6()
{
    #define STOCK_ID "\n\t\""
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_7()
{
    #define STOCK_ID "_\n\t\""
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_8()
{
    #define STOCK_ID "\b"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_9()
{
    #define STOCK_ID "_\b"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_10()
{
    #define STOCK_ID GTK_STOCK_ADD
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_11()
{
    #define STOCK_ID GTK_STOCK_APPLY
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_12()
{
    #define STOCK_ID GTK_STOCK_BOLD
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_13()
{
    #define STOCK_ID GTK_STOCK_CANCEL
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_14()
{
    #define STOCK_ID GTK_STOCK_CDROM
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_15()
{
    #define STOCK_ID 	     GTK_STOCK_CLEAR
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_16()
{
    #define STOCK_ID 	     GTK_STOCK_CLOSE
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_17()
{
    #define STOCK_ID 	     GTK_STOCK_CONVERT
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_18()
{
    #define STOCK_ID 	     GTK_STOCK_COPY
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_19()
{
    #define STOCK_ID 	     GTK_STOCK_CUT
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_20()
{
    #define STOCK_ID 	     GTK_STOCK_DELETE
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_21()
{
    #define STOCK_ID 	     GTK_STOCK_DIALOG_ERROR
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_22()
{
    #define STOCK_ID 	     GTK_STOCK_DIALOG_INFO
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_23()
{
    #define STOCK_ID 	     GTK_STOCK_DIALOG_QUESTION
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_24()
{
    #define STOCK_ID 	     GTK_STOCK_DIALOG_WARNING
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_25()
{
    #define STOCK_ID 	     GTK_STOCK_DND
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_26()
{
    #define STOCK_ID 	     GTK_STOCK_DND_MULTIPLE
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_27()
{
    #define STOCK_ID 	     GTK_STOCK_DND_MULTIPLE
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_28()
{
    #define STOCK_ID 	     GTK_STOCK_EXECUTE
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_29()
{
    #define STOCK_ID 	     GTK_STOCK_FIND
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_30()
{
    #define STOCK_ID 	     GTK_STOCK_FIND_AND_REPLACE
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_31()
{
    #define STOCK_ID 	     GTK_STOCK_FLOPPY
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_32()
{
    #define STOCK_ID 	     GTK_STOCK_GOTO_BOTTOM
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_33()
{
    #define STOCK_ID 	     GTK_STOCK_GOTO_FIRST
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_34()
{
    #define STOCK_ID 	     GTK_STOCK_GOTO_LAST
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_35()
{
    #define STOCK_ID 	     GTK_STOCK_GOTO_TOP
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_36()
{
    #define STOCK_ID 	     GTK_STOCK_GO_BACK
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_37()
{
    #define STOCK_ID 	     GTK_STOCK_GO_DOWN
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_38()
{
    #define STOCK_ID 	     GTK_STOCK_GO_FORWARD
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_39()
{
    #define STOCK_ID 	     GTK_STOCK_GO_UP
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_40()
{
    #define STOCK_ID 	     GTK_STOCK_HELP
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_41()
{
    #define STOCK_ID 	     GTK_STOCK_HOME
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_42()
{
    #define STOCK_ID 	     GTK_STOCK_INDEX
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_43()
{
    #define STOCK_ID 	     GTK_STOCK_ITALIC
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_44()
{
    #define STOCK_ID 	     GTK_STOCK_JUMP_TO
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_45()
{
    #define STOCK_ID 	     GTK_STOCK_JUSTIFY_CENTER
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_46()
{
    #define STOCK_ID 	     GTK_STOCK_JUSTIFY_FILL
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_47()
{
    #define STOCK_ID 	     GTK_STOCK_JUSTIFY_LEFT
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_48()
{
    #define STOCK_ID 	     GTK_STOCK_JUSTIFY_RIGHT
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_49()
{
    #define STOCK_ID 	     GTK_STOCK_MISSING_IMAGE
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_50()
{
    #define STOCK_ID 	     GTK_STOCK_NEW
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_51()
{
    #define STOCK_ID 	     GTK_STOCK_NO
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_52()
{
    #define STOCK_ID 	     GTK_STOCK_OK
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_53()
{
    #define STOCK_ID 	     GTK_STOCK_OPEN
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_54()
{
    #define STOCK_ID 	     GTK_STOCK_PASTE
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_55()
{
    #define STOCK_ID 	     GTK_STOCK_PREFERENCES
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_56()
{
    #define STOCK_ID 	     GTK_STOCK_PRINT
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_57()
{
    #define STOCK_ID 	     GTK_STOCK_PRINT_PREVIEW
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_58()
{
    #define STOCK_ID 	     GTK_STOCK_PROPERTIES
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_59()
{
    #define STOCK_ID 	     GTK_STOCK_QUIT
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_60()
{
    #define STOCK_ID 	     GTK_STOCK_REDO
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_61()
{
    #define STOCK_ID 	     GTK_STOCK_REFRESH
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_62()
{
    #define STOCK_ID 	     GTK_STOCK_REMOVE
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_63()
{
    #define STOCK_ID 	     GTK_STOCK_REVERT_TO_SAVED
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_64()
{
    #define STOCK_ID 	     GTK_STOCK_SAVE
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_65()
{
    #define STOCK_ID 	     GTK_STOCK_SAVE_AS
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_66()
{
    #define STOCK_ID 	     GTK_STOCK_SELECT_COLOR
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_67()
{
    #define STOCK_ID 	     GTK_STOCK_SELECT_FONT
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_68()
{
    #define STOCK_ID 	     GTK_STOCK_SORT_ASCENDING
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_69()
{
    #define STOCK_ID 	     GTK_STOCK_SORT_DESCENDING
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_70()
{
    #define STOCK_ID 	     GTK_STOCK_SPELL_CHECK
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_71()
{
    #define STOCK_ID 	     GTK_STOCK_STOP
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_72()
{
    #define STOCK_ID 	     GTK_STOCK_STRIKETHROUGH
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_73()
{
    #define STOCK_ID 	     GTK_STOCK_UNDELETE
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_74()
{
    #define STOCK_ID 	     GTK_STOCK_UNDERLINE
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_75()
{
    #define STOCK_ID 	     GTK_STOCK_UNDO
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_76()
{
    #define STOCK_ID 	     GTK_STOCK_YES
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_77()
{
    #define STOCK_ID GTK_STOCK_ZOOM_100
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_78()
{
    #define STOCK_ID GTK_STOCK_ZOOM_FIT
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_79()
{
    #define STOCK_ID GTK_STOCK_ZOOM_IN
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_from_stock
 * Params: const gchar *stock_id, GtkAccelGroup *accel_group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing the image and text from a stock item.
 * Params Values: const gchar *stock_id, GtkAccelGroup *accel_group
 * Expected: GtkWidget*  
 */
static void test_purpose_80()
{
    #define STOCK_ID GTK_STOCK_ZOOM_OUT
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_from_stock (STOCK_ID, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_bar_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing a label.
 * Params Values: "Text"
 * Expected: GtkWidget*  
 */
static void test_purpose_81()
{
    #define LABEL "Text"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_with_label (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing a label.
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkWidget*  
 */
static void test_purpose_82()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_with_label (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing a label.
 * Params Values: "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: GtkWidget*  
 */
static void test_purpose_83()
{
    #define LABEL "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_with_label (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing a label.
 * Params Values: "\n\t"
 * Expected: GtkWidget*  
 */
static void test_purpose_84()
{
    #define LABEL "\n\t"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_with_label (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing a label.
 * Params Values: ""
 * Expected: GtkWidget*  
 */
static void test_purpose_85()
{
    #define LABEL ""
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_with_label (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing a label.
 * Params Values: " "
 * Expected: GtkWidget*  
 */
static void test_purpose_86()
{
    #define LABEL " "
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_with_label (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing a label.
 * Params Values: "_Text"
 * Expected: GtkWidget*  
 */
static void test_purpose_87()
{
    #define LABEL "_Text"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_with_mnemonic (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing a label.
 * Params Values: "abc_de_fghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkWidget*  
 */
static void test_purpose_88()
{
    #define LABEL "abc_de_fghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_with_mnemonic (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing a label.
 * Params Values: "!@#$%^_&*()_+|~=\";:'_?<>`/"
 * Expected: GtkWidget*  
 */
static void test_purpose_89()
{
    #define LABEL "!@#$%^_&*()_+|~=\";:'_?<>`/"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_with_mnemonic (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing a label.
 * Params Values: "\n_\t"
 * Expected: GtkWidget*  
 */
static void test_purpose_90()
{
    #define LABEL "\n_\t"
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_with_mnemonic (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing a label.
 * Params Values: ""
 * Expected: GtkWidget*  
 */
static void test_purpose_91()
{
    #define LABEL ""
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_with_mnemonic (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkImageMenuItem containing a label.
 * Params Values: "_ "
 * Expected: GtkWidget*  
 */
static void test_purpose_92()
{
    #define LABEL "_ "
    
    GtkWidget *widget;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_with_mnemonic (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion:  The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "Te_xt"
 * Expected: GtkWidget*  
 */
static void test_purpose_93()
{
    #define    LABEL "Te_xt"
    #define    KEY GDK_x
    
    GtkWidget* widget;
    GList *children;
    GtkWidget* child;
    guint keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_with_mnemonic (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
        gtk_widget_destroy (gtk_widget_get_toplevel (widget));
        return;
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion:  The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "_Text"
 * Expected: GtkWidget*  
 */
static void test_purpose_94()
{
    #define    LABEL "_Text"
    #define    KEY GDK_t
    
    GtkWidget* widget;
    GList *children;
    GtkWidget* child;
    guint keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_with_mnemonic (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
        gtk_widget_destroy (gtk_widget_get_toplevel (widget));
        return;
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion:  The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the menu item.
 * Params Values: "T_ext"
 * Expected: GtkWidget*  
 */
static void test_purpose_95()
{
    #define    LABEL "T_ext"
    #define    KEY GDK_e
    
    GtkWidget* widget;
    GList *children;
    GtkWidget* child;
    guint keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new_with_mnemonic (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_IMAGE_MENU_ITEM (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    children = gtk_container_get_children (GTK_CONTAINER (widget));
    child = g_list_nth_data (children, 0);
    
    if (!GTK_IS_LABEL (child))
    {
        TEST_FAIL ("GtkLabel object should be menu item's child", NULL);
        gtk_widget_destroy (gtk_widget_get_toplevel (widget));
        return;
    } 
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_set_image
 * Params: GtkImageMenuItem *image_menu_item, GtkWidget *image
 * Returns: void
 * Assertion: Sets the image of image_menu_item to the given widget.
 * Params Values: GtkImageMenuItem *image_menu_item, NULL
 * Expected: void
 * 
 * Name: gtk_image_menu_item_get_image
 * Params: GtkImageMenuItem *image_menu_item
 * Returns: GtkWidget*
 * Assertion: Gets the widget that is currently set as the image of image_menu_item.
 * Params Values: GtkImageMenuItem *image_menu_item
 * Expected: NULL  
 */
static void test_purpose_96()
{
    #define IMAGE NULL
    
    GtkWidget *widget;
    GtkWidget *image;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    image = IMAGE;
    
    gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (widget), image);
    if (image != gtk_image_menu_item_get_image (GTK_IMAGE_MENU_ITEM (widget)))
    {
        TEST_FAIL ("'image' wrong", NULL);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef IMAGE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_set_image
 * Params: GtkImageMenuItem *image_menu_item, GtkWidget *image
 * Returns: void
 * Assertion: Sets the image of image_menu_item to the given widget.
 * Params Values: GtkImageMenuItem *image_menu_item, gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU)
 * Expected: void
 * 
 * Name: gtk_image_menu_item_get_image
 * Params: GtkImageMenuItem *image_menu_item
 * Returns: GtkWidget*
 * Assertion: Gets the widget that is currently set as the image of image_menu_item.
 * Params Values: GtkImageMenuItem *image_menu_item
 * Expected: gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU)  
 */
static void test_purpose_97()
{
    #define IMAGE gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU)
    
    GtkWidget *widget;
    GtkWidget *image;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    image = IMAGE;
    
    gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (widget), image);
    if (image != gtk_image_menu_item_get_image (GTK_IMAGE_MENU_ITEM (widget)))
    {
        TEST_FAIL ("'image' wrong", NULL);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef IMAGE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_set_image
 * Params: GtkImageMenuItem *image_menu_item, GtkWidget *image
 * Returns: void
 * Assertion: Sets the image of image_menu_item to the given widget.
 * Params Values: GtkImageMenuItem *image_menu_item, gtk_image_new_from_stock (GTK_STOCK_QUIT, GTK_ICON_SIZE_MENU)
 * Expected: void
 * 
 * Name: gtk_image_menu_item_get_image
 * Params: GtkImageMenuItem *image_menu_item
 * Returns: GtkWidget*
 * Assertion: Gets the widget that is currently set as the image of image_menu_item.
 * Params Values: GtkImageMenuItem *image_menu_item
 * Expected: gtk_image_new_from_stock (GTK_STOCK_QUIT, GTK_ICON_SIZE_MENU)  
 */
static void test_purpose_98()
{
    #define IMAGE gtk_image_new_from_stock (GTK_STOCK_QUIT, GTK_ICON_SIZE_MENU)
    
    GtkWidget *widget;
    GtkWidget *image;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    image = IMAGE;
    
    gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (widget), image);
    if (image != gtk_image_menu_item_get_image (GTK_IMAGE_MENU_ITEM (widget)))
    {
        TEST_FAIL ("'image' wrong", NULL);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef IMAGE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_set_image
 * Params: GtkImageMenuItem *image_menu_item, GtkWidget *image
 * Returns: void
 * Assertion: Sets the image of image_menu_item to the given widget.
 * Params Values: GtkImageMenuItem *image_menu_item, gtk_image_new_from_stock (GTK_STOCK_NEW, GTK_ICON_SIZE_MENU)
 * Expected: void
 * 
 * Name: gtk_image_menu_item_get_image
 * Params: GtkImageMenuItem *image_menu_item
 * Returns: GtkWidget*
 * Assertion: Gets the widget that is currently set as the image of image_menu_item.
 * Params Values: GtkImageMenuItem *image_menu_item
 * Expected: gtk_image_new_from_stock (GTK_STOCK_NEW, GTK_ICON_SIZE_MENU)  
 */
static void test_purpose_99()
{
    #define IMAGE gtk_image_new_from_stock (GTK_STOCK_NEW, GTK_ICON_SIZE_MENU)
    
    GtkWidget *widget;
    GtkWidget *image;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    image = IMAGE;
    
    gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (widget), image);
    if (image != gtk_image_menu_item_get_image (GTK_IMAGE_MENU_ITEM (widget)))
    {
        TEST_FAIL ("'image' wrong", NULL);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef IMAGE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_image_menu_item_set_image
 * Params: GtkImageMenuItem *image_menu_item, GtkWidget *image
 * Returns: void
 * Assertion: Sets the image of image_menu_item to the given widget.
 * Params Values: GtkImageMenuItem *image_menu_item, gtk_image_new_from_stock (GTK_STOCK_SAVE, GTK_ICON_SIZE_MENU)
 * Expected: void
 * 
 * Name: gtk_image_menu_item_get_image
 * Params: GtkImageMenuItem *image_menu_item
 * Returns: GtkWidget*
 * Assertion: Gets the widget that is currently set as the image of image_menu_item.
 * Params Values: GtkImageMenuItem *image_menu_item
 * Expected: gtk_image_new_from_stock (GTK_STOCK_SAVE, GTK_ICON_SIZE_MENU)  
 */
static void test_purpose_100()
{
    #define IMAGE gtk_image_new_from_stock (GTK_STOCK_SAVE, GTK_ICON_SIZE_MENU)
    
    GtkWidget *widget;
    GtkWidget *image;
    GList *children;
    gpointer child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_image_menu_item_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    image = IMAGE;
    
    gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (widget), image);
    if (image != gtk_image_menu_item_get_image (GTK_IMAGE_MENU_ITEM (widget)))
    {
        TEST_FAIL ("'image' wrong", NULL);
    }
    
    /******* VISUALISATION *******/
    {
        GtkWidget* menu_shell = gtk_menu_new ();
        gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), widget);
        gtk_widget_show (widget);
        gtk_menu_popup (GTK_MENU (menu_shell), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
        TEST_VISUALIZE (menu_shell);
    }
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef IMAGE
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkImageMenuItem ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {test_purpose_79, 1},
    {test_purpose_80, 1},
    {test_purpose_81, 1},
    {test_purpose_82, 1},
    {test_purpose_83, 1},
    {test_purpose_84, 1},
    {test_purpose_85, 1},
    {test_purpose_86, 1},
    {test_purpose_87, 1},
    {test_purpose_88, 1},
    {test_purpose_89, 1},
    {test_purpose_90, 1},
    {test_purpose_91, 1},
    {test_purpose_92, 1},
    {test_purpose_93, 1},
    {test_purpose_94, 1},
    {test_purpose_95, 1},
    {test_purpose_96, 1},
    {test_purpose_97, 1},
    {test_purpose_98, 1},
    {test_purpose_99, 1},
    {test_purpose_100, 1},
    {NULL,0}
};
