/*
 * GtkLayout methods tests
 * Testing GtkLayout methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_layout_new   
 * Params: GtkAdjustment *hadjustment, GtkAdjustment *vadjustment
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkLayout.
 * Params Values: GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0)), GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
 * Expected: GtkLayout*   
 */
static void test_purpose_1()
{
    #define HADJUSTMENT GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
    #define VADJUSTMENT GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
    
    GtkWidget *widget;
    GtkAdjustment *hadjustment;
    GtkAdjustment *vadjustment;
    GtkAdjustment *real_vadjustment;
    GtkAdjustment *real_hadjustment;
    guint width;
    guint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    hadjustment = HADJUSTMENT;
    vadjustment = VADJUSTMENT;
    
    widget = gtk_layout_new (hadjustment,vadjustment);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LAYOUT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "hadjustment", &real_hadjustment, NULL);
    if (real_hadjustment != hadjustment)
    {
        TEST_FAIL ("h_adjustment is different from the one was set", NULL);
    }
    
    g_object_get (GTK_OBJECT (widget), "vadjustment", &real_vadjustment, NULL);
    if (real_vadjustment != vadjustment)
    {
        TEST_FAIL ("v_adjustment is different from the one was set", NULL);
    }
    
    g_object_get (GTK_OBJECT (widget), "width", &width, NULL);
    if (width != 100)
    {
        TEST_FAIL ("width is %d, should be %d", width, 100);
    }
    
    g_object_get (GTK_OBJECT (widget), "height", &height, NULL);
    if (height != 100)
    {
        TEST_FAIL ("height is %d, should be %d", height, 100);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HADJUSTMENT 
    #undef VADJUSTMENT 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_new   
 * Params: GtkAdjustment *hadjustment, GtkAdjustment *vadjustment
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkLayout.
 * Params Values: GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0)), GTK_ADJUSTMENT(gtk_adjustment_new(10.0, 10.0, 500.0, 5.0, 20.0, 50.0))
 * Expected: GtkLayout*   
 */
static void test_purpose_2()
{
    #define HADJUSTMENT GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
    #define VADJUSTMENT GTK_ADJUSTMENT(gtk_adjustment_new(10.0, 10.0, 500.0, 5.0, 20.0, 50.0))
    
    GtkWidget *widget;
    GtkAdjustment *hadjustment;
    GtkAdjustment *vadjustment;
    GtkAdjustment *real_vadjustment;
    GtkAdjustment *real_hadjustment;
    guint width;
    guint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    hadjustment = HADJUSTMENT;
    vadjustment = VADJUSTMENT;
    
    widget = gtk_layout_new (hadjustment,vadjustment);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_LAYOUT (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "hadjustment", &real_hadjustment, NULL);
    if (real_hadjustment != hadjustment)
    {
        TEST_FAIL ("h_adjustment is different from the one was set", NULL);
    }
    
    g_object_get (GTK_OBJECT (widget), "vadjustment", &real_vadjustment, NULL);
    if (real_vadjustment != vadjustment)
    {
        TEST_FAIL ("v_adjustment is different from the one was set", NULL);
    }
    
    g_object_get (GTK_OBJECT (widget), "width", &width, NULL);
    if (width != 100)
    {
        TEST_FAIL ("width is %d, should be %d", width, 100);
    }
    
    g_object_get (GTK_OBJECT (widget), "height", &height, NULL);
    if (height != 100)
    {
        TEST_FAIL ("height is %d, should be %d", height, 100);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HADJUSTMENT 
    #undef VADJUSTMENT 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_set_size
 * Params: GtkLayout *layout, guint width, guint height
 * Returns: void
 * Assertion: Sets the size of the scrollable area of the layout.
 * Params Values: newly created GtkLayout*, 0, 0
 * Expected: void  
 */
static void test_purpose_3()
{
    #define WIDTH 0
    #define HEIGHT 0
    
    GtkWidget *widget;
    GtkAdjustment *hadjustment = NULL;
    GtkAdjustment *vadjustment = NULL;
    guint width;
    guint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_layout_new (hadjustment, vadjustment);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LAYOUT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_layout_set_size (GTK_LAYOUT (widget), WIDTH, HEIGHT);
    
    
    g_object_get (GTK_OBJECT (widget), "width", &width, NULL);
    if (width != WIDTH)
    {
        TEST_FAIL("layout width = %i, should be %i", width, WIDTH);
    }
    
    g_object_get (GTK_OBJECT (widget), "height", &height, NULL);
    if (height != HEIGHT)
    {
        TEST_FAIL("layout height = %i, should be %i", height, HEIGHT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_set_size
 * Params: GtkLayout *layout, guint width, guint height
 * Returns: void
 * Assertion: Sets the size of the scrollable area of the layout.
 * Params Values: newly created GtkLayout*, 1, 1
 * Expected: void  
 */
static void test_purpose_4()
{
    #define WIDTH 1
    #define HEIGHT 1
    
    GtkWidget *widget;
    GtkAdjustment *hadjustment = NULL;
    GtkAdjustment *vadjustment = NULL;
    guint width;
    guint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_layout_new (hadjustment, vadjustment);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LAYOUT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_layout_set_size (GTK_LAYOUT (widget), WIDTH, HEIGHT);
    
    
    g_object_get (GTK_OBJECT (widget), "width", &width, NULL);
    if (width != WIDTH)
    {
        TEST_FAIL("layout width = %i, should be %i", width, WIDTH);
    }
    
    g_object_get (GTK_OBJECT (widget), "height", &height, NULL);
    if (height != HEIGHT)
    {
        TEST_FAIL("layout height = %i, should be %i", height, HEIGHT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_set_size
 * Params: GtkLayout *layout, guint width, guint height
 * Returns: void
 * Assertion: Sets the size of the scrollable area of the layout.
 * Params Values: newly created GtkLayout*, G_MAXINT, G_MAXINT
 * Expected: void  
 */
static void test_purpose_5()
{
    #define WIDTH G_MAXINT
    #define HEIGHT G_MAXINT
    
    GtkWidget *widget;
    GtkAdjustment *hadjustment = NULL;
    GtkAdjustment *vadjustment = NULL;
    guint width;
    guint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_layout_new (hadjustment, vadjustment);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LAYOUT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_layout_set_size (GTK_LAYOUT (widget), WIDTH, HEIGHT);
    
    
    g_object_get (GTK_OBJECT (widget), "width", &width, NULL);
    if (width != WIDTH)
    {
        TEST_FAIL("layout width = %i, should be %i", width, WIDTH);
    }
    
    g_object_get (GTK_OBJECT (widget), "height", &height, NULL);
    if (height != HEIGHT)
    {
        TEST_FAIL("layout height = %i, should be %i", height, HEIGHT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_get_size
 * Params: GtkLayout *layout, guint *width, guint *height
 * Returns: void
 * Assertion: Gets the size that has been set on the layout, and that determines the total extents of the layout's scrollbar area.'
 * Params Values: newly created GtkLayout*, 0, 0
 * Expected: void  
 */
static void test_purpose_6()
{
    #define WIDTH 0
    #define HEIGHT 0
    
    GtkWidget *widget;
    GtkAdjustment *hadjustment = NULL;
    GtkAdjustment *vadjustment = NULL;
    guint width;
    guint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_layout_new (hadjustment, vadjustment);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LAYOUT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "width",WIDTH , NULL);
    g_object_set (GTK_OBJECT (widget), "height", HEIGHT, NULL);
    
    gtk_layout_get_size (GTK_LAYOUT (widget), &width, &height);
    if (width != WIDTH)
    {
        TEST_FAIL("layout width = %i, should be %i", width, WIDTH);
    }
    if (height != HEIGHT)
    {
        TEST_FAIL("layout height = %i, should be %i", height, HEIGHT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_get_size
 * Params: GtkLayout *layout, guint *width, guint *height
 * Returns: void
 * Assertion: Gets the size that has been set on the layout, and that determines the total extents of the layout's scrollbar area.'
 * Params Values: newly created GtkLayout*, 1, 1
 * Expected: void  
 */
static void test_purpose_7()
{
    #define WIDTH 1
    #define HEIGHT 1
    
    GtkWidget *widget;
    GtkAdjustment *hadjustment = NULL;
    GtkAdjustment *vadjustment = NULL;
    guint width;
    guint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_layout_new (hadjustment, vadjustment);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LAYOUT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "width",WIDTH , NULL);
    g_object_set (GTK_OBJECT (widget), "height", HEIGHT, NULL);
    
    gtk_layout_get_size (GTK_LAYOUT (widget), &width, &height);
    if (width != WIDTH)
    {
        TEST_FAIL("layout width = %i, should be %i", width, WIDTH);
    }
    if (height != HEIGHT)
    {
        TEST_FAIL("layout height = %i, should be %i", height, HEIGHT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_get_size
 * Params: GtkLayout *layout, guint *width, guint *height
 * Returns: void
 * Assertion: Gets the size that has been set on the layout, and that determines the total extents of the layout's scrollbar area.'
 * Params Values: newly created GtkLayout*, G_MAXINT, G_MAXINT
 * Expected: void  
 */
static void test_purpose_8()
{
    #define WIDTH G_MAXINT
    #define HEIGHT G_MAXINT
    
    GtkWidget *widget;
    GtkAdjustment *hadjustment = NULL;
    GtkAdjustment *vadjustment = NULL;
    guint width;
    guint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_layout_new (hadjustment, vadjustment);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LAYOUT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "width",WIDTH , NULL);
    g_object_set (GTK_OBJECT (widget), "height", HEIGHT, NULL);
    
    gtk_layout_get_size (GTK_LAYOUT (widget), &width, &height);
    if (width != WIDTH)
    {
        TEST_FAIL("layout width = %i, should be %i", width, WIDTH);
    }
    if (height != HEIGHT)
    {
        TEST_FAIL("layout height = %i, should be %i", height, HEIGHT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_set_hadjustment
 * Params: GtkLayout *layout, GtkAdjustment *adjustment
 * Returns: void
 * Assertion: Sets the horizontal scroll adjustment for the layout.
 * Params Values: newly created GtkLayout*, GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
 * Expected: void
 * 
 * Name: gtk_layout_get_hadjustment
 * Params: GtkLayout *layout
 * Returns: GtkAdjustment*
 * Assertion: It returns the GtkAdjustment used for communication between the horizontal scrollbar and layout.
 * Params Values: newly created GtkLayout*
 * Expected: GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))  
 */
static void test_purpose_9()
{
    #define ADJUSTMENT  GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
    
    GtkWidget *widget;
    GtkAdjustment *hadjustment = NULL;
    GtkAdjustment *vadjustment = NULL;
    GtkAdjustment *new_hadjustment;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_layout_new (hadjustment, vadjustment);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LAYOUT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    new_hadjustment = ADJUSTMENT;
    gtk_layout_set_hadjustment (GTK_LAYOUT (widget), new_hadjustment);
    
    if (gtk_layout_get_hadjustment (GTK_LAYOUT (widget)) != new_hadjustment)
    {
        TEST_FAIL("real layout hadjustment is differ form that was set by  gtk_layout_set_hadjustment ()", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_set_hadjustment
 * Params: GtkLayout *layout, GtkAdjustment *adjustment
 * Returns: void
 * Assertion: Sets the horizontal scroll adjustment for the layout.
 * Params Values: newly created GtkLayout*, GTK_ADJUSTMENT(gtk_adjustment_new(10.0, 10.0, 500.0, 5.0, 20.0, 50.0))
 * Expected: void
 * 
 * Name: gtk_layout_get_hadjustment
 * Params: GtkLayout *layout
 * Returns: GtkAdjustment*
 * Assertion: It returns the GtkAdjustment used for communication between the horizontal scrollbar and layout.
 * Params Values: newly created GtkLayout*
 * Expected: GTK_ADJUSTMENT(gtk_adjustment_new(10.0, 10.0, 500.0, 5.0, 20.0, 50.0))  
 */
static void test_purpose_10()
{
    #define ADJUSTMENT  GTK_ADJUSTMENT(gtk_adjustment_new(10.0, 10.0, 500.0, 5.0, 20.0, 50.0))
    
    GtkWidget *widget;
    GtkAdjustment *hadjustment = NULL;
    GtkAdjustment *vadjustment = NULL;
    GtkAdjustment *new_hadjustment;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_layout_new (hadjustment, vadjustment);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LAYOUT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    new_hadjustment = ADJUSTMENT;
    gtk_layout_set_hadjustment (GTK_LAYOUT (widget), new_hadjustment);
    
    if (gtk_layout_get_hadjustment (GTK_LAYOUT (widget)) != new_hadjustment)
    {
        TEST_FAIL("real layout hadjustment is differ form that was set by  gtk_layout_set_hadjustment ()", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_set_vadjustment
 * Params: GtkLayout *layout, GtkAdjustment *adjustment
 * Returns: void
 * Assertion: Sets the vertical scroll adjustment for the layout.
 * Params Values: newly created GtkLayout*, GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
 * Expected: void
 * 
 * Name: gtk_layout_get_vadjustment
 * Params: GtkLayout *layout
 * Returns: GtkAdjustment*
 * Assertion: It returns the GtkAdjustment used for communication between the vertical scrollbar and layout.
 * Params Values: newly created GtkLayout*
 * Expected: GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))  
 */
static void test_purpose_11()
{
    #define ADJUSTMENT  GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
    
    GtkWidget *widget;
    GtkAdjustment *hadjustment = NULL;
    GtkAdjustment *vadjustment = NULL;
    GtkAdjustment *new_vadjustment;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_layout_new (hadjustment, vadjustment);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LAYOUT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    new_vadjustment = ADJUSTMENT;
    gtk_layout_set_vadjustment (GTK_LAYOUT (widget), new_vadjustment);
    
    if (gtk_layout_get_vadjustment (GTK_LAYOUT (widget)) != new_vadjustment)
    {
        TEST_FAIL("real layout vadjustment is differ form that was set by  gtk_layout_set_vadjustment ()", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_set_vadjustment
 * Params: GtkLayout *layout, GtkAdjustment *adjustment
 * Returns: void
 * Assertion: Sets the vertical scroll adjustment for the layout.
 * Params Values: newly created GtkLayout*, GTK_ADJUSTMENT(gtk_adjustment_new(10.0, 10.0, 500.0, 5.0, 20.0, 50.0))
 * Expected: void
 * 
 * Name: gtk_layout_get_vadjustment
 * Params: GtkLayout *layout
 * Returns: GtkAdjustment*
 * Assertion: It returns the GtkAdjustment used for communication between the vertical scrollbar and layout.
 * Params Values: newly created GtkLayout*
 * Expected: GTK_ADJUSTMENT(gtk_adjustment_new(10.0, 10.0, 500.0, 5.0, 20.0, 50.0))  
 */
static void test_purpose_12()
{
    #define ADJUSTMENT  GTK_ADJUSTMENT(gtk_adjustment_new(10.0, 10.0, 500.0, 5.0, 20.0, 50.0))
    
    GtkWidget *widget;
    GtkAdjustment *hadjustment = NULL;
    GtkAdjustment *vadjustment = NULL;
    GtkAdjustment *new_vadjustment;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_layout_new (hadjustment, vadjustment);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_LAYOUT (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    new_vadjustment = ADJUSTMENT;
    gtk_layout_set_vadjustment (GTK_LAYOUT (widget), new_vadjustment);
    
    if (gtk_layout_get_vadjustment (GTK_LAYOUT (widget)) != new_vadjustment)
    {
        TEST_FAIL("real layout vadjustment is differ form that was set by  gtk_layout_set_vadjustment ()", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ADJUSTMENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_put
 * Params: GtkLayout *layout,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: Adds child_widget to layout, at position (x,y).
 * Params Values: a newly created GtkLayout*, gtk_button_new_with_label ("Button"),10,20
 * Expected: void  
 */
static void test_purpose_13()
{
    #define WIDGET gtk_button_new_with_label ("Button")
    #define X 10
    #define Y 20
    
    GtkWidget *layout;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    layout =  gtk_layout_new (
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0)),
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
        );
    
    widget = WIDGET;
    
    gtk_layout_put (GTK_LAYOUT (layout), widget, X,Y);
    
    children = gtk_container_get_children (GTK_CONTAINER (layout)); 
    child = children->data; 
    
    gtk_container_child_get (GTK_CONTAINER (layout), child, "x", &x, "y", &y, NULL);
    
    parent = gtk_widget_get_parent (widget);
    if (layout != parent)
    {
        TEST_FAIL ("Widget is not added to GtkLayout container",NULL);
    }
    
    if (x != X)
    {
        TEST_FAIL ("The horizontal position is '%d',should be '%d'",x,X);
    }
    if (y != Y)
    {
        TEST_FAIL ("The vertical position is '%d',should be '%d'",y,Y);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (layout);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (layout));
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_put
 * Params: GtkLayout *layout,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: Adds child_widget to layout, at position (x,y).
 * Params Values: a newly created GtkLayout*, gtk_button_new_with_label ("Button"),0,0
 * Expected: void  
 */
static void test_purpose_14()
{
    #define WIDGET gtk_button_new_with_label ("Button")
    #define X 0
    #define Y 0
    
    GtkWidget *layout;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    layout =  gtk_layout_new (
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0)),
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
        );
    
    widget = WIDGET;
    
    gtk_layout_put (GTK_LAYOUT (layout), widget, X,Y);
    
    children = gtk_container_get_children (GTK_CONTAINER (layout)); 
    child = children->data; 
    
    gtk_container_child_get (GTK_CONTAINER (layout), child, "x", &x, "y", &y, NULL);
    
    parent = gtk_widget_get_parent (widget);
    if (layout != parent)
    {
        TEST_FAIL ("Widget is not added to GtkLayout container",NULL);
    }
    
    if (x != X)
    {
        TEST_FAIL ("The horizontal position is '%d',should be '%d'",x,X);
    }
    if (y != Y)
    {
        TEST_FAIL ("The vertical position is '%d',should be '%d'",y,Y);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (layout);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (layout));
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_put
 * Params: GtkLayout *layout,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: Adds child_widget to layout, at position (x,y).
 * Params Values: a newly created GtkLayout*, gtk_button_new_with_label ("Button"),1,1
 * Expected: void  
 */
static void test_purpose_15()
{
    #define WIDGET gtk_button_new_with_label ("Button")
    #define X 1
    #define Y 1
    
    GtkWidget *layout;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    layout =  gtk_layout_new (
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0)),
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
        );
    
    widget = WIDGET;
    
    gtk_layout_put (GTK_LAYOUT (layout), widget, X,Y);
    
    children = gtk_container_get_children (GTK_CONTAINER (layout)); 
    child = children->data; 
    
    gtk_container_child_get (GTK_CONTAINER (layout), child, "x", &x, "y", &y, NULL);
    
    parent = gtk_widget_get_parent (widget);
    if (layout != parent)
    {
        TEST_FAIL ("Widget is not added to GtkLayout container",NULL);
    }
    
    if (x != X)
    {
        TEST_FAIL ("The horizontal position is '%d',should be '%d'",x,X);
    }
    if (y != Y)
    {
        TEST_FAIL ("The vertical position is '%d',should be '%d'",y,Y);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (layout);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (layout));
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_put
 * Params: GtkLayout *layout,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: Adds child_widget to layout, at position (x,y).
 * Params Values: a newly created GtkLayout*, gtk_button_new_with_label ("Button"),1,100
 * Expected: void  
 */
static void test_purpose_16()
{
    #define WIDGET gtk_button_new_with_label ("Button")
    #define X 1
    #define Y 100
    
    GtkWidget *layout;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    layout =  gtk_layout_new (
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0)),
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
        );
    
    widget = WIDGET;
    
    gtk_layout_put (GTK_LAYOUT (layout), widget, X,Y);
    
    children = gtk_container_get_children (GTK_CONTAINER (layout)); 
    child = children->data; 
    
    gtk_container_child_get (GTK_CONTAINER (layout), child, "x", &x, "y", &y, NULL);
    
    parent = gtk_widget_get_parent (widget);
    if (layout != parent)
    {
        TEST_FAIL ("Widget is not added to GtkLayout container",NULL);
    }
    
    if (x != X)
    {
        TEST_FAIL ("The horizontal position is '%d',should be '%d'",x,X);
    }
    if (y != Y)
    {
        TEST_FAIL ("The vertical position is '%d',should be '%d'",y,Y);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (layout);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (layout));
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_put
 * Params: GtkLayout *layout,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: Adds child_widget to layout, at position (x,y).
 * Params Values: a newly created GtkLayout*, gtk_button_new_with_label ("Button"),1,1000
 * Expected: void  
 */
static void test_purpose_17()
{
    #define WIDGET gtk_button_new_with_label ("Button")
    #define X 1
    #define Y 1000
    
    GtkWidget *layout;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    layout =  gtk_layout_new (
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0)),
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
        );
    
    widget = WIDGET;
    
    gtk_layout_put (GTK_LAYOUT (layout), widget, X,Y);
    
    children = gtk_container_get_children (GTK_CONTAINER (layout)); 
    child = children->data; 
    
    gtk_container_child_get (GTK_CONTAINER (layout), child, "x", &x, "y", &y, NULL);
    
    parent = gtk_widget_get_parent (widget);
    if (layout != parent)
    {
        TEST_FAIL ("Widget is not added to GtkLayout container",NULL);
    }
    
    if (x != X)
    {
        TEST_FAIL ("The horizontal position is '%d',should be '%d'",x,X);
    }
    if (y != Y)
    {
        TEST_FAIL ("The vertical position is '%d',should be '%d'",y,Y);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (layout);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (layout));
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_put
 * Params: GtkLayout *layout,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: Adds child_widget to layout, at position (x,y).
 * Params Values: a newly created GtkLayout*, gtk_button_new_with_label ("Button"),G_MAXINT,G_MAXINT
 * Expected: void  
 */
static void test_purpose_18()
{
    #define WIDGET gtk_button_new_with_label ("Button")
    #define X G_MAXINT
    #define Y G_MAXINT
    
    GtkWidget *layout;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    layout =  gtk_layout_new (
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0)),
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
        );
    
    widget = WIDGET;
    
    gtk_layout_put (GTK_LAYOUT (layout), widget, X,Y);
    
    children = gtk_container_get_children (GTK_CONTAINER (layout)); 
    child = children->data; 
    
    gtk_container_child_get (GTK_CONTAINER (layout), child, "x", &x, "y", &y, NULL);
    
    parent = gtk_widget_get_parent (widget);
    if (layout != parent)
    {
        TEST_FAIL ("Widget is not added to GtkLayout container",NULL);
    }
    
    if (x != X)
    {
        TEST_FAIL ("The horizontal position is '%d',should be '%d'",x,X);
    }
    if (y != Y)
    {
        TEST_FAIL ("The vertical position is '%d',should be '%d'",y,Y);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (layout);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (layout));
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_put
 * Params: GtkLayout *layout,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: layout becomes the new parent container of child_widget.
 * Params Values: a newly created GtkLayout*, gtk_button_new_with_label ("Button"),10,20
 * Expected: void  
 */
static void test_purpose_19()
{
    #define WIDGET gtk_button_new_with_label ("Button")
    #define X 10
    #define Y 20
    
    GtkWidget *layout;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    layout =  gtk_layout_new (
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0)),
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
        );
    
    widget = WIDGET;
    
    gtk_layout_put (GTK_LAYOUT (layout), widget, X,Y);
    
    
    parent = gtk_widget_get_parent (widget);
    if (layout != parent)
    {
        TEST_FAIL ("Widget is not added to GtkLayout container",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (layout);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (layout));
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_move
 * Params: GtkLayout *layout,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: Moves a current child of layout to a new position.
 * Params Values: a newly created GtkLayout*, gtk_button_new_with_label ("Button"),10,20
 * Expected: void  
 */
static void test_purpose_20()
{
    #define WIDGET gtk_button_new_with_label ("Button")
    #define X 10
    #define Y 20
    
    GtkWidget *layout;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    layout =  gtk_layout_new (
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0)),
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
        );
    
    widget = WIDGET;
    
    gtk_layout_put (GTK_LAYOUT (layout), widget, 1,1);
    
    gtk_layout_move (GTK_LAYOUT (layout), widget, X,Y);
    
    children = gtk_container_get_children (GTK_CONTAINER (layout));
    child = children->data; 
    
    gtk_container_child_get (GTK_CONTAINER (layout), child, "x", &x, "y", &y, NULL);
    
    parent = gtk_widget_get_parent (widget);
    if (layout != parent)
    {
        TEST_FAIL ("Widget is not added to GtkLayout container",NULL);
    }
    
    if (x != X)
    {
        TEST_FAIL ("The horizontal position is '%d',should be '%d'",x,X);
    }
    if (y != Y)
    {
        TEST_FAIL ("The vertical position is '%d',should be '%d'",y,Y);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (layout);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (layout));
    
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_move
 * Params: GtkLayout *layout,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: Moves a current child of layout to a new position.
 * Params Values: a newly created GtkLayout*, gtk_button_new_with_label ("Button"),0,0
 * Expected: void  
 */
static void test_purpose_21()
{
    #define WIDGET gtk_button_new_with_label ("Button")
    #define X 0
    #define Y 0
    
    GtkWidget *layout;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    layout =  gtk_layout_new (
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0)),
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
        );
    
    widget = WIDGET;
    
    gtk_layout_put (GTK_LAYOUT (layout), widget, 1,1);
    
    gtk_layout_move (GTK_LAYOUT (layout), widget, X,Y);
    
    children = gtk_container_get_children (GTK_CONTAINER (layout));
    child = children->data; 
    
    gtk_container_child_get (GTK_CONTAINER (layout), child, "x", &x, "y", &y, NULL);
    
    parent = gtk_widget_get_parent (widget);
    if (layout != parent)
    {
        TEST_FAIL ("Widget is not added to GtkLayout container",NULL);
    }
    
    if (x != X)
    {
        TEST_FAIL ("The horizontal position is '%d',should be '%d'",x,X);
    }
    if (y != Y)
    {
        TEST_FAIL ("The vertical position is '%d',should be '%d'",y,Y);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (layout);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (layout));
    
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_move
 * Params: GtkLayout *layout,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: Moves a current child of layout to a new position.
 * Params Values: a newly created GtkLayout*, gtk_button_new_with_label ("Button"),1,1
 * Expected: void  
 */
static void test_purpose_22()
{
    #define WIDGET gtk_button_new_with_label ("Button")
    #define X 1
    #define Y 1
    
    GtkWidget *layout;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    layout =  gtk_layout_new (
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0)),
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
        );
    
    widget = WIDGET;
    
    gtk_layout_put (GTK_LAYOUT (layout), widget, 1,1);
    
    gtk_layout_move (GTK_LAYOUT (layout), widget, X,Y);
    
    children = gtk_container_get_children (GTK_CONTAINER (layout));
    child = children->data; 
    
    gtk_container_child_get (GTK_CONTAINER (layout), child, "x", &x, "y", &y, NULL);
    
    parent = gtk_widget_get_parent (widget);
    if (layout != parent)
    {
        TEST_FAIL ("Widget is not added to GtkLayout container",NULL);
    }
    
    if (x != X)
    {
        TEST_FAIL ("The horizontal position is '%d',should be '%d'",x,X);
    }
    if (y != Y)
    {
        TEST_FAIL ("The vertical position is '%d',should be '%d'",y,Y);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (layout);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (layout));
    
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_move
 * Params: GtkLayout *layout,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: Moves a current child of layout to a new position.
 * Params Values: a newly created GtkLayout*, gtk_button_new_with_label ("Button"),1,100
 * Expected: void  
 */
static void test_purpose_23()
{
    #define WIDGET gtk_button_new_with_label ("Button")
    #define X 1
    #define Y 100
    
    GtkWidget *layout;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    layout =  gtk_layout_new (
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0)),
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
        );
    
    widget = WIDGET;
    
    gtk_layout_put (GTK_LAYOUT (layout), widget, 1,1);
    
    gtk_layout_move (GTK_LAYOUT (layout), widget, X,Y);
    
    children = gtk_container_get_children (GTK_CONTAINER (layout));
    child = children->data; 
    
    gtk_container_child_get (GTK_CONTAINER (layout), child, "x", &x, "y", &y, NULL);
    
    parent = gtk_widget_get_parent (widget);
    if (layout != parent)
    {
        TEST_FAIL ("Widget is not added to GtkLayout container",NULL);
    }
    
    if (x != X)
    {
        TEST_FAIL ("The horizontal position is '%d',should be '%d'",x,X);
    }
    if (y != Y)
    {
        TEST_FAIL ("The vertical position is '%d',should be '%d'",y,Y);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (layout);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (layout));
    
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_move
 * Params: GtkLayout *layout,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: Moves a current child of layout to a new position.
 * Params Values: a newly created GtkLayout*, gtk_button_new_with_label ("Button"),1,1000
 * Expected: void  
 */
static void test_purpose_24()
{
    #define WIDGET gtk_button_new_with_label ("Button")
    #define X 1
    #define Y 1000
    
    GtkWidget *layout;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    layout =  gtk_layout_new (
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0)),
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
        );
    
    widget = WIDGET;
    
    gtk_layout_put (GTK_LAYOUT (layout), widget, 1,1);
    
    gtk_layout_move (GTK_LAYOUT (layout), widget, X,Y);
    
    children = gtk_container_get_children (GTK_CONTAINER (layout));
    child = children->data; 
    
    gtk_container_child_get (GTK_CONTAINER (layout), child, "x", &x, "y", &y, NULL);
    
    parent = gtk_widget_get_parent (widget);
    if (layout != parent)
    {
        TEST_FAIL ("Widget is not added to GtkLayout container",NULL);
    }
    
    if (x != X)
    {
        TEST_FAIL ("The horizontal position is '%d',should be '%d'",x,X);
    }
    if (y != Y)
    {
        TEST_FAIL ("The vertical position is '%d',should be '%d'",y,Y);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (layout);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (layout));
    
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_layout_move
 * Params: GtkLayout *layout,GtkWidget *widget,gint x,gint y
 * Returns: void
 * Assertion: Moves a current child of layout to a new position.
 * Params Values: a newly created GtkLayout*, gtk_button_new_with_label ("Button"),G_MAXINT,G_MAXINT
 * Expected: void  
 */
static void test_purpose_25()
{
    #define WIDGET gtk_button_new_with_label ("Button")
    #define X G_MAXINT
    #define Y G_MAXINT
    
    GtkWidget *layout;
    GtkWidget *widget;
    GList* children;
    GtkWidget* child;
    GtkWidget* parent;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    layout =  gtk_layout_new (
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0)),
        GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 5.0, 20.0, 50.0))
        );
    
    widget = WIDGET;
    
    gtk_layout_put (GTK_LAYOUT (layout), widget, 1,1);
    
    gtk_layout_move (GTK_LAYOUT (layout), widget, X,Y);
    
    children = gtk_container_get_children (GTK_CONTAINER (layout));
    child = children->data; 
    
    gtk_container_child_get (GTK_CONTAINER (layout), child, "x", &x, "y", &y, NULL);
    
    parent = gtk_widget_get_parent (widget);
    if (layout != parent)
    {
        TEST_FAIL ("Widget is not added to GtkLayout container",NULL);
    }
    
    if (x != X)
    {
        TEST_FAIL ("The horizontal position is '%d',should be '%d'",x,X);
    }
    if (y != Y)
    {
        TEST_FAIL ("The vertical position is '%d',should be '%d'",y,Y);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (layout);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (layout));
    
    #undef WIDGET 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkLayout ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {NULL,0}
};
