/*
 * GtkRadioButton methods tests
 * Testing GtkRadioButton methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_radio_button_new
 * Params: GSList *group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton.
 * Params Values: NULL
 * Expected: GtkRadioButton*  
 */
static void test_purpose_1()
{
    #define    GROUP NULL
    
    GtkWidget* widget;
    GSList*    group;
    
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GROUP;
    widget = gtk_radio_button_new (group);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  GROUP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_from_widget
 * Params: GtkRadioButton *group
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton, adding it to the same group as group.
 * Params Values: <%0%>
 * Expected: GtkRadioButton*  
 */
static void test_purpose_2()
{
    GtkWidget* widget;
    GtkRadioButton*    group;
    GSList *group1;
    GSList *group2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = GTK_RADIO_BUTTON (gtk_radio_button_new(NULL));
    
    widget = gtk_radio_button_new_from_widget (group);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    group1 = gtk_radio_button_get_group (group);
    group2 = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
    
    if (group1 != group2)
    {
        TEST_FAIL ("radio button was added to another group", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_label
 * Params: GSList *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton with a text label.
 * Params Values: NULL, NULL
 * Expected: GtkRadioButton*  
 */
static void test_purpose_3()
{
    #define    LABEL NULL
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_radio_button_new_with_label (NULL, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_label
 * Params: GSList *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton with a text label.
 * Params Values: NULL, ""
 * Expected: GtkRadioButton*  
 */
static void test_purpose_4()
{
    #define    LABEL ""
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_radio_button_new_with_label (NULL, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_label
 * Params: GSList *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton with a text label.
 * Params Values: NULL, "!@#$%^&*"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_5()
{
    #define    LABEL "!@#$%^&*"
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_radio_button_new_with_label (NULL, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_label
 * Params: GSList *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton with a text label.
 * Params Values: NULL, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ12345678"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_6()
{
    #define    LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ12345678"
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_radio_button_new_with_label (NULL, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_label
 * Params: GSList *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton with a text label.
 * Params Values: NULL, "Label"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_7()
{
    #define    LABEL "Label"
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_radio_button_new_with_label (NULL, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_label_from_widget
 * Params: GtkRadioButton *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton with a text label, adding it to the same group as group.
 * Params Values: gtk_radio_button_new(NULL), NULL
 * Expected: GtkRadioButton*  
 */
static void test_purpose_8()
{
    #define    GROUP gtk_radio_button_new(NULL)
    #define    LABEL NULL
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    GtkRadioButton*  gr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (GROUP)
    {
        gr = GTK_RADIO_BUTTON (GROUP);
    } else {
        gr = NULL;
    }
    
    widget = gtk_radio_button_new_with_label_from_widget (gr, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  GROUP
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_label_from_widget
 * Params: GtkRadioButton *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton with a text label, adding it to the same group as group.
 * Params Values: gtk_radio_button_new(NULL), ""
 * Expected: GtkRadioButton*  
 */
static void test_purpose_9()
{
    #define    GROUP gtk_radio_button_new(NULL)
    #define    LABEL ""
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    GtkRadioButton*  gr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (GROUP)
    {
        gr = GTK_RADIO_BUTTON (GROUP);
    } else {
        gr = NULL;
    }
    
    widget = gtk_radio_button_new_with_label_from_widget (gr, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  GROUP
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_label_from_widget
 * Params: GtkRadioButton *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton with a text label, adding it to the same group as group.
 * Params Values: gtk_radio_button_new(NULL), "Label"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_10()
{
    #define    GROUP gtk_radio_button_new(NULL)
    #define    LABEL "Label"
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    GtkRadioButton*  gr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (GROUP)
    {
        gr = GTK_RADIO_BUTTON (GROUP);
    } else {
        gr = NULL;
    }
    
    widget = gtk_radio_button_new_with_label_from_widget (gr, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  GROUP
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_label_from_widget
 * Params: GtkRadioButton *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton with a text label, adding it to the same group as group.
 * Params Values: gtk_radio_button_new(NULL), "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ12345678"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_11()
{
    #define    GROUP gtk_radio_button_new(NULL)
    #define    LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ12345678"
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    GtkRadioButton*  gr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (GROUP)
    {
        gr = GTK_RADIO_BUTTON (GROUP);
    } else {
        gr = NULL;
    }
    
    widget = gtk_radio_button_new_with_label_from_widget (gr, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  GROUP
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_label_from_widget
 * Params: GtkRadioButton *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton with a text label, adding it to the same group as group.
 * Params Values: gtk_radio_button_new(NULL), "!@#$%^&*"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_12()
{
    #define    GROUP gtk_radio_button_new(NULL)
    #define    LABEL "!@#$%^&*"
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    GtkRadioButton*  gr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (GROUP)
    {
        gr = GTK_RADIO_BUTTON (GROUP);
    } else {
        gr = NULL;
    }
    
    widget = gtk_radio_button_new_with_label_from_widget (gr, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  GROUP
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton containing a label, adding it to the same group as group.
 * Params Values: NULL, NULL
 * Expected: GtkRadioButton*  
 */
static void test_purpose_13()
{
    #define    LABEL NULL
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_radio_button_new_with_mnemonic (NULL, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton containing a label, adding it to the same group as group.
 * Params Values: NULL, ""
 * Expected: GtkRadioButton*  
 */
static void test_purpose_14()
{
    #define    LABEL ""
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_radio_button_new_with_mnemonic (NULL, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton containing a label, adding it to the same group as group.
 * Params Values: NULL, "!@#$%^&*"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_15()
{
    #define    LABEL "!@#$%^&*"
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_radio_button_new_with_mnemonic (NULL, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton containing a label, adding it to the same group as group.
 * Params Values: NULL, "!_@#$%^&*"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_16()
{
    #define    LABEL "!_@#$%^&*"
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_radio_button_new_with_mnemonic (NULL, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton containing a label, adding it to the same group as group.
 * Params Values: NULL, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ12345678"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_17()
{
    #define    LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ12345678"
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_radio_button_new_with_mnemonic (NULL, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton containing a label, adding it to the same group as group.
 * Params Values: NULL, "abcdefghijk_lmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ12345678"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_18()
{
    #define    LABEL "abcdefghijk_lmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ12345678"
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_radio_button_new_with_mnemonic (NULL, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton containing a label, adding it to the same group as group.
 * Params Values: NULL, "Label"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_19()
{
    #define    LABEL "Label"
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_radio_button_new_with_mnemonic (NULL, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton containing a label, adding it to the same group as group.
 * Params Values: NULL, "Lab_el"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_20()
{
    #define    LABEL "Lab_el"
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_radio_button_new_with_mnemonic (NULL, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion:  The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the button.
 * Params Values: NULL, "Te_xt"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_21()
{
    #define    LABEL "Te_xt"
    #define    KEY GDK_x
    
    GtkWidget* widget;
    GtkWidget* child;
    guint keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_radio_button_new_with_mnemonic (NULL, LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    keyval = gtk_label_get_mnemonic_keyval (GTK_LABEL (child));
    if (keyval != KEY)
    {
        TEST_FAIL ("keyval = %i, should be %i", keyval, KEY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion:  The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the button.
 * Params Values: NULL, "_Text"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_22()
{
    #define    LABEL "_Text"
    #define    KEY GDK_t
    
    GtkWidget* widget;
    GtkWidget* child;
    guint keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_radio_button_new_with_mnemonic (NULL, LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    keyval = gtk_label_get_mnemonic_keyval (GTK_LABEL (child));
    if (keyval != KEY)
    {
        TEST_FAIL ("keyval = %i, should be %i", keyval, KEY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic
 * Params: GSList *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion:  The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the button.
 * Params Values: NULL, "T_ext"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_23()
{
    #define    LABEL "T_ext"
    #define    KEY GDK_e
    
    GtkWidget* widget;
    GtkWidget* child;
    guint keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_radio_button_new_with_mnemonic (NULL, LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    keyval = gtk_label_get_mnemonic_keyval (GTK_LABEL (child));
    if (keyval != KEY)
    {
        TEST_FAIL ("keyval = %i, should be %i", keyval, KEY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic_from_widget
 * Params: GtkRadioButton *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton containing a label.
 * Params Values: gtk_radio_button_new(NULL), NULL
 * Expected: GtkRadioButton*  
 */
static void test_purpose_24()
{
    #define    GROUP gtk_radio_button_new(NULL)
    #define    LABEL NULL
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    GtkRadioButton*  gr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (GROUP)
    {
        gr = GTK_RADIO_BUTTON (GROUP);
    } else {
        gr = NULL;
    }
    
    widget = gtk_radio_button_new_with_mnemonic_from_widget (gr, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  GROUP
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic_from_widget
 * Params: GtkRadioButton *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton containing a label.
 * Params Values: gtk_radio_button_new(NULL), ""
 * Expected: GtkRadioButton*  
 */
static void test_purpose_25()
{
    #define    GROUP gtk_radio_button_new(NULL)
    #define    LABEL ""
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    GtkRadioButton*  gr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (GROUP)
    {
        gr = GTK_RADIO_BUTTON (GROUP);
    } else {
        gr = NULL;
    }
    
    widget = gtk_radio_button_new_with_mnemonic_from_widget (gr, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  GROUP
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic_from_widget
 * Params: GtkRadioButton *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton containing a label.
 * Params Values: gtk_radio_button_new(NULL), "Label"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_26()
{
    #define    GROUP gtk_radio_button_new(NULL)
    #define    LABEL "Label"
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    GtkRadioButton*  gr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (GROUP)
    {
        gr = GTK_RADIO_BUTTON (GROUP);
    } else {
        gr = NULL;
    }
    
    widget = gtk_radio_button_new_with_mnemonic_from_widget (gr, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  GROUP
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic_from_widget
 * Params: GtkRadioButton *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton containing a label.
 * Params Values: gtk_radio_button_new(NULL), "Lab_el"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_27()
{
    #define    GROUP gtk_radio_button_new(NULL)
    #define    LABEL "Lab_el"
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    GtkRadioButton*  gr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (GROUP)
    {
        gr = GTK_RADIO_BUTTON (GROUP);
    } else {
        gr = NULL;
    }
    
    widget = gtk_radio_button_new_with_mnemonic_from_widget (gr, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  GROUP
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic_from_widget
 * Params: GtkRadioButton *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton containing a label.
 * Params Values: gtk_radio_button_new(NULL), "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ12345678"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_28()
{
    #define    GROUP gtk_radio_button_new(NULL)
    #define    LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ12345678"
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    GtkRadioButton*  gr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (GROUP)
    {
        gr = GTK_RADIO_BUTTON (GROUP);
    } else {
        gr = NULL;
    }
    
    widget = gtk_radio_button_new_with_mnemonic_from_widget (gr, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  GROUP
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic_from_widget
 * Params: GtkRadioButton *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton containing a label.
 * Params Values: gtk_radio_button_new(NULL), "abcdefghijklmnopqrstuvwxy_zABCDEFGHIJKLMNOPQRSTUVWXYZ12345678"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_29()
{
    #define    GROUP gtk_radio_button_new(NULL)
    #define    LABEL "abcdefghijklmnopqrstuvwxy_zABCDEFGHIJKLMNOPQRSTUVWXYZ12345678"
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    GtkRadioButton*  gr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (GROUP)
    {
        gr = GTK_RADIO_BUTTON (GROUP);
    } else {
        gr = NULL;
    }
    
    widget = gtk_radio_button_new_with_mnemonic_from_widget (gr, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  GROUP
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic_from_widget
 * Params: GtkRadioButton *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton containing a label.
 * Params Values: gtk_radio_button_new(NULL), "!@#$%^&*"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_30()
{
    #define    GROUP gtk_radio_button_new(NULL)
    #define    LABEL "!@#$%^&*"
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    GtkRadioButton*  gr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (GROUP)
    {
        gr = GTK_RADIO_BUTTON (GROUP);
    } else {
        gr = NULL;
    }
    
    widget = gtk_radio_button_new_with_mnemonic_from_widget (gr, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  GROUP
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic_from_widget
 * Params: GtkRadioButton *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkRadioButton containing a label.
 * Params Values: gtk_radio_button_new(NULL), "!@#_$_%^&*"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_31()
{
    #define    GROUP gtk_radio_button_new(NULL)
    #define    LABEL "!@#_$_%^&*"
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    gchararray real_label;
    GtkRadioButton*  gr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (GROUP)
    {
        gr = GTK_RADIO_BUTTON (GROUP);
    } else {
        gr = NULL;
    }
    
    widget = gtk_radio_button_new_with_mnemonic_from_widget (gr, LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("radio button child should be of type GtkLabel", NULL);
        }
    } else {
        if (child)
        {
            TEST_FAIL ("radio button child should be NULL", NULL);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "label", &real_label, NULL);
    if (!LABEL)
    {
        if (real_label)
        {
            TEST_FAIL ("real label is not NULL but should be", NULL);
        }
    } else {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL, should be '%s'", LABEL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, LABEL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  GROUP
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic_from_widget
 * Params: GtkRadioButton *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the button.
 * Params Values: gtk_radio_button_new(NULL), "Te_xt"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_32()
{
    #define    GROUP gtk_radio_button_new(NULL)
    #define    LABEL "Te_xt"
    #define    KEY GDK_x
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    GtkRadioButton*  gr;
    guint keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (GROUP)
    {
        gr = GTK_RADIO_BUTTON (GROUP);
    } else {
        gr = NULL;
    }
    
    widget = gtk_radio_button_new_with_mnemonic_from_widget (gr, LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    keyval = gtk_label_get_mnemonic_keyval (GTK_LABEL (child));
    if (keyval != KEY)
    {
        TEST_FAIL ("keyval = %i, should be %i", keyval, KEY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  GROUP
    #undef  LABEL
    #undef  KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic_from_widget
 * Params: GtkRadioButton *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the button.
 * Params Values: gtk_radio_button_new(NULL), "_Text"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_33()
{
    #define    GROUP gtk_radio_button_new(NULL)
    #define    LABEL "_Text"
    #define    KEY GDK_t
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    GtkRadioButton*  gr;
    guint keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (GROUP)
    {
        gr = GTK_RADIO_BUTTON (GROUP);
    } else {
        gr = NULL;
    }
    
    widget = gtk_radio_button_new_with_mnemonic_from_widget (gr, LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    keyval = gtk_label_get_mnemonic_keyval (GTK_LABEL (child));
    if (keyval != KEY)
    {
        TEST_FAIL ("keyval = %i, should be %i", keyval, KEY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  GROUP
    #undef  LABEL
    #undef  KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_radio_button_new_with_mnemonic_from_widget
 * Params: GtkRadioButton *group, const gchar *label
 * Returns: GtkWidget*
 * Assertion: The label will be created using gtk_label_new_with_mnemonic(), so underscores in label indicate the mnemonic for the button.
 * Params Values: gtk_radio_button_new(NULL), "T_ext"
 * Expected: GtkRadioButton*  
 */
static void test_purpose_34()
{
    #define    GROUP gtk_radio_button_new(NULL)
    #define    LABEL "T_ext"
    #define    KEY GDK_e
    
    GtkWidget* widget;
    GSList*    group;
    GtkWidget* child;
    GtkRadioButton*  gr;
    guint keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if (GROUP)
    {
        gr = GTK_RADIO_BUTTON (GROUP);
    } else {
        gr = NULL;
    }
    
    widget = gtk_radio_button_new_with_mnemonic_from_widget (gr, LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    keyval = gtk_label_get_mnemonic_keyval (GTK_LABEL (child));
    if (keyval != KEY)
    {
        TEST_FAIL ("keyval = %i, should be %i", keyval, KEY);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  GROUP
    #undef  LABEL
    #undef  KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_radio_button_set_group
 * Params: GtkRadioButton *radio_button
 * Returns: GSList*
 * Assertion: Sets a GtkRadioButton's group.'
 * Params Values: a newly created GtkRadioButton
 * Expected: GSList*
 * 
 * Name:   gtk_radio_button_get_group
 * Params: GtkRadioButton *radio_button, GSList *group
 * Returns: void
 * Assertion: Retrieves the group assigned to a radio button.
 * Params Values: a newly created GtkRadioButton, GSList*
 * Expected: void  
 */
static void test_purpose_35()
{
    #define    COUNT 10
    #define    OTHER 9
    
    GSList*    group;
    GSList*    group_value;
    GtkWidget* buttons[COUNT];
    GtkWidget* widget;
    GtkWidget* widget1;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_radio_button_new (NULL);
    widget1 = gtk_radio_button_new (NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < COUNT; i++)
    {
        buttons[i] = gtk_radio_button_new_from_widget (GTK_RADIO_BUTTON (widget));
        if (!buttons[i])
        {
            TEST_FAIL (get_not_created_msg (), NULL);
            return;
        }
        if (!GTK_IS_RADIO_BUTTON (buttons[i]))
        {
            TEST_FAIL (get_wrong_type_msg (), NULL);
            return;
        }
    }
    
    for (i = 0; i < COUNT; i++)
    {
        if (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget)) != gtk_radio_button_get_group (GTK_RADIO_BUTTON (buttons[i])))
        {
            TEST_FAIL ("group of  buttons[%i] = %p wrong", i, gtk_radio_button_get_group (GTK_RADIO_BUTTON (buttons[i])));
        }
    }
    
    for (i = 0; i < OTHER; i++)
    {
        gtk_radio_button_set_group (GTK_RADIO_BUTTON (buttons[i]), gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget1)));
    }
    
    for (i = 0; i < OTHER; i++)
    {
        if (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget1)) != gtk_radio_button_get_group (GTK_RADIO_BUTTON (buttons[i])))
        {
            TEST_FAIL ("group of  buttons[%i] = %p wrong", i, gtk_radio_button_get_group (GTK_RADIO_BUTTON (buttons[i])));
        }
    }
    
    if (g_slist_length (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget1))) != OTHER + 1)
    {
        TEST_FAIL ("changed list count = %i, should be %i", g_slist_length (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget1))), OTHER + 1);
    }
    
    for (i = OTHER; i < COUNT; i++)
    {
        if (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget)) != gtk_radio_button_get_group (GTK_RADIO_BUTTON (buttons[i])))
        {
            TEST_FAIL ("group of  buttons[%i] = %p wrong", i, gtk_radio_button_get_group (GTK_RADIO_BUTTON (buttons[i])));
        }
    }
    
    if (g_slist_length (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget))) != (COUNT - OTHER + 1))
    {
        TEST_FAIL ("list count = %i, should be %i", g_slist_length (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget1))), COUNT - OTHER + 1);
    }
    
    
    #undef    COUNT
    #undef    OTHER
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_radio_button_set_group
 * Params: GtkRadioButton *radio_button
 * Returns: GSList*
 * Assertion: Sets a GtkRadioButton's group.'
 * Params Values: a newly created GtkRadioButton
 * Expected: GSList*
 * 
 * Name:   gtk_radio_button_get_group
 * Params: GtkRadioButton *radio_button, GSList *group
 * Returns: void
 * Assertion: Retrieves the group assigned to a radio button.
 * Params Values: a newly created GtkRadioButton, GSList*
 * Expected: void  
 */
static void test_purpose_36()
{
    #define    COUNT 20
    #define    OTHER 2
    
    GSList*    group;
    GSList*    group_value;
    GtkWidget* buttons[COUNT];
    GtkWidget* widget;
    GtkWidget* widget1;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_radio_button_new (NULL);
    widget1 = gtk_radio_button_new (NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < COUNT; i++)
    {
        buttons[i] = gtk_radio_button_new_from_widget (GTK_RADIO_BUTTON (widget));
        if (!buttons[i])
        {
            TEST_FAIL (get_not_created_msg (), NULL);
            return;
        }
        if (!GTK_IS_RADIO_BUTTON (buttons[i]))
        {
            TEST_FAIL (get_wrong_type_msg (), NULL);
            return;
        }
    }
    
    for (i = 0; i < COUNT; i++)
    {
        if (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget)) != gtk_radio_button_get_group (GTK_RADIO_BUTTON (buttons[i])))
        {
            TEST_FAIL ("group of  buttons[%i] = %p wrong", i, gtk_radio_button_get_group (GTK_RADIO_BUTTON (buttons[i])));
        }
    }
    
    for (i = 0; i < OTHER; i++)
    {
        gtk_radio_button_set_group (GTK_RADIO_BUTTON (buttons[i]), gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget1)));
    }
    
    for (i = 0; i < OTHER; i++)
    {
        if (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget1)) != gtk_radio_button_get_group (GTK_RADIO_BUTTON (buttons[i])))
        {
            TEST_FAIL ("group of  buttons[%i] = %p wrong", i, gtk_radio_button_get_group (GTK_RADIO_BUTTON (buttons[i])));
        }
    }
    
    if (g_slist_length (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget1))) != OTHER + 1)
    {
        TEST_FAIL ("changed list count = %i, should be %i", g_slist_length (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget1))), OTHER + 1);
    }
    
    for (i = OTHER; i < COUNT; i++)
    {
        if (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget)) != gtk_radio_button_get_group (GTK_RADIO_BUTTON (buttons[i])))
        {
            TEST_FAIL ("group of  buttons[%i] = %p wrong", i, gtk_radio_button_get_group (GTK_RADIO_BUTTON (buttons[i])));
        }
    }
    
    if (g_slist_length (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget))) != (COUNT - OTHER + 1))
    {
        TEST_FAIL ("list count = %i, should be %i", g_slist_length (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget1))), COUNT - OTHER + 1);
    }
    
    
    #undef    COUNT
    #undef    OTHER
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_radio_button_set_group
 * Params: GtkRadioButton *radio_button
 * Returns: GSList*
 * Assertion: Sets a GtkRadioButton's group.'
 * Params Values: a newly created GtkRadioButton
 * Expected: GSList*
 * 
 * Name:   gtk_radio_button_get_group
 * Params: GtkRadioButton *radio_button, GSList *group
 * Returns: void
 * Assertion: Retrieves the group assigned to a radio button.
 * Params Values: a newly created GtkRadioButton, GSList*
 * Expected: void  
 */
static void test_purpose_37()
{
    #define    COUNT 200
    #define    OTHER 10
    
    GSList*    group;
    GSList*    group_value;
    GtkWidget* buttons[COUNT];
    GtkWidget* widget;
    GtkWidget* widget1;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_radio_button_new (NULL);
    widget1 = gtk_radio_button_new (NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_RADIO_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < COUNT; i++)
    {
        buttons[i] = gtk_radio_button_new_from_widget (GTK_RADIO_BUTTON (widget));
        if (!buttons[i])
        {
            TEST_FAIL (get_not_created_msg (), NULL);
            return;
        }
        if (!GTK_IS_RADIO_BUTTON (buttons[i]))
        {
            TEST_FAIL (get_wrong_type_msg (), NULL);
            return;
        }
    }
    
    for (i = 0; i < COUNT; i++)
    {
        if (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget)) != gtk_radio_button_get_group (GTK_RADIO_BUTTON (buttons[i])))
        {
            TEST_FAIL ("group of  buttons[%i] = %p wrong", i, gtk_radio_button_get_group (GTK_RADIO_BUTTON (buttons[i])));
        }
    }
    
    for (i = 0; i < OTHER; i++)
    {
        gtk_radio_button_set_group (GTK_RADIO_BUTTON (buttons[i]), gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget1)));
    }
    
    for (i = 0; i < OTHER; i++)
    {
        if (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget1)) != gtk_radio_button_get_group (GTK_RADIO_BUTTON (buttons[i])))
        {
            TEST_FAIL ("group of  buttons[%i] = %p wrong", i, gtk_radio_button_get_group (GTK_RADIO_BUTTON (buttons[i])));
        }
    }
    
    if (g_slist_length (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget1))) != OTHER + 1)
    {
        TEST_FAIL ("changed list count = %i, should be %i", g_slist_length (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget1))), OTHER + 1);
    }
    
    for (i = OTHER; i < COUNT; i++)
    {
        if (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget)) != gtk_radio_button_get_group (GTK_RADIO_BUTTON (buttons[i])))
        {
            TEST_FAIL ("group of  buttons[%i] = %p wrong", i, gtk_radio_button_get_group (GTK_RADIO_BUTTON (buttons[i])));
        }
    }
    
    if (g_slist_length (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget))) != (COUNT - OTHER + 1))
    {
        TEST_FAIL ("list count = %i, should be %i", g_slist_length (gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget1))), COUNT - OTHER + 1);
    }
    
    
    #undef    COUNT
    #undef    OTHER
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkRadioButton ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {NULL,0}
};
