/*
 * GtkTextMark methods tests
 * Testing GtkTextMark methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name:  gtk_text_mark_set_visible
 * Params: GtkTextMark *mark, gboolean setting
 * Returns: void
 * Assertion: Sets the visibility of mark; the insertion point is normally visible, i.e. you can see it as a vertical bar.
 * Params Values: a newly created GtkTextMark with name "Text", TRUE
 * Expected: void
 * 
 * Name:  gtk_text_mark_get_visible
 * Params: GtkTextMark *mark
 * Returns: gboolean
 * Assertion: Returns TRUE if the mark is visible (i.e. a cursor is displayed for it)
 * Params Values: a newly created GtkTextMark with name "Text"
 * Expected: TRUE  
 */
static void test_purpose_1()
{
    #define MARK_NAME  "Text"
    #define SETTING TRUE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    mark = gtk_text_buffer_create_mark (buffer, MARK_NAME, &start, FALSE);
    
    gtk_text_mark_set_visible (mark, SETTING);
    visible = gtk_text_mark_get_visible (mark);
    
    if (visible != SETTING)
    {
        TEST_FAIL ("visible = %d, should be %d", visible, SETTING);
    }
    
    #undef MARK_NAME
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_mark_set_visible
 * Params: GtkTextMark *mark, gboolean setting
 * Returns: void
 * Assertion: Sets the visibility of mark; the insertion point is normally visible, i.e. you can see it as a vertical bar.
 * Params Values: a newly created GtkTextMark with name "Text", FALSE
 * Expected: void
 * 
 * Name:  gtk_text_mark_get_visible
 * Params: GtkTextMark *mark
 * Returns: gboolean
 * Assertion: Returns TRUE if the mark is visible (i.e. a cursor is displayed for it)
 * Params Values: a newly created GtkTextMark with name "Text"
 * Expected: FALSE  
 */
static void test_purpose_2()
{
    #define MARK_NAME  "Text"
    #define SETTING FALSE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    mark = gtk_text_buffer_create_mark (buffer, MARK_NAME, &start, FALSE);
    
    gtk_text_mark_set_visible (mark, SETTING);
    visible = gtk_text_mark_get_visible (mark);
    
    if (visible != SETTING)
    {
        TEST_FAIL ("visible = %d, should be %d", visible, SETTING);
    }
    
    #undef MARK_NAME
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_mark_set_visible
 * Params: GtkTextMark *mark, gboolean setting
 * Returns: void
 * Assertion: Marks are not visible by default.
 * Params Values: a newly created GtkTextMark with name "Text", TRUE
 * Expected: void  
 */
static void test_purpose_3()
{
    #define MARK_NAME  "Text"
    #define SETTING TRUE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    mark = gtk_text_buffer_create_mark (buffer, MARK_NAME, &start, FALSE);
    
    visible = gtk_text_mark_get_visible (mark);
    if (visible != FALSE)
    {
        TEST_FAIL ("marks are not visible by default", NULL);
    }
    
    gtk_text_mark_set_visible (mark, SETTING);
    visible = gtk_text_mark_get_visible (mark);
    
    if (visible != SETTING)
    {
        TEST_FAIL ("visible = %d, should be %d", visible, SETTING);
    }
    
    #undef MARK_NAME
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_mark_get_deleted
 * Params: GtkTextMark *mark
 * Returns: gboolean
 * Assertion: Returns TRUE if the mark has been removed from its buffer with gtk_text_buffer_delete_mark().
 * Params Values: a newly created GtkTextMark with name "Text"
 * Expected: TRUE  
 */
static void test_purpose_4()
{
    #define MARK_NAME  "Text"
    #define DELETED TRUE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    gboolean deleted;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    mark = gtk_text_buffer_create_mark (buffer, MARK_NAME, &start, FALSE);
    g_object_ref (mark);
    
    if (DELETED)
    {
        gtk_text_buffer_delete_mark (buffer, mark);
    }
    
    deleted = gtk_text_mark_get_deleted (mark);
    if (deleted != DELETED)
    {
        TEST_FAIL ("deleted = %d, should be %d", deleted, DELETED);
    }
    
    #undef MARK_NAME
    #undef DELETED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_mark_get_deleted
 * Params: GtkTextMark *mark
 * Returns: gboolean
 * Assertion: Returns TRUE if the mark has been removed from its buffer with gtk_text_buffer_delete_mark().
 * Params Values: a newly created GtkTextMark with name "Text"
 * Expected: FALSE  
 */
static void test_purpose_5()
{
    #define MARK_NAME  "Text"
    #define DELETED FALSE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    gboolean deleted;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    mark = gtk_text_buffer_create_mark (buffer, MARK_NAME, &start, FALSE);
    g_object_ref (mark);
    
    if (DELETED)
    {
        gtk_text_buffer_delete_mark (buffer, mark);
    }
    
    deleted = gtk_text_mark_get_deleted (mark);
    if (deleted != DELETED)
    {
        TEST_FAIL ("deleted = %d, should be %d", deleted, DELETED);
    }
    
    #undef MARK_NAME
    #undef DELETED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_mark_get_name 
 * Params: GtkTextMark *mark
 * Returns: const char*
 * Assertion: Returns the mark name; returns NULL for anonymous marks.
 * Params Values: a newly created GtkTextMark with name NULL
 * Expected: NULL  
 */
static void test_purpose_6()
{
    #define MARK_NAME  NULL
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    const char* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    mark = gtk_text_buffer_create_mark (buffer, MARK_NAME, &start, FALSE);
    name = gtk_text_mark_get_name (mark);
    
    if (MARK_NAME == NULL)
    {
        if (name != NULL)
        {
            TEST_FAIL ("gtk_text_mark_get_name() should return NULL for anonymous marks", NULL);
        }
    } else {
        if (name == NULL)
        {
            TEST_FAIL ("gtk_text_mark_get_name() should return not NULL for non-anonymous marks", NULL);
        } else {
            if (strcmp (name, (char*) (MARK_NAME)))
            {
                TEST_FAIL ("name is %s, should be %s", name, MARK_NAME);
            }
        }
    }
    
    #undef MARK_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_mark_get_name 
 * Params: GtkTextMark *mark
 * Returns: const char*
 * Assertion: Returns the mark name; returns NULL for anonymous marks.
 * Params Values: a newly created GtkTextMark with name "Text"
 * Expected: "Text"  
 */
static void test_purpose_7()
{
    #define MARK_NAME  "Text"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    const char* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    mark = gtk_text_buffer_create_mark (buffer, MARK_NAME, &start, FALSE);
    name = gtk_text_mark_get_name (mark);
    
    if (MARK_NAME == NULL)
    {
        if (name != NULL)
        {
            TEST_FAIL ("gtk_text_mark_get_name() should return NULL for anonymous marks", NULL);
        }
    } else {
        if (name == NULL)
        {
            TEST_FAIL ("gtk_text_mark_get_name() should return not NULL for non-anonymous marks", NULL);
        } else {
            if (strcmp (name, (char*) (MARK_NAME)))
            {
                TEST_FAIL ("name is %s, should be %s", name, MARK_NAME);
            }
        }
    }
    
    #undef MARK_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_mark_get_name 
 * Params: GtkTextMark *mark
 * Returns: const char*
 * Assertion: Returns the mark name; returns NULL for anonymous marks.
 * Params Values: a newly created GtkTextMark with name "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"  
 */
static void test_purpose_8()
{
    #define MARK_NAME  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    const char* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    mark = gtk_text_buffer_create_mark (buffer, MARK_NAME, &start, FALSE);
    name = gtk_text_mark_get_name (mark);
    
    if (MARK_NAME == NULL)
    {
        if (name != NULL)
        {
            TEST_FAIL ("gtk_text_mark_get_name() should return NULL for anonymous marks", NULL);
        }
    } else {
        if (name == NULL)
        {
            TEST_FAIL ("gtk_text_mark_get_name() should return not NULL for non-anonymous marks", NULL);
        } else {
            if (strcmp (name, (char*) (MARK_NAME)))
            {
                TEST_FAIL ("name is %s, should be %s", name, MARK_NAME);
            }
        }
    }
    
    #undef MARK_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_mark_get_name 
 * Params: GtkTextMark *mark
 * Returns: const char*
 * Assertion: Returns the mark name; returns NULL for anonymous marks.
 * Params Values: a newly created GtkTextMark with name "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: "!@#$%^&*()_+|~=\";:'?<>`/"  
 */
static void test_purpose_9()
{
    #define MARK_NAME  "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    const char* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    mark = gtk_text_buffer_create_mark (buffer, MARK_NAME, &start, FALSE);
    name = gtk_text_mark_get_name (mark);
    
    if (MARK_NAME == NULL)
    {
        if (name != NULL)
        {
            TEST_FAIL ("gtk_text_mark_get_name() should return NULL for anonymous marks", NULL);
        }
    } else {
        if (name == NULL)
        {
            TEST_FAIL ("gtk_text_mark_get_name() should return not NULL for non-anonymous marks", NULL);
        } else {
            if (strcmp (name, (char*) (MARK_NAME)))
            {
                TEST_FAIL ("name is %s, should be %s", name, MARK_NAME);
            }
        }
    }
    
    #undef MARK_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_mark_get_name 
 * Params: GtkTextMark *mark
 * Returns: const char*
 * Assertion: Returns the mark name; returns NULL for anonymous marks.
 * Params Values: a newly created GtkTextMark with name "\b\n\t"
 * Expected: "\b\n\t"  
 */
static void test_purpose_10()
{
    #define MARK_NAME  "\b\n\t"
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    const char* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    mark = gtk_text_buffer_create_mark (buffer, MARK_NAME, &start, FALSE);
    name = gtk_text_mark_get_name (mark);
    
    if (MARK_NAME == NULL)
    {
        if (name != NULL)
        {
            TEST_FAIL ("gtk_text_mark_get_name() should return NULL for anonymous marks", NULL);
        }
    } else {
        if (name == NULL)
        {
            TEST_FAIL ("gtk_text_mark_get_name() should return not NULL for non-anonymous marks", NULL);
        } else {
            if (strcmp (name, (char*) (MARK_NAME)))
            {
                TEST_FAIL ("name is %s, should be %s", name, MARK_NAME);
            }
        }
    }
    
    #undef MARK_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_mark_get_name 
 * Params: GtkTextMark *mark
 * Returns: const char*
 * Assertion: Returns the mark name; returns NULL for anonymous marks.
 * Params Values: a newly created GtkTextMark with name ""
 * Expected: ""  
 */
static void test_purpose_11()
{
    #define MARK_NAME  ""
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    const char* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    mark = gtk_text_buffer_create_mark (buffer, MARK_NAME, &start, FALSE);
    name = gtk_text_mark_get_name (mark);
    
    if (MARK_NAME == NULL)
    {
        if (name != NULL)
        {
            TEST_FAIL ("gtk_text_mark_get_name() should return NULL for anonymous marks", NULL);
        }
    } else {
        if (name == NULL)
        {
            TEST_FAIL ("gtk_text_mark_get_name() should return not NULL for non-anonymous marks", NULL);
        } else {
            if (strcmp (name, (char*) (MARK_NAME)))
            {
                TEST_FAIL ("name is %s, should be %s", name, MARK_NAME);
            }
        }
    }
    
    #undef MARK_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_mark_get_name 
 * Params: GtkTextMark *mark
 * Returns: const char*
 * Assertion: Returns the mark name; returns NULL for anonymous marks.
 * Params Values: a newly created GtkTextMark with name " "
 * Expected: " "  
 */
static void test_purpose_12()
{
    #define MARK_NAME  " "
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    const char* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    mark = gtk_text_buffer_create_mark (buffer, MARK_NAME, &start, FALSE);
    name = gtk_text_mark_get_name (mark);
    
    if (MARK_NAME == NULL)
    {
        if (name != NULL)
        {
            TEST_FAIL ("gtk_text_mark_get_name() should return NULL for anonymous marks", NULL);
        }
    } else {
        if (name == NULL)
        {
            TEST_FAIL ("gtk_text_mark_get_name() should return not NULL for non-anonymous marks", NULL);
        } else {
            if (strcmp (name, (char*) (MARK_NAME)))
            {
                TEST_FAIL ("name is %s, should be %s", name, MARK_NAME);
            }
        }
    }
    
    #undef MARK_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_mark_get_buffer
 * Params: GtkTextMark *mark
 * Returns: GtkTextBuffer*
 * Assertion: Gets the buffer this mark is located inside, or NULL if the mark is deleted.
 * Params Values: a newly created GtkTextMark with name "Text"
 * Expected: GtkTextBuffer* the mark is located inside  
 */
static void test_purpose_13()
{
    #define MARK_NAME  "Text"
    #define DELETED FALSE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    GtkTextBuffer* buffer1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    mark = gtk_text_buffer_create_mark (buffer, MARK_NAME, &start, FALSE);
    g_object_ref (mark);
    
    if (DELETED)
    {
        gtk_text_buffer_delete_mark (buffer, mark);
    }
    
    buffer1 = gtk_text_mark_get_buffer (mark);
    if (DELETED == TRUE)
    {
        if (buffer1 != NULL)
        {
            ("gtk_text_mark_get_buffer() should return NULL for deleted marks");
        }
    } else if (buffer1 != buffer) {
        TEST_FAIL ("buffer1 is differs from the one the mark is located inside", 
                  NULL);
    }
    
    #undef MARK_NAME
    #undef DELETED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_mark_get_buffer
 * Params: GtkTextMark *mark
 * Returns: GtkTextBuffer*
 * Assertion: Gets the buffer this mark is located inside, or NULL if the mark is deleted.
 * Params Values: a newly created GtkTextMark with name ""
 * Expected: GtkTextBuffer* the mark is located inside  
 */
static void test_purpose_14()
{
    #define MARK_NAME  ""
    #define DELETED FALSE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    GtkTextBuffer* buffer1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    mark = gtk_text_buffer_create_mark (buffer, MARK_NAME, &start, FALSE);
    g_object_ref (mark);
    
    if (DELETED)
    {
        gtk_text_buffer_delete_mark (buffer, mark);
    }
    
    buffer1 = gtk_text_mark_get_buffer (mark);
    if (DELETED == TRUE)
    {
        if (buffer1 != NULL)
        {
            ("gtk_text_mark_get_buffer() should return NULL for deleted marks");
        }
    } else if (buffer1 != buffer) {
        TEST_FAIL ("buffer1 is differs from the one the mark is located inside", 
                  NULL);
    }
    
    #undef MARK_NAME
    #undef DELETED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_mark_get_buffer
 * Params: GtkTextMark *mark
 * Returns: GtkTextBuffer*
 * Assertion: Gets the buffer this mark is located inside, or NULL if the mark is deleted.
 * Params Values: a newly created GtkTextMark with name " "
 * Expected: GtkTextBuffer* the mark is located inside  
 */
static void test_purpose_15()
{
    #define MARK_NAME  " "
    #define DELETED FALSE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    GtkTextBuffer* buffer1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    mark = gtk_text_buffer_create_mark (buffer, MARK_NAME, &start, FALSE);
    g_object_ref (mark);
    
    if (DELETED)
    {
        gtk_text_buffer_delete_mark (buffer, mark);
    }
    
    buffer1 = gtk_text_mark_get_buffer (mark);
    if (DELETED == TRUE)
    {
        if (buffer1 != NULL)
        {
            ("gtk_text_mark_get_buffer() should return NULL for deleted marks");
        }
    } else if (buffer1 != buffer) {
        TEST_FAIL ("buffer1 is differs from the one the mark is located inside", 
                  NULL);
    }
    
    #undef MARK_NAME
    #undef DELETED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_mark_get_buffer
 * Params: GtkTextMark *mark
 * Returns: GtkTextBuffer*
 * Assertion: Gets the buffer this mark is located inside, or NULL if the mark is deleted.
 * Params Values: a newly created GtkTextMark with name "Text"
 * Expected: GtkTextBuffer* the mark is located inside  
 */
static void test_purpose_16()
{
    #define MARK_NAME  "Text"
    #define DELETED TRUE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    GtkTextBuffer* buffer1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    mark = gtk_text_buffer_create_mark (buffer, MARK_NAME, &start, FALSE);
    g_object_ref (mark);
    
    if (DELETED)
    {
        gtk_text_buffer_delete_mark (buffer, mark);
    }
    
    buffer1 = gtk_text_mark_get_buffer (mark);
    if (DELETED == TRUE)
    {
        if (buffer1 != NULL)
        {
            ("gtk_text_mark_get_buffer() should return NULL for deleted marks");
        }
    } else if (buffer1 != buffer) {
        TEST_FAIL ("buffer1 is differs from the one the mark is located inside", 
                  NULL);
    }
    
    #undef MARK_NAME
    #undef DELETED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_mark_get_buffer
 * Params: GtkTextMark *mark
 * Returns: GtkTextBuffer*
 * Assertion: Gets the buffer this mark is located inside, or NULL if the mark is deleted.
 * Params Values: a newly created GtkTextMark with name ""
 * Expected: GtkTextBuffer* the mark is located inside  
 */
static void test_purpose_17()
{
    #define MARK_NAME  ""
    #define DELETED TRUE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    GtkTextBuffer* buffer1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    mark = gtk_text_buffer_create_mark (buffer, MARK_NAME, &start, FALSE);
    g_object_ref (mark);
    
    if (DELETED)
    {
        gtk_text_buffer_delete_mark (buffer, mark);
    }
    
    buffer1 = gtk_text_mark_get_buffer (mark);
    if (DELETED == TRUE)
    {
        if (buffer1 != NULL)
        {
            ("gtk_text_mark_get_buffer() should return NULL for deleted marks");
        }
    } else if (buffer1 != buffer) {
        TEST_FAIL ("buffer1 is differs from the one the mark is located inside", 
                  NULL);
    }
    
    #undef MARK_NAME
    #undef DELETED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_mark_get_buffer
 * Params: GtkTextMark *mark
 * Returns: GtkTextBuffer*
 * Assertion: Gets the buffer this mark is located inside, or NULL if the mark is deleted.
 * Params Values: a newly created GtkTextMark with name " "
 * Expected: GtkTextBuffer* the mark is located inside  
 */
static void test_purpose_18()
{
    #define MARK_NAME  " "
    #define DELETED TRUE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    GtkTextBuffer* buffer1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    mark = gtk_text_buffer_create_mark (buffer, MARK_NAME, &start, FALSE);
    g_object_ref (mark);
    
    if (DELETED)
    {
        gtk_text_buffer_delete_mark (buffer, mark);
    }
    
    buffer1 = gtk_text_mark_get_buffer (mark);
    if (DELETED == TRUE)
    {
        if (buffer1 != NULL)
        {
            ("gtk_text_mark_get_buffer() should return NULL for deleted marks");
        }
    } else if (buffer1 != buffer) {
        TEST_FAIL ("buffer1 is differs from the one the mark is located inside", 
                  NULL);
    }
    
    #undef MARK_NAME
    #undef DELETED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_mark_get_left_gravity
 * Params: GtkTextMark *mark
 * Returns: gboolean
 * Assertion: Determines whether the mark has left gravity.
 * Params Values: a newly created GtkTextMark with name "Text"
 * Expected: TRUE  
 */
static void test_purpose_19()
{
    #define MARK_NAME  "Text"
    #define LEFT_GRAVITY TRUE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    gboolean left_gravity;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    mark = gtk_text_buffer_create_mark (buffer, MARK_NAME, &start, LEFT_GRAVITY);
    
    left_gravity = gtk_text_mark_get_left_gravity (mark);
    if (left_gravity != LEFT_GRAVITY)
    {
        TEST_FAIL ("left_gravity = %d, should be %d", left_gravity, LEFT_GRAVITY);
    }
    
    #undef MARK_NAME
    #undef LEFT_GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_mark_get_left_gravity
 * Params: GtkTextMark *mark
 * Returns: gboolean
 * Assertion: Determines whether the mark has left gravity.
 * Params Values: a newly created GtkTextMark with name "Text"
 * Expected: FALSE  
 */
static void test_purpose_20()
{
    #define MARK_NAME  "Text"
    #define LEFT_GRAVITY FALSE
    
    GtkTextBuffer* buffer;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextMark *mark;
    gboolean left_gravity;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer =  gtk_text_buffer_new(NULL);
    
    if (!buffer)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_BUFFER (buffer))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_text_buffer_get_bounds (buffer, &start, &end);
    mark = gtk_text_buffer_create_mark (buffer, MARK_NAME, &start, LEFT_GRAVITY);
    
    left_gravity = gtk_text_mark_get_left_gravity (mark);
    if (left_gravity != LEFT_GRAVITY)
    {
        TEST_FAIL ("left_gravity = %d, should be %d", left_gravity, LEFT_GRAVITY);
    }
    
    #undef MARK_NAME
    #undef LEFT_GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkTextMark ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {NULL,0}
};
