/*
 * Stock_Items methods tests
 * Testing Stock_Items methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_stock_add
 * Params: const GtkStockItem *items, guint n_items
 * Returns: void
 * Assertion: Registers each of the stock items in items.
 * Params Values: a pointer to {}, 0
 * Expected: void
 * 
 * Name: gtk_stock_add_static
 * Params: const GtkStockItem *items, guint n_items
 * Returns: void
 * Assertion: Same as gtk_stock_add(), but doesn't copy items, so items must persist until application exit.'
 * Params Values: a pointer to {}, 0
 * Expected: void
 * 
 * Name: gtk_stock_list_ids
 * Params: void
 * Returns: GSList*
 * Assertion: Retrieves a list of all known stock IDs added to a GtkIconFactory or registered with gtk_stock_add().
 * Params Values: void
 * Expected: GSList*  
 */
static void test_purpose_1()
{
    #define ITEMS {}
    #define N_ITEMS 0
    #define CORRECT_ITEMS_DELTA 0
    
    static GtkStockItem items[] = ITEMS;
    GSList* ids_list_before;
    GSList* ids_list_after;
    guint ids_list_length_before;
    guint ids_list_length_after;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ids_list_before = gtk_stock_list_ids ();
    ids_list_length_before = g_slist_length (ids_list_before);
    
    gtk_stock_add (items, N_ITEMS);
    
    ids_list_after = gtk_stock_list_ids ();
    ids_list_length_after = g_slist_length (ids_list_after);
    
    if (ids_list_length_after - ids_list_length_before != CORRECT_ITEMS_DELTA)
    {
        TEST_FAIL ("%d items were registered, the length of their stock ids list is increased for %d, the value should be the same", 
                   CORRECT_ITEMS_DELTA, 
                   ids_list_length_after - ids_list_length_before);
    }
    
    #undef ITEMS
    #undef N_ITEMS
    #undef CORRECT_ITEMS_DELTA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_stock_add
 * Params: const GtkStockItem *items, guint n_items
 * Returns: void
 * Assertion: Registers each of the stock items in items.
 * Params Values: a pointer to {{"id11",  "lab11",  0, 0, NULL}}, 0
 * Expected: void
 * 
 * Name: gtk_stock_add_static
 * Params: const GtkStockItem *items, guint n_items
 * Returns: void
 * Assertion: Same as gtk_stock_add(), but doesn't copy items, so items must persist until application exit.'
 * Params Values: a pointer to {{"id11",  "lab11",  0, 0, NULL}}, 0
 * Expected: void
 * 
 * Name: gtk_stock_list_ids
 * Params: void
 * Returns: GSList*
 * Assertion: Retrieves a list of all known stock IDs added to a GtkIconFactory or registered with gtk_stock_add().
 * Params Values: void
 * Expected: GSList*  
 */
static void test_purpose_2()
{
    #define ITEMS {{"id11",  "lab11",  0, 0, NULL}}
    #define N_ITEMS 0
    #define CORRECT_ITEMS_DELTA 0
    
    static GtkStockItem items[] = ITEMS;
    GSList* ids_list_before;
    GSList* ids_list_after;
    guint ids_list_length_before;
    guint ids_list_length_after;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ids_list_before = gtk_stock_list_ids ();
    ids_list_length_before = g_slist_length (ids_list_before);
    
    gtk_stock_add (items, N_ITEMS);
    
    ids_list_after = gtk_stock_list_ids ();
    ids_list_length_after = g_slist_length (ids_list_after);
    
    if (ids_list_length_after - ids_list_length_before != CORRECT_ITEMS_DELTA)
    {
        TEST_FAIL ("%d items were registered, the length of their stock ids list is increased for %d, the value should be the same", 
                   CORRECT_ITEMS_DELTA, 
                   ids_list_length_after - ids_list_length_before);
    }
    
    #undef ITEMS
    #undef N_ITEMS
    #undef CORRECT_ITEMS_DELTA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_stock_add
 * Params: const GtkStockItem *items, guint n_items
 * Returns: void
 * Assertion: Registers each of the stock items in items.
 * Params Values: a pointer to {{"id12",  "lab12",  0, 0, NULL}}, 1
 * Expected: void
 * 
 * Name: gtk_stock_add_static
 * Params: const GtkStockItem *items, guint n_items
 * Returns: void
 * Assertion: Same as gtk_stock_add(), but doesn't copy items, so items must persist until application exit.'
 * Params Values: a pointer to {{"id12",  "lab12",  0, 0, NULL}}, 1
 * Expected: void
 * 
 * Name: gtk_stock_list_ids
 * Params: void
 * Returns: GSList*
 * Assertion: Retrieves a list of all known stock IDs added to a GtkIconFactory or registered with gtk_stock_add().
 * Params Values: void
 * Expected: GSList*  
 */
static void test_purpose_3()
{
    #define ITEMS {{"id12",  "lab12",  0, 0, NULL}}
    #define N_ITEMS 1
    #define CORRECT_ITEMS_DELTA 1
    
    static GtkStockItem items[] = ITEMS;
    GSList* ids_list_before;
    GSList* ids_list_after;
    guint ids_list_length_before;
    guint ids_list_length_after;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ids_list_before = gtk_stock_list_ids ();
    ids_list_length_before = g_slist_length (ids_list_before);
    
    gtk_stock_add (items, N_ITEMS);
    
    ids_list_after = gtk_stock_list_ids ();
    ids_list_length_after = g_slist_length (ids_list_after);
    
    if (ids_list_length_after - ids_list_length_before != CORRECT_ITEMS_DELTA)
    {
        TEST_FAIL ("%d items were registered, the length of their stock ids list is increased for %d, the value should be the same", 
                   CORRECT_ITEMS_DELTA, 
                   ids_list_length_after - ids_list_length_before);
    }
    
    #undef ITEMS
    #undef N_ITEMS
    #undef CORRECT_ITEMS_DELTA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_stock_add
 * Params: const GtkStockItem *items, guint n_items
 * Returns: void
 * Assertion: Registers each of the stock items in items.
 * Params Values: a pointer to {{"id21",  "lab21",  0, 0, NULL}, {"id22",  "lab22",  0, 0, NULL}, {"id23",  "lab23",  0, 0, NULL}, {"id24",  "lab24",  0, 0, NULL}}, 0
 * Expected: void
 * 
 * Name: gtk_stock_add_static
 * Params: const GtkStockItem *items, guint n_items
 * Returns: void
 * Assertion: Same as gtk_stock_add(), but doesn't copy items, so items must persist until application exit.'
 * Params Values: a pointer to {{"id21",  "lab21",  0, 0, NULL}, {"id22",  "lab22",  0, 0, NULL}, {"id23",  "lab23",  0, 0, NULL}, {"id24",  "lab24",  0, 0, NULL}}, 0
 * Expected: void
 * 
 * Name: gtk_stock_list_ids
 * Params: void
 * Returns: GSList*
 * Assertion: Retrieves a list of all known stock IDs added to a GtkIconFactory or registered with gtk_stock_add().
 * Params Values: void
 * Expected: GSList*  
 */
static void test_purpose_4()
{
    #define ITEMS {{"id21",  "lab21",  0, 0, NULL}, {"id22",  "lab22",  0, 0, NULL}, {"id23",  "lab23",  0, 0, NULL}, {"id24",  "lab24",  0, 0, NULL}}
    #define N_ITEMS 0
    #define CORRECT_ITEMS_DELTA 0
    
    static GtkStockItem items[] = ITEMS;
    GSList* ids_list_before;
    GSList* ids_list_after;
    guint ids_list_length_before;
    guint ids_list_length_after;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ids_list_before = gtk_stock_list_ids ();
    ids_list_length_before = g_slist_length (ids_list_before);
    
    gtk_stock_add (items, N_ITEMS);
    
    ids_list_after = gtk_stock_list_ids ();
    ids_list_length_after = g_slist_length (ids_list_after);
    
    if (ids_list_length_after - ids_list_length_before != CORRECT_ITEMS_DELTA)
    {
        TEST_FAIL ("%d items were registered, the length of their stock ids list is increased for %d, the value should be the same", 
                   CORRECT_ITEMS_DELTA, 
                   ids_list_length_after - ids_list_length_before);
    }
    
    #undef ITEMS
    #undef N_ITEMS
    #undef CORRECT_ITEMS_DELTA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_stock_add
 * Params: const GtkStockItem *items, guint n_items
 * Returns: void
 * Assertion: Registers each of the stock items in items.
 * Params Values: a pointer to {{"id25",  "lab25",  0, 0, NULL}, {"id26",  "lab26",  0, 0, NULL}, {"id27",  "lab28",  0, 0, NULL}, {"id29",  "lab29",  0, 0, NULL}}, 3
 * Expected: void
 * 
 * Name: gtk_stock_add_static
 * Params: const GtkStockItem *items, guint n_items
 * Returns: void
 * Assertion: Same as gtk_stock_add(), but doesn't copy items, so items must persist until application exit.'
 * Params Values: a pointer to {{"id25",  "lab25",  0, 0, NULL}, {"id26",  "lab26",  0, 0, NULL}, {"id27",  "lab28",  0, 0, NULL}, {"id29",  "lab29",  0, 0, NULL}}, 3
 * Expected: void
 * 
 * Name: gtk_stock_list_ids
 * Params: void
 * Returns: GSList*
 * Assertion: Retrieves a list of all known stock IDs added to a GtkIconFactory or registered with gtk_stock_add().
 * Params Values: void
 * Expected: GSList*  
 */
static void test_purpose_5()
{
    #define ITEMS {{"id25",  "lab25",  0, 0, NULL}, {"id26",  "lab26",  0, 0, NULL}, {"id27",  "lab28",  0, 0, NULL}, {"id29",  "lab29",  0, 0, NULL}}
    #define N_ITEMS 3
    #define CORRECT_ITEMS_DELTA 3
    
    static GtkStockItem items[] = ITEMS;
    GSList* ids_list_before;
    GSList* ids_list_after;
    guint ids_list_length_before;
    guint ids_list_length_after;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ids_list_before = gtk_stock_list_ids ();
    ids_list_length_before = g_slist_length (ids_list_before);
    
    gtk_stock_add (items, N_ITEMS);
    
    ids_list_after = gtk_stock_list_ids ();
    ids_list_length_after = g_slist_length (ids_list_after);
    
    if (ids_list_length_after - ids_list_length_before != CORRECT_ITEMS_DELTA)
    {
        TEST_FAIL ("%d items were registered, the length of their stock ids list is increased for %d, the value should be the same", 
                   CORRECT_ITEMS_DELTA, 
                   ids_list_length_after - ids_list_length_before);
    }
    
    #undef ITEMS
    #undef N_ITEMS
    #undef CORRECT_ITEMS_DELTA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_stock_add
 * Params: const GtkStockItem *items, guint n_items
 * Returns: void
 * Assertion: Registers each of the stock items in items.
 * Params Values: a pointer to {{"id210",  "lab210",  0, 0, NULL}, {"id211",  "lab211",  0, 0, NULL}, {"id212",  "lab212",  0, 0, NULL}, {"id213",  "lab213",  0, 0, NULL}}, 4
 * Expected: void
 * 
 * Name: gtk_stock_add_static
 * Params: const GtkStockItem *items, guint n_items
 * Returns: void
 * Assertion: Same as gtk_stock_add(), but doesn't copy items, so items must persist until application exit.'
 * Params Values: a pointer to {{"id210",  "lab210",  0, 0, NULL}, {"id211",  "lab211",  0, 0, NULL}, {"id212",  "lab212",  0, 0, NULL}, {"id213",  "lab213",  0, 0, NULL}}, 4
 * Expected: void
 * 
 * Name: gtk_stock_list_ids
 * Params: void
 * Returns: GSList*
 * Assertion: Retrieves a list of all known stock IDs added to a GtkIconFactory or registered with gtk_stock_add().
 * Params Values: void
 * Expected: GSList*  
 */
static void test_purpose_6()
{
    #define ITEMS {{"id210",  "lab210",  0, 0, NULL}, {"id211",  "lab211",  0, 0, NULL}, {"id212",  "lab212",  0, 0, NULL}, {"id213",  "lab213",  0, 0, NULL}}
    #define N_ITEMS 4
    #define CORRECT_ITEMS_DELTA 4
    
    static GtkStockItem items[] = ITEMS;
    GSList* ids_list_before;
    GSList* ids_list_after;
    guint ids_list_length_before;
    guint ids_list_length_after;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ids_list_before = gtk_stock_list_ids ();
    ids_list_length_before = g_slist_length (ids_list_before);
    
    gtk_stock_add (items, N_ITEMS);
    
    ids_list_after = gtk_stock_list_ids ();
    ids_list_length_after = g_slist_length (ids_list_after);
    
    if (ids_list_length_after - ids_list_length_before != CORRECT_ITEMS_DELTA)
    {
        TEST_FAIL ("%d items were registered, the length of their stock ids list is increased for %d, the value should be the same", 
                   CORRECT_ITEMS_DELTA, 
                   ids_list_length_after - ids_list_length_before);
    }
    
    #undef ITEMS
    #undef N_ITEMS
    #undef CORRECT_ITEMS_DELTA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_stock_add
 * Params: const GtkStockItem *items, guint n_items
 * Returns: void
 * Assertion: If an item already exists with the same stock ID as one of the items, the old item gets replaced.
 * Params Values: a pointer to {{"id1_11",  "lab1_11",  0, 0, NULL}, {"id1_12",  "lab1_12",  0, 0, NULL}, {"id1_13",  "lab1_13",  0, 0, NULL}, {"id1_14",  "lab1_14",  0, 0, NULL}}, 4 and a pointer to {{"id1_11",  "lab1_11",  0, 0, NULL}, {"id1_12",  "lab1_12",  0, 0, NULL}, {"id1_13",  "lab1_13",  0, 0, NULL}, {"id1_14",  "lab1_14",  0, 0, NULL}}, 4
 * Expected: void  
 */
static void test_purpose_7()
{
    #define ITEMS1 {{"id1_11",  "lab1_11",  0, 0, NULL}, {"id1_12",  "lab1_12",  0, 0, NULL}, {"id1_13",  "lab1_13",  0, 0, NULL}, {"id1_14",  "lab1_14",  0, 0, NULL}}
    #define N_ITEMS1 4
    #define ITEMS2 {{"id1_11",  "lab1_11",  0, 0, NULL}, {"id1_12",  "lab1_12",  0, 0, NULL}, {"id1_13",  "lab1_13",  0, 0, NULL}, {"id1_14",  "lab1_14",  0, 0, NULL}}
    #define N_ITEMS2 4
    #define CORRECT_ITEMS_DELTA 0
    
    static GtkStockItem items1[] = ITEMS1;
    static GtkStockItem items2[] = ITEMS2;
    GSList* ids_list1;
    GSList* ids_list2;
    guint ids_list_length1;
    guint ids_list_length2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_stock_add (items1, N_ITEMS1);
    
    ids_list1 = gtk_stock_list_ids ();
    ids_list_length1 = g_slist_length (ids_list1);
    
    gtk_stock_add (items2, N_ITEMS2);
    
    ids_list2 = gtk_stock_list_ids ();
    ids_list_length2 = g_slist_length (ids_list2);
    
    if (ids_list_length2 - ids_list_length1 != CORRECT_ITEMS_DELTA)
    {
        TEST_FAIL ("%d items were added after the second _add(); should be %d", 
                   ids_list_length2 - ids_list_length1, 
                   CORRECT_ITEMS_DELTA);
    }
    
    #undef ITEMS1
    #undef N_ITEMS1
    #undef ITEMS2
    #undef N_ITEMS2
    #undef CORRECT_ITEMS_DELTA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_stock_add
 * Params: const GtkStockItem *items, guint n_items
 * Returns: void
 * Assertion: If an item already exists with the same stock ID as one of the items, the old item gets replaced.
 * Params Values: a pointer to {{"id1_21",  "lab1_21",  0, 0, NULL}, {"id1_22",  "lab1_22",  0, 0, NULL}, {"id1_23",  "lab1_23",  0, 0, NULL}, {"id1_24",  "lab1_24",  0, 0, NULL}}, 4 and a pointer to {{"id1_21",  "lab1_21",  0, 0, NULL}, {"id1_22",  "lab1_22",  0, 0, NULL}, {"id1_23",  "lab1_23",  0, 0, NULL} , {"id1_25",  "lab1_25",  0, 0, NULL}}, 4
 * Expected: void  
 */
static void test_purpose_8()
{
    #define ITEMS1 {{"id1_21",  "lab1_21",  0, 0, NULL}, {"id1_22",  "lab1_22",  0, 0, NULL}, {"id1_23",  "lab1_23",  0, 0, NULL}, {"id1_24",  "lab1_24",  0, 0, NULL}}
    #define N_ITEMS1 4
    #define ITEMS2 {{"id1_21",  "lab1_21",  0, 0, NULL}, {"id1_22",  "lab1_22",  0, 0, NULL}, {"id1_23",  "lab1_23",  0, 0, NULL} , {"id1_25",  "lab1_25",  0, 0, NULL}}
    #define N_ITEMS2 4
    #define CORRECT_ITEMS_DELTA 1
    
    static GtkStockItem items1[] = ITEMS1;
    static GtkStockItem items2[] = ITEMS2;
    GSList* ids_list1;
    GSList* ids_list2;
    guint ids_list_length1;
    guint ids_list_length2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_stock_add (items1, N_ITEMS1);
    
    ids_list1 = gtk_stock_list_ids ();
    ids_list_length1 = g_slist_length (ids_list1);
    
    gtk_stock_add (items2, N_ITEMS2);
    
    ids_list2 = gtk_stock_list_ids ();
    ids_list_length2 = g_slist_length (ids_list2);
    
    if (ids_list_length2 - ids_list_length1 != CORRECT_ITEMS_DELTA)
    {
        TEST_FAIL ("%d items were added after the second _add(); should be %d", 
                   ids_list_length2 - ids_list_length1, 
                   CORRECT_ITEMS_DELTA);
    }
    
    #undef ITEMS1
    #undef N_ITEMS1
    #undef ITEMS2
    #undef N_ITEMS2
    #undef CORRECT_ITEMS_DELTA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_stock_item_copy
 * Params: const GtkStockItem *item
 * Returns: GtkStockItem*
 * Assertion: Copies a stock item, mostly useful for language bindings and not in applications.
 * Params Values:  GtkStockItem*
 * Expected:  GtkStockItem*, copy of the passed to the func.  
 */
static void test_purpose_9()
{
    #define ITEMS {{"id12",  "lab12",  0, 0, NULL}}
    #define N_ITEMS 1
    #define ITEM_TO_COPY_POS 0
    
    static GtkStockItem items[] = ITEMS;
    GtkStockItem* item_copy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_stock_add (items, N_ITEMS);
    
    item_copy = gtk_stock_item_copy (&items [ITEM_TO_COPY_POS]);
    
    if (strcmp (item_copy->stock_id, items [ITEM_TO_COPY_POS].stock_id))
    {
        TEST_FAIL ("item_copy stock_id is '%s', item stock_id is '%s', they should be the same", item_copy->stock_id, items [ITEM_TO_COPY_POS].stock_id);
    }
    
    if (strcmp (item_copy->label, items [ITEM_TO_COPY_POS].label))
    {
        TEST_FAIL ("item_copy label is '%s', item label is '%s', they should be the same", item_copy->label, items [ITEM_TO_COPY_POS].label);
    }
    
    if (item_copy->modifier != items [ITEM_TO_COPY_POS].modifier)
    {
        TEST_FAIL ("item_copy modifier is '%s', item modifier is '%s', they should be the same", item_copy->modifier, items [ITEM_TO_COPY_POS].modifier);
    }
    
    if (item_copy->keyval != items [ITEM_TO_COPY_POS].keyval)
    {
        TEST_FAIL ("item_copy keyval is '%s', item keyval is '%s', they should be the same", item_copy->keyval, items [ITEM_TO_COPY_POS].keyval);
    }
    
    #undef ITEMS
    #undef N_ITEMS
    #undef ITEM_TO_COPY_POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_stock_item_copy
 * Params: const GtkStockItem *item
 * Returns: GtkStockItem*
 * Assertion: Copies a stock item, mostly useful for language bindings and not in applications.
 * Params Values:  GtkStockItem*
 * Expected:  GtkStockItem*, copy of the passed to the func.  
 */
static void test_purpose_10()
{
    #define ITEMS {{"id21",  "lab21",  0, 0, NULL}, {"id22",  "lab22",  0, 0, NULL}, {"id23",  "lab23",  0, 0, NULL}, {"id24",  "lab24",  0, 0, NULL}}
    #define N_ITEMS 0
    #define ITEM_TO_COPY_POS 3
    
    static GtkStockItem items[] = ITEMS;
    GtkStockItem* item_copy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_stock_add (items, N_ITEMS);
    
    item_copy = gtk_stock_item_copy (&items [ITEM_TO_COPY_POS]);
    
    if (strcmp (item_copy->stock_id, items [ITEM_TO_COPY_POS].stock_id))
    {
        TEST_FAIL ("item_copy stock_id is '%s', item stock_id is '%s', they should be the same", item_copy->stock_id, items [ITEM_TO_COPY_POS].stock_id);
    }
    
    if (strcmp (item_copy->label, items [ITEM_TO_COPY_POS].label))
    {
        TEST_FAIL ("item_copy label is '%s', item label is '%s', they should be the same", item_copy->label, items [ITEM_TO_COPY_POS].label);
    }
    
    if (item_copy->modifier != items [ITEM_TO_COPY_POS].modifier)
    {
        TEST_FAIL ("item_copy modifier is '%s', item modifier is '%s', they should be the same", item_copy->modifier, items [ITEM_TO_COPY_POS].modifier);
    }
    
    if (item_copy->keyval != items [ITEM_TO_COPY_POS].keyval)
    {
        TEST_FAIL ("item_copy keyval is '%s', item keyval is '%s', they should be the same", item_copy->keyval, items [ITEM_TO_COPY_POS].keyval);
    }
    
    #undef ITEMS
    #undef N_ITEMS
    #undef ITEM_TO_COPY_POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_stock_item_free
 * Params: GtkStockItem *item
 * Returns: void
 * Assertion: Frees a stock item allocated on the heap, such as one returned by gtk_stock_item_copy().
 * Params Values:  GtkStockItem*
 * Expected:  void
 * 
 * Name: gtk_stock_item_free
 * Params: GtkStockItem *item
 * Returns: void
 * Assertion: Also frees the fields inside the stock item, if they are not NULL.
 * Params Values:  GtkStockItem*
 * Expected:  void  
 */
static void test_purpose_11()
{
    #define ITEMS {{"id12",  "lab12",  0, 0, NULL}}
    #define N_ITEMS 1
    #define ITEM_TO_COPY_POS 0
    
    static GtkStockItem items[] = ITEMS;
    GtkStockItem* item_copy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_stock_add (items, N_ITEMS);
    
    item_copy = gtk_stock_item_copy (&items [ITEM_TO_COPY_POS]);
    
    gtk_stock_item_free (item_copy);
    
    #undef ITEMS
    #undef N_ITEMS
    #undef ITEM_TO_COPY_POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_stock_item_free
 * Params: GtkStockItem *item
 * Returns: void
 * Assertion: Frees a stock item allocated on the heap, such as one returned by gtk_stock_item_copy().
 * Params Values:  GtkStockItem*
 * Expected:  void
 * 
 * Name: gtk_stock_item_free
 * Params: GtkStockItem *item
 * Returns: void
 * Assertion: Also frees the fields inside the stock item, if they are not NULL.
 * Params Values:  GtkStockItem*
 * Expected:  void  
 */
static void test_purpose_12()
{
    #define ITEMS {{"id21",  "lab21",  0, 0, NULL}, {"id22",  "lab22",  0, 0, NULL}, {"id23",  "lab23",  0, 0, NULL}, {"id24",  "lab24",  0, 0, NULL}}
    #define N_ITEMS 0
    #define ITEM_TO_COPY_POS 3
    
    static GtkStockItem items[] = ITEMS;
    GtkStockItem* item_copy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_stock_add (items, N_ITEMS);
    
    item_copy = gtk_stock_item_copy (&items [ITEM_TO_COPY_POS]);
    
    gtk_stock_item_free (item_copy);
    
    #undef ITEMS
    #undef N_ITEMS
    #undef ITEM_TO_COPY_POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_stock_lookup
 * Params: const gchar *stock_id, GtkStockItem *item
 * Returns: gboolean
 * Assertion: Fills item with the registered values for stock_id, returning TRUE if stock_id was known.
 * Params Values: 
 * Expected:   
 */
static void test_purpose_13()
{
    #define ITEMS {}
    #define N_ITEMS 0
    #define LOOKUP_ID "id"
    #define CORRECT_RES FALSE
    
    GtkStockItem items[] = ITEMS;
    GtkStockItem lookup_res;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_stock_add (items, N_ITEMS);
    
    res = gtk_stock_lookup (LOOKUP_ID, &lookup_res);
    if (res != CORRECT_RES)
    {
        TEST_FAIL ("res = %d, should be %d", res, CORRECT_RES);
    }
    
    #undef ITEMS
    #undef N_ITEMS
    #undef LOOKUP_ID
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_stock_lookup
 * Params: const gchar *stock_id, GtkStockItem *item
 * Returns: gboolean
 * Assertion: Fills item with the registered values for stock_id, returning TRUE if stock_id was known.
 * Params Values: 
 * Expected:   
 */
static void test_purpose_14()
{
    #define ITEMS {{"id311",  "lab311",  0, 0, NULL}}
    #define N_ITEMS 1
    #define LOOKUP_ID "id311"
    #define CORRECT_RES TRUE
    
    GtkStockItem items[] = ITEMS;
    GtkStockItem lookup_res;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_stock_add (items, N_ITEMS);
    
    res = gtk_stock_lookup (LOOKUP_ID, &lookup_res);
    if (res != CORRECT_RES)
    {
        TEST_FAIL ("res = %d, should be %d", res, CORRECT_RES);
    }
    
    #undef ITEMS
    #undef N_ITEMS
    #undef LOOKUP_ID
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_stock_lookup
 * Params: const gchar *stock_id, GtkStockItem *item
 * Returns: gboolean
 * Assertion: Fills item with the registered values for stock_id, returning TRUE if stock_id was known.
 * Params Values: 
 * Expected:   
 */
static void test_purpose_15()
{
    #define ITEMS {{"id311",  "lab311",  0, 0, NULL}}
    #define N_ITEMS 1
    #define LOOKUP_ID "id312"
    #define CORRECT_RES FALSE
    
    GtkStockItem items[] = ITEMS;
    GtkStockItem lookup_res;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_stock_add (items, N_ITEMS);
    
    res = gtk_stock_lookup (LOOKUP_ID, &lookup_res);
    if (res != CORRECT_RES)
    {
        TEST_FAIL ("res = %d, should be %d", res, CORRECT_RES);
    }
    
    #undef ITEMS
    #undef N_ITEMS
    #undef LOOKUP_ID
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_stock_lookup
 * Params: const gchar *stock_id, GtkStockItem *item
 * Returns: gboolean
 * Assertion: Fills item with the registered values for stock_id, returning TRUE if stock_id was known.
 * Params Values: 
 * Expected:   
 */
static void test_purpose_16()
{
    #define ITEMS {{"id321",  "lab321",  0, 0, NULL}, {"id322",  "lab322",  0, 0, NULL}, {"id323",  "lab323",  0, 0, NULL}, {"id324",  "lab324",  0, 0, NULL}}
    #define N_ITEMS 3
    #define LOOKUP_ID "id324"
    #define CORRECT_RES FALSE
    
    GtkStockItem items[] = ITEMS;
    GtkStockItem lookup_res;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_stock_add (items, N_ITEMS);
    
    res = gtk_stock_lookup (LOOKUP_ID, &lookup_res);
    if (res != CORRECT_RES)
    {
        TEST_FAIL ("res = %d, should be %d", res, CORRECT_RES);
    }
    
    #undef ITEMS
    #undef N_ITEMS
    #undef LOOKUP_ID
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_stock_lookup
 * Params: const gchar *stock_id, GtkStockItem *item
 * Returns: gboolean
 * Assertion: Fills item with the registered values for stock_id, returning TRUE if stock_id was known.
 * Params Values: 
 * Expected:   
 */
static void test_purpose_17()
{
    #define ITEMS {{"id325",  "lab325",  0, 0, NULL}, {"id326",  "lab326",  0, 0, NULL}, {"id327",  "lab328",  0, 0, NULL}, {"id329",  "lab329",  0, 0, NULL}}
    #define N_ITEMS 4
    #define LOOKUP_ID "id329"
    #define CORRECT_RES TRUE
    
    GtkStockItem items[] = ITEMS;
    GtkStockItem lookup_res;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_stock_add (items, N_ITEMS);
    
    res = gtk_stock_lookup (LOOKUP_ID, &lookup_res);
    if (res != CORRECT_RES)
    {
        TEST_FAIL ("res = %d, should be %d", res, CORRECT_RES);
    }
    
    #undef ITEMS
    #undef N_ITEMS
    #undef LOOKUP_ID
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for Stock_Items ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {NULL,0}
};
