/*
 * pango_glyph methods tests
 * Testing pango_glyph methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
#include <math.h>

/*
 * Name: pango_matrix_rotate
 * Params: PangoMatrix *matrix,double degrees
 * Returns: void 
 * Assertion:Changes the transformation represented by matrix to be the transformation given by first rotating by degrees degrees counter-clokwise then applying the original transformation.
 * Params Values: matrix,0 
 * Expected: matrix rotate by degree 0
 *   
 */
static void test_purpose_1()
{
    #define MATRIX matrix
    #define DEGREE 0
    
    /*   gdouble xx,xy,yx,yy,x0,y0;*/
    PangoMatrix tmp;
    gdouble r, s, c;
    
    
    gdouble degrees;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    degrees = DEGREE;
    
    /*The original matrix.*/
    PangoMatrix matrix_org = {1,2,3,4,5,6.0};
    
    PangoMatrix matrix = matrix_org;
    
    /*Rotate matrix by DEGREE.*/
    pango_matrix_rotate (&MATRIX,DEGREE);
    
    /*The following codes do the same to matrix,for checking the mathod implemented in pango_matrix_rotate().*/
    r = degrees * (G_PI / 180.);
    s = sin (r);
    c = cos (r);
    
    tmp.xx = c;
    tmp.xy = s;
    tmp.yx = -s;
    tmp.yy = c;
    tmp.x0 = 0;
    tmp.y0 = 0;
    
    pango_matrix_concat(&matrix_org, &tmp);
    
    /*   g_printf("\n xx = %f,xy = %f,yx = %f,yy = %f,x0 = %f,y0 = %f\n",xx,xy,yx,yy,x0,y0);*/
    
    /*Check whether the matrix is rotated correctly.*/  
    if (matrix_org.xx != MATRIX.xx || matrix_org.xy != MATRIX.xy || matrix_org.yx != MATRIX.yx || matrix_org.yy != MATRIX.yy)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
        return;
    }
    
    #undef MATRIX
    #undef DEGREE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_matrix_rotate
 * Params: PangoMatrix *matrix,double degrees
 * Returns: void 
 * Assertion:Changes the transformation represented by matrix to be the transformation given by first rotating by degrees degrees counter-clokwise then applying the original transformation.
 * Params Values: matrix,45 
 * Expected: matrix rotate by degree 45
 *   
 */
static void test_purpose_2()
{
    #define MATRIX matrix
    #define DEGREE 45
    
    /*   gdouble xx,xy,yx,yy,x0,y0;*/
    PangoMatrix tmp;
    gdouble r, s, c;
    
    
    gdouble degrees;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    degrees = DEGREE;
    
    /*The original matrix.*/
    PangoMatrix matrix_org = {1,2,3,4,5,6.0};
    
    PangoMatrix matrix = matrix_org;
    
    /*Rotate matrix by DEGREE.*/
    pango_matrix_rotate (&MATRIX,DEGREE);
    
    /*The following codes do the same to matrix,for checking the mathod implemented in pango_matrix_rotate().*/
    r = degrees * (G_PI / 180.);
    s = sin (r);
    c = cos (r);
    
    tmp.xx = c;
    tmp.xy = s;
    tmp.yx = -s;
    tmp.yy = c;
    tmp.x0 = 0;
    tmp.y0 = 0;
    
    pango_matrix_concat(&matrix_org, &tmp);
    
    /*   g_printf("\n xx = %f,xy = %f,yx = %f,yy = %f,x0 = %f,y0 = %f\n",xx,xy,yx,yy,x0,y0);*/
    
    /*Check whether the matrix is rotated correctly.*/  
    if (matrix_org.xx != MATRIX.xx || matrix_org.xy != MATRIX.xy || matrix_org.yx != MATRIX.yx || matrix_org.yy != MATRIX.yy)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
        return;
    }
    
    #undef MATRIX
    #undef DEGREE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_matrix_rotate
 * Params: PangoMatrix *matrix,double degrees
 * Returns: void 
 * Assertion:Changes the transformation represented by matrix to be the transformation given by first rotating by degrees degrees counter-clokwise then applying the original transformation.
 * Params Values: matrix,90 
 * Expected: matrix rotate by degree 90
 *   
 */
static void test_purpose_3()
{
    #define MATRIX matrix
    #define DEGREE 90
    
    /*   gdouble xx,xy,yx,yy,x0,y0;*/
    PangoMatrix tmp;
    gdouble r, s, c;
    
    
    gdouble degrees;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    degrees = DEGREE;
    
    /*The original matrix.*/
    PangoMatrix matrix_org = {1,2,3,4,5,6.0};
    
    PangoMatrix matrix = matrix_org;
    
    /*Rotate matrix by DEGREE.*/
    pango_matrix_rotate (&MATRIX,DEGREE);
    
    /*The following codes do the same to matrix,for checking the mathod implemented in pango_matrix_rotate().*/
    r = degrees * (G_PI / 180.);
    s = sin (r);
    c = cos (r);
    
    tmp.xx = c;
    tmp.xy = s;
    tmp.yx = -s;
    tmp.yy = c;
    tmp.x0 = 0;
    tmp.y0 = 0;
    
    pango_matrix_concat(&matrix_org, &tmp);
    
    /*   g_printf("\n xx = %f,xy = %f,yx = %f,yy = %f,x0 = %f,y0 = %f\n",xx,xy,yx,yy,x0,y0);*/
    
    /*Check whether the matrix is rotated correctly.*/  
    if (matrix_org.xx != MATRIX.xx || matrix_org.xy != MATRIX.xy || matrix_org.yx != MATRIX.yx || matrix_org.yy != MATRIX.yy)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
        return;
    }
    
    #undef MATRIX
    #undef DEGREE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_matrix_rotate
 * Params: PangoMatrix *matrix,double degrees
 * Returns: void 
 * Assertion:Changes the transformation represented by matrix to be the transformation given by first rotating by degrees degrees counter-clokwise then applying the original transformation.
 * Params Values: matrix,180 
 * Expected: matrix rotate by degree 180
 *   
 */
static void test_purpose_4()
{
    #define MATRIX matrix
    #define DEGREE 180
    
    /*   gdouble xx,xy,yx,yy,x0,y0;*/
    PangoMatrix tmp;
    gdouble r, s, c;
    
    
    gdouble degrees;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    degrees = DEGREE;
    
    /*The original matrix.*/
    PangoMatrix matrix_org = {1,2,3,4,5,6.0};
    
    PangoMatrix matrix = matrix_org;
    
    /*Rotate matrix by DEGREE.*/
    pango_matrix_rotate (&MATRIX,DEGREE);
    
    /*The following codes do the same to matrix,for checking the mathod implemented in pango_matrix_rotate().*/
    r = degrees * (G_PI / 180.);
    s = sin (r);
    c = cos (r);
    
    tmp.xx = c;
    tmp.xy = s;
    tmp.yx = -s;
    tmp.yy = c;
    tmp.x0 = 0;
    tmp.y0 = 0;
    
    pango_matrix_concat(&matrix_org, &tmp);
    
    /*   g_printf("\n xx = %f,xy = %f,yx = %f,yy = %f,x0 = %f,y0 = %f\n",xx,xy,yx,yy,x0,y0);*/
    
    /*Check whether the matrix is rotated correctly.*/  
    if (matrix_org.xx != MATRIX.xx || matrix_org.xy != MATRIX.xy || matrix_org.yx != MATRIX.yx || matrix_org.yy != MATRIX.yy)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
        return;
    }
    
    #undef MATRIX
    #undef DEGREE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_glyph_string_new
 * Params: void
 * Returns: PangoGlyphString*
 * Assertion: Create a new PangoGlyphString.
 * Params Values: void
 * Expected: new created glyph string
 *   
 */
static void test_purpose_5()
{
    
    PangoGlyphString *glyph_string_new = NULL;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*If the new glyph string is not created, test fails.*/
    if ((glyph_string_new = pango_glyph_string_new())== NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
        return;
    }
    
    pango_glyph_string_free(glyph_string_new);
    
    
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for pango_glyph ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {NULL,0}
};
