/*
 * GtkEditable methods tests
 * Testing GtkEditable methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
gint global_counter;

void global_emit_signal (GtkEditable *adjustment,gpointer user_data)
{
    global_counter++;
}

/*
 * Name: gtk_editable_get_selection_bounds
 * Params: GtkEditable *editable, gint *start,gint *end 
 * Returns: gboolean
 * Assertion: Gets the current selection bounds, if there is a selection.
 * Params Values: GtkEditable*, qint*, qint*
 * Expected: gboolean  
 */
static void test_purpose_1()
{
    GtkWidget* widget;
    gint start;
    gint end;
    gboolean editable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), "Hello world !!!");
    
    editable = gtk_editable_get_selection_bounds (GTK_EDITABLE (widget),&start,&end);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 0, 0
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 0, 0
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 0, 0
 * Expected: gchar*  
 */
static void test_purpose_2()
{
    #define START 0
    #define END 0
    #define STRING "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 1, 1
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 1, 1
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 1, 1
 * Expected: gchar*  
 */
static void test_purpose_3()
{
    #define START 1
    #define END 1
    #define STRING "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 1, -1
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 1, -1
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 1, -1
 * Expected: gchar*  
 */
static void test_purpose_4()
{
    #define START 1
    #define END -1
    #define STRING "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 1, -1
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 1, -1
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 1, -1
 * Expected: gchar*  
 */
static void test_purpose_5()
{
    #define START 1
    #define END -1
    #define STRING "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 1, 10000
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 1, 10000
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 1, 10000
 * Expected: gchar*  
 */
static void test_purpose_6()
{
    #define START 1
    #define END 10000
    #define STRING "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 10000, 10000
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 10000, 10000
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 10000, 10000
 * Expected: gchar*  
 */
static void test_purpose_7()
{
    #define START 10000
    #define END 10000
    #define STRING "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 100001, 100001
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 100001, 100001
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 100001, 100001
 * Expected: gchar*  
 */
static void test_purpose_8()
{
    #define START 100001
    #define END 100001
    #define STRING "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, G_MAXINT, G_MAXINT
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, G_MAXINT, G_MAXINT
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, G_MAXINT, G_MAXINT
 * Expected: gchar*  
 */
static void test_purpose_9()
{
    #define START G_MAXINT
    #define END G_MAXINT
    #define STRING "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 0, G_MAXINT
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 0, G_MAXINT
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 0, G_MAXINT
 * Expected: gchar*  
 */
static void test_purpose_10()
{
    #define START 0
    #define END G_MAXINT
    #define STRING "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 1, G_MAXINT
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 1, G_MAXINT
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 1, G_MAXINT
 * Expected: gchar*  
 */
static void test_purpose_11()
{
    #define START 1
    #define END G_MAXINT
    #define STRING "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 1, 10
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 1, 10
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 1, 10
 * Expected: gchar*  
 */
static void test_purpose_12()
{
    #define START 1
    #define END 10
    #define STRING "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 0, 0
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 0, 0
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 0, 0
 * Expected: gchar*  
 */
static void test_purpose_13()
{
    #define START 0
    #define END 0
    #define STRING ""
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 0, 1
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 0, 1
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 0, 1
 * Expected: gchar*  
 */
static void test_purpose_14()
{
    #define START 0
    #define END 1
    #define STRING ""
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 10000, 10000
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 10000, 10000
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 10000, 10000
 * Expected: gchar*  
 */
static void test_purpose_15()
{
    #define START 10000
    #define END 10000
    #define STRING ""
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, G_MAXINT, G_MAXINT
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, G_MAXINT, G_MAXINT
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, G_MAXINT, G_MAXINT
 * Expected: gchar*  
 */
static void test_purpose_16()
{
    #define START G_MAXINT
    #define END G_MAXINT
    #define STRING ""
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 0, 0
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 0, 0
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 0, 0
 * Expected: gchar*  
 */
static void test_purpose_17()
{
    #define START 0
    #define END 0
    #define STRING "Label"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 1, 1
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 1, 1
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 1, 1
 * Expected: gchar*  
 */
static void test_purpose_18()
{
    #define START 1
    #define END 1
    #define STRING "Label"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 1, -1
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 1, -1
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 1, -1
 * Expected: gchar*  
 */
static void test_purpose_19()
{
    #define START 1
    #define END -1
    #define STRING "Label"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 10000, 10000
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 10000, 10000
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 10000, 10000
 * Expected: gchar*  
 */
static void test_purpose_20()
{
    #define START 10000
    #define END 10000
    #define STRING "Label"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, G_MAXINT, G_MAXINT
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, G_MAXINT, G_MAXINT
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, G_MAXINT, G_MAXINT
 * Expected: gchar*  
 */
static void test_purpose_21()
{
    #define START G_MAXINT
    #define END G_MAXINT
    #define STRING "Label"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 0, G_MAXINT
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 0, G_MAXINT
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 0, G_MAXINT
 * Expected: gchar*  
 */
static void test_purpose_22()
{
    #define START 0
    #define END G_MAXINT
    #define STRING "Label"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 1, G_MAXINT
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 1, G_MAXINT
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 1, G_MAXINT
 * Expected: gchar*  
 */
static void test_purpose_23()
{
    #define START 1
    #define END G_MAXINT
    #define STRING "Label"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 1, 10
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 1, 10
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 1, 10
 * Expected: gchar*  
 */
static void test_purpose_24()
{
    #define START 1
    #define END 10
    #define STRING "Label"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 0, 0
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 0, 0
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 0, 0
 * Expected: gchar*  
 */
static void test_purpose_25()
{
    #define START 0
    #define END 0
    #define STRING "!@#$%^&*"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 1, 1
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 1, 1
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 1, 1
 * Expected: gchar*  
 */
static void test_purpose_26()
{
    #define START 1
    #define END 1
    #define STRING "!@#$%^&*"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 1, 10
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 1, 10
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 1, 10
 * Expected: gchar*  
 */
static void test_purpose_27()
{
    #define START 1
    #define END 10
    #define STRING "!@#$%^&*"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 1, -1
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 1, -1
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 1, -1
 * Expected: gchar*  
 */
static void test_purpose_28()
{
    #define START 1
    #define END -1
    #define STRING "!@#$%^&*"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 10000, 10000
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 10000, 10000
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 10000, 10000
 * Expected: gchar*  
 */
static void test_purpose_29()
{
    #define START 10000
    #define END 10000
    #define STRING "!@#$%^&*"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 10000, -10000
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 10000, -10000
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 10000, -10000
 * Expected: gchar*  
 */
static void test_purpose_30()
{
    #define START 10000
    #define END -10000
    #define STRING "!@#$%^&*"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, G_MAXINT, G_MAXINT
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, G_MAXINT, G_MAXINT
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, G_MAXINT, G_MAXINT
 * Expected: gchar*  
 */
static void test_purpose_31()
{
    #define START G_MAXINT
    #define END G_MAXINT
    #define STRING "!@#$%^&*"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 0, G_MAXINT
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 0, G_MAXINT
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 0, G_MAXINT
 * Expected: gchar*  
 */
static void test_purpose_32()
{
    #define START 0
    #define END G_MAXINT
    #define STRING "!@#$%^&*"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 1, G_MAXINT
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 1, G_MAXINT
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 1, G_MAXINT
 * Expected: gchar*  
 */
static void test_purpose_33()
{
    #define START 1
    #define END G_MAXINT
    #define STRING "!@#$%^&*"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: Retrieves a sequence of characters.
 * Params Values: GtkEditable*, 1, 10
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: The characters that are retrieved are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 1, 10
 * Expected: gchar*
 * 
 * Name: gtk_editable_get_chars
 * Params: GtkEditable *editable, gint start_pos,gint end_pos 
 * Returns: gchar*
 * Assertion: If end_pos is negative, then the the characters retrieved will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 1, 10
 * Expected: gchar*  
 */
static void test_purpose_34()
{
    #define START 1
    #define END 10
    #define STRING "!@#$%^&*"
    
    
    GtkWidget* widget;
    gint start;
    gint end;
    gchar* string;
    gchar* source;
    gchar* string_real;
    gint length;
    gchar* substr;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    string = gtk_editable_get_chars (GTK_EDITABLE (widget),START, END);
    source = STRING;
    
    if ( ((START > END)&&(END > 0)) || (START > strlen(source)-1))
    {
        string_real = "";
    }
    else
    {
        if (START < 0) 
            start = 0;
        else
            start = START;
        if ((END < 0) || (END > strlen(source)-1)) 
            length = strlen(source) - start;
        else         
            length = END - start;
        substr = (gchar*) calloc (length + 1, sizeof(gchar));
        strncpy(substr, source + start, length);
        substr[length] = '\0';
        string_real = substr;
    }
    if (strcmp (string,string_real))
    {
        TEST_FAIL ("string is %s, should be %s", string,string_real);
    }
    
    #undef START
    #undef END
    #undef STRING
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, ""
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_35()
{
    #define STRING ""
    #define POSITION 0
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, ""
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_36()
{
    #define STRING ""
    #define POSITION -1
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, " "
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_37()
{
    #define STRING " "
    #define POSITION 0
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, " "
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_38()
{
    #define STRING " "
    #define POSITION -1
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, " "
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_39()
{
    #define STRING " "
    #define POSITION 1
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, "Label"
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_40()
{
    #define STRING "Label"
    #define POSITION 0
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, "Label"
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_41()
{
    #define STRING "Label"
    #define POSITION -1
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, "Label"
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_42()
{
    #define STRING "Label"
    #define POSITION 1
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, "Label"
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_43()
{
    #define STRING "Label"
    #define POSITION 4
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, "Label"
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_44()
{
    #define STRING "Label"
    #define POSITION -1
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, "Label"
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_45()
{
    #define STRING "Label"
    #define POSITION -10
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, "\b\t\n"
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_46()
{
    #define STRING "\b\t\n"
    #define POSITION 0
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, "\b\t\n"
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_47()
{
    #define STRING "\b\t\n"
    #define POSITION -1
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, "\b\t\n"
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_48()
{
    #define STRING "\b\t\n"
    #define POSITION 2
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, "!@#$%^&*"
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_49()
{
    #define STRING "!@#$%^&*"
    #define POSITION 0
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, "!@#$%^&*"
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_50()
{
    #define STRING "!@#$%^&*"
    #define POSITION -1
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, "!@#$%^&*"
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_51()
{
    #define STRING "!@#$%^&*"
    #define POSITION 1
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, "!@#$%^&*"
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_52()
{
    #define STRING "!@#$%^&*"
    #define POSITION 7
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_53()
{
    #define STRING "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define POSITION 0
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_54()
{
    #define STRING "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define POSITION -1
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_55()
{
    #define STRING "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define POSITION 1
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_position
 * Params: GtkEditable *editable, gint position 
 * Returns: void
 * Assertion: Sets the cursor position.
 * Params Values: a newly created GtkEditable*, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
 * Expected: void
 * 
 * Name: gtk_editable_get_position
 * Params: GtkEditable *editable
 * Returns: gint
 * Assertion: Retrieves the current cursor position.
 * Params Values: a newly created GtkEditable*
 * Expected: gint  
 */
static void test_purpose_56()
{
    #define STRING "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define POSITION 58
    
    GtkWidget* widget;
    gint position;
    gint real_position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), STRING);
    
    gtk_editable_set_position (GTK_EDITABLE (widget),POSITION);
    position = gtk_editable_get_position (GTK_EDITABLE (widget));
    if (POSITION < 0)
    {
        real_position = strlen(STRING);
    }
    else
    {
        real_position = POSITION;
    }
    if (position != real_position)
    {
        TEST_FAIL ("position is '%d', should be '%d'",position,POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef POSITION
    #undef STRING
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_editable
 * Params: GtkEditable *editable, gboolean is_editable 
 * Returns: void
 * Assertion: Determines if the user can edit the text in the editable widget or not.
 * Params Values: a newly created GtkEditable*, TRUE
 * Expected: void
 * 
 * Name: gtk_editable_get_editable
 * Params: GtkEditable *editable
 * Returns: gboolean
 * Assertion: Retrieves whether editable is editable.
 * Params Values: a newly created GtkEditable*
 * Expected: gboolean  
 */
static void test_purpose_57()
{
    #define IS_EDITABLE TRUE
    
    GtkWidget* widget;
    gboolean is_editable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), "Hello world !!!");
    
    gtk_editable_set_editable (GTK_EDITABLE (widget),IS_EDITABLE);
    is_editable = gtk_editable_get_editable (GTK_EDITABLE (widget));
    if (is_editable != IS_EDITABLE)
    {
        TEST_FAIL ("is_editable is '%s', should be '%s'",is_editable,IS_EDITABLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef IS_EDITABLE
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_set_editable
 * Params: GtkEditable *editable, gboolean is_editable 
 * Returns: void
 * Assertion: Determines if the user can edit the text in the editable widget or not.
 * Params Values: a newly created GtkEditable*, FALSE
 * Expected: void
 * 
 * Name: gtk_editable_get_editable
 * Params: GtkEditable *editable
 * Returns: gboolean
 * Assertion: Retrieves whether editable is editable.
 * Params Values: a newly created GtkEditable*
 * Expected: gboolean  
 */
static void test_purpose_58()
{
    #define IS_EDITABLE FALSE
    
    GtkWidget* widget;
    gboolean is_editable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), "Hello world !!!");
    
    gtk_editable_set_editable (GTK_EDITABLE (widget),IS_EDITABLE);
    is_editable = gtk_editable_get_editable (GTK_EDITABLE (widget));
    if (is_editable != IS_EDITABLE)
    {
        TEST_FAIL ("is_editable is '%s', should be '%s'",is_editable,IS_EDITABLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    #undef IS_EDITABLE
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_select_region
 * Params: GtkEditable *editable, gint *start,gint *end 
 * Returns: void
 * Assertion: Selects a region of text.
 * Params Values: GtkEditable*, 1, 3
 * Expected: void
 * 
 * Name: gtk_editable_select_region
 * Params: GtkEditable *editable, gint *start,gint *end 
 * Returns: void
 * Assertion: The characters that are selected are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 1, 3
 * Expected: void  
 */
static void test_purpose_59()
{
    #define TEXT "Label"
    #define START 1
    #define END 3
    
    GtkWidget* widget;
    gint start;
    gint end;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    gtk_editable_select_region (GTK_EDITABLE (widget),START,END);
    
    res = gtk_editable_get_selection_bounds (GTK_EDITABLE (widget),&start,&end);
    if (res)
    {
        if (start != START)
        {
            TEST_FAIL ("selection_start is '%d', should be '%d'",start,START);
        }
        
        if (end != END)
        {
            TEST_FAIL ("selection_end is '%d', should be '%d'",end,END);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef TEXT
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_select_region
 * Params: GtkEditable *editable, gint *start,gint *end 
 * Returns: void
 * Assertion: Selects a region of text.
 * Params Values: GtkEditable*, 1, 5
 * Expected: void
 * 
 * Name: gtk_editable_select_region
 * Params: GtkEditable *editable, gint *start,gint *end 
 * Returns: void
 * Assertion: The characters that are selected are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 1, 5
 * Expected: void  
 */
static void test_purpose_60()
{
    #define TEXT "Label"
    #define START 1
    #define END 5
    
    GtkWidget* widget;
    gint start;
    gint end;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    gtk_editable_select_region (GTK_EDITABLE (widget),START,END);
    
    res = gtk_editable_get_selection_bounds (GTK_EDITABLE (widget),&start,&end);
    if (res)
    {
        if (start != START)
        {
            TEST_FAIL ("selection_start is '%d', should be '%d'",start,START);
        }
        
        if (end != END)
        {
            TEST_FAIL ("selection_end is '%d', should be '%d'",end,END);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef TEXT
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_select_region
 * Params: GtkEditable *editable, gint *start,gint *end 
 * Returns: void
 * Assertion: Selects a region of text.
 * Params Values: GtkEditable*, 0, 1
 * Expected: void
 * 
 * Name: gtk_editable_select_region
 * Params: GtkEditable *editable, gint *start,gint *end 
 * Returns: void
 * Assertion: The characters that are selected are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 0, 1
 * Expected: void  
 */
static void test_purpose_61()
{
    #define TEXT "Label"
    #define START 0
    #define END 1
    
    GtkWidget* widget;
    gint start;
    gint end;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    gtk_editable_select_region (GTK_EDITABLE (widget),START,END);
    
    res = gtk_editable_get_selection_bounds (GTK_EDITABLE (widget),&start,&end);
    if (res)
    {
        if (start != START)
        {
            TEST_FAIL ("selection_start is '%d', should be '%d'",start,START);
        }
        
        if (end != END)
        {
            TEST_FAIL ("selection_end is '%d', should be '%d'",end,END);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef TEXT
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_select_region
 * Params: GtkEditable *editable, gint *start,gint *end 
 * Returns: void
 * Assertion: Selects a region of text.
 * Params Values: GtkEditable*, 0, 0
 * Expected: void
 * 
 * Name: gtk_editable_select_region
 * Params: GtkEditable *editable, gint *start,gint *end 
 * Returns: void
 * Assertion: The characters that are selected are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 0, 0
 * Expected: void  
 */
static void test_purpose_62()
{
    #define TEXT "Label"
    #define START 0
    #define END 0
    
    GtkWidget* widget;
    gint start;
    gint end;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    gtk_editable_select_region (GTK_EDITABLE (widget),START,END);
    
    res = gtk_editable_get_selection_bounds (GTK_EDITABLE (widget),&start,&end);
    if (res)
    {
        if (start != START)
        {
            TEST_FAIL ("selection_start is '%d', should be '%d'",start,START);
        }
        
        if (end != END)
        {
            TEST_FAIL ("selection_end is '%d', should be '%d'",end,END);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef TEXT
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_select_region
 * Params: GtkEditable *editable, gint *start,gint *end 
 * Returns: void
 * Assertion: If end_pos is negative, then the the characters selected will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 1, -1
 * Expected: void  
 */
static void test_purpose_63()
{
    #define TEXT "Label"
    #define START 1
    #define END -1
    
    GtkWidget* widget;
    gint start;
    gint end;
    gint len;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    gtk_editable_select_region (GTK_EDITABLE (widget),START,END);
    len = strlen (gtk_editable_get_chars(GTK_EDITABLE (widget),0,-1));
    
    res = gtk_editable_get_selection_bounds (GTK_EDITABLE (widget),&start,&end);
    if (res)
    {
        if (start != START)
        {
            TEST_FAIL ("selection_start is '%d', should be '%d'",start,START);
        }
        
        if (end != len)
        {
            TEST_FAIL ("selection_end is '%d', should be '%d'",end,len);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef TEXT
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_select_region
 * Params: GtkEditable *editable, gint *start,gint *end 
 * Returns: void
 * Assertion: If end_pos is negative, then the the characters selected will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 4, -1
 * Expected: void  
 */
static void test_purpose_64()
{
    #define TEXT "Label"
    #define START 4
    #define END -1
    
    GtkWidget* widget;
    gint start;
    gint end;
    gint len;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    gtk_editable_select_region (GTK_EDITABLE (widget),START,END);
    len = strlen (gtk_editable_get_chars(GTK_EDITABLE (widget),0,-1));
    
    res = gtk_editable_get_selection_bounds (GTK_EDITABLE (widget),&start,&end);
    if (res)
    {
        if (start != START)
        {
            TEST_FAIL ("selection_start is '%d', should be '%d'",start,START);
        }
        
        if (end != len)
        {
            TEST_FAIL ("selection_end is '%d', should be '%d'",end,len);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef TEXT
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_select_region
 * Params: GtkEditable *editable, gint *start,gint *end 
 * Returns: void
 * Assertion: If end_pos is negative, then the the characters selected will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 0, -1
 * Expected: void  
 */
static void test_purpose_65()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define START 0
    #define END -1
    
    GtkWidget* widget;
    gint start;
    gint end;
    gint len;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    gtk_editable_select_region (GTK_EDITABLE (widget),START,END);
    len = strlen (gtk_editable_get_chars(GTK_EDITABLE (widget),0,-1));
    
    res = gtk_editable_get_selection_bounds (GTK_EDITABLE (widget),&start,&end);
    if (res)
    {
        if (start != START)
        {
            TEST_FAIL ("selection_start is '%d', should be '%d'",start,START);
        }
        
        if (end != len)
        {
            TEST_FAIL ("selection_end is '%d', should be '%d'",end,len);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef TEXT
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_select_region
 * Params: GtkEditable *editable, gint *start,gint *end 
 * Returns: void
 * Assertion: If end_pos is negative, then the the characters selected will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 1, -10
 * Expected: void  
 */
static void test_purpose_66()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define START 1
    #define END -10
    
    GtkWidget* widget;
    gint start;
    gint end;
    gint len;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    gtk_editable_select_region (GTK_EDITABLE (widget),START,END);
    len = strlen (gtk_editable_get_chars(GTK_EDITABLE (widget),0,-1));
    
    res = gtk_editable_get_selection_bounds (GTK_EDITABLE (widget),&start,&end);
    if (res)
    {
        if (start != START)
        {
            TEST_FAIL ("selection_start is '%d', should be '%d'",start,START);
        }
        
        if (end != len)
        {
            TEST_FAIL ("selection_end is '%d', should be '%d'",end,len);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef TEXT
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_select_region
 * Params: GtkEditable *editable, gint *start,gint *end 
 * Returns: void
 * Assertion: If end_pos is negative, then the the characters selected will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 10, -100
 * Expected: void  
 */
static void test_purpose_67()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define START 10
    #define END -100
    
    GtkWidget* widget;
    gint start;
    gint end;
    gint len;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    gtk_editable_select_region (GTK_EDITABLE (widget),START,END);
    len = strlen (gtk_editable_get_chars(GTK_EDITABLE (widget),0,-1));
    
    res = gtk_editable_get_selection_bounds (GTK_EDITABLE (widget),&start,&end);
    if (res)
    {
        if (start != START)
        {
            TEST_FAIL ("selection_start is '%d', should be '%d'",start,START);
        }
        
        if (end != len)
        {
            TEST_FAIL ("selection_end is '%d', should be '%d'",end,len);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef TEXT
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_select_region
 * Params: GtkEditable *editable, gint *start,gint *end 
 * Returns: void
 * Assertion: If end_pos is negative, then the the characters selected will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, strlen (TEXT), -100
 * Expected: void  
 */
static void test_purpose_68()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define START strlen (TEXT)
    #define END -100
    
    GtkWidget* widget;
    gint start;
    gint end;
    gint len;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    gtk_editable_select_region (GTK_EDITABLE (widget),START,END);
    len = strlen (gtk_editable_get_chars(GTK_EDITABLE (widget),0,-1));
    
    res = gtk_editable_get_selection_bounds (GTK_EDITABLE (widget),&start,&end);
    if (res)
    {
        if (start != START)
        {
            TEST_FAIL ("selection_start is '%d', should be '%d'",start,START);
        }
        
        if (end != len)
        {
            TEST_FAIL ("selection_end is '%d', should be '%d'",end,len);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef TEXT
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_insert_text 
 * Params: GtkEditable *editable, const gchar *new_text,gint new_text_length,gint *position
 * Returns: void
 * Assertion: Inserts text at a given position.
 * Params Values: GtkEditable*, "*****", 5, 1
 * Expected: void  
 */
static void test_purpose_69()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define TEXT "*****"
    #define LENGTH 5
    #define POS 1
    
    GtkWidget* widget;
    gchar* str;
    gint pos;
    gint len;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    gtk_entry_set_text (GTK_ENTRY (widget),LABEL);
    pos = POS;
    gtk_editable_insert_text (GTK_EDITABLE (widget),TEXT,LENGTH,&pos);
    
    if (LENGTH<0)
      len = strlen (TEXT);
    else
      len = LENGTH;
    
    str = gtk_editable_get_chars (GTK_EDITABLE (widget),POS, len + POS);
    if (strcmp (str,TEXT))
    {
        TEST_FAIL ("string is %s, should be %s", str,TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef LENGTH
    #undef POS
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_insert_text 
 * Params: GtkEditable *editable, const gchar *new_text,gint new_text_length,gint *position
 * Returns: void
 * Assertion: Inserts text at a given position.
 * Params Values: GtkEditable*, "*****", 5, 0
 * Expected: void  
 */
static void test_purpose_70()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define TEXT "*****"
    #define LENGTH 5
    #define POS 0
    
    GtkWidget* widget;
    gchar* str;
    gint pos;
    gint len;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    gtk_entry_set_text (GTK_ENTRY (widget),LABEL);
    pos = POS;
    gtk_editable_insert_text (GTK_EDITABLE (widget),TEXT,LENGTH,&pos);
    
    if (LENGTH<0)
      len = strlen (TEXT);
    else
      len = LENGTH;
    
    str = gtk_editable_get_chars (GTK_EDITABLE (widget),POS, len + POS);
    if (strcmp (str,TEXT))
    {
        TEST_FAIL ("string is %s, should be %s", str,TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef LENGTH
    #undef POS
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_insert_text 
 * Params: GtkEditable *editable, const gchar *new_text,gint new_text_length,gint *position
 * Returns: void
 * Assertion: Inserts text at a given position.
 * Params Values: GtkEditable*, "*****", -1, 10
 * Expected: void  
 */
static void test_purpose_71()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define TEXT "*****"
    #define LENGTH -1
    #define POS 10
    
    GtkWidget* widget;
    gchar* str;
    gint pos;
    gint len;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    gtk_entry_set_text (GTK_ENTRY (widget),LABEL);
    pos = POS;
    gtk_editable_insert_text (GTK_EDITABLE (widget),TEXT,LENGTH,&pos);
    
    if (LENGTH<0)
      len = strlen (TEXT);
    else
      len = LENGTH;
    
    str = gtk_editable_get_chars (GTK_EDITABLE (widget),POS, len + POS);
    if (strcmp (str,TEXT))
    {
        TEST_FAIL ("string is %s, should be %s", str,TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef LENGTH
    #undef POS
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_insert_text 
 * Params: GtkEditable *editable, const gchar *new_text,gint new_text_length,gint *position
 * Returns: void
 * Assertion: Inserts text at a given position.
 * Params Values: GtkEditable*, "*****", 5, strlen(LABEL)
 * Expected: void  
 */
static void test_purpose_72()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define TEXT "*****"
    #define LENGTH 5
    #define POS strlen(LABEL)
    
    GtkWidget* widget;
    gchar* str;
    gint pos;
    gint len;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    gtk_entry_set_text (GTK_ENTRY (widget),LABEL);
    pos = POS;
    gtk_editable_insert_text (GTK_EDITABLE (widget),TEXT,LENGTH,&pos);
    
    if (LENGTH<0)
      len = strlen (TEXT);
    else
      len = LENGTH;
    
    str = gtk_editable_get_chars (GTK_EDITABLE (widget),POS, len + POS);
    if (strcmp (str,TEXT))
    {
        TEST_FAIL ("string is %s, should be %s", str,TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef LENGTH
    #undef POS
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_insert_text 
 * Params: GtkEditable *editable, const gchar *new_text,gint new_text_length,gint *position
 * Returns: void
 * Assertion: Inserts text at a given position.
 * Params Values: GtkEditable*, "*****", 5, strlen(LABEL)-1
 * Expected: void  
 */
static void test_purpose_73()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define TEXT "*****"
    #define LENGTH 5
    #define POS strlen(LABEL)-1
    
    GtkWidget* widget;
    gchar* str;
    gint pos;
    gint len;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    gtk_entry_set_text (GTK_ENTRY (widget),LABEL);
    pos = POS;
    gtk_editable_insert_text (GTK_EDITABLE (widget),TEXT,LENGTH,&pos);
    
    if (LENGTH<0)
      len = strlen (TEXT);
    else
      len = LENGTH;
    
    str = gtk_editable_get_chars (GTK_EDITABLE (widget),POS, len + POS);
    if (strcmp (str,TEXT))
    {
        TEST_FAIL ("string is %s, should be %s", str,TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef LENGTH
    #undef POS
    #undef LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_delete_text 
 * Params: GtkEditable *editable, gint start_pos,gint end_pos
 * Returns: void
 * Assertion: Deletes a sequence of characters.
 * Params Values: GtkEditable*, 0, 5
 * Expected: void  
 */
static void test_purpose_74()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define START 0
    #define END 5
    
    GtkWidget* widget;
    gchar* str;
    gint length;
    gint len;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    gtk_entry_set_text (GTK_ENTRY (widget),TEXT);
    
    length = strlen (TEXT);
    gtk_editable_delete_text (GTK_EDITABLE (widget),START,END);
    len = strlen (gtk_editable_get_chars(GTK_EDITABLE (widget),0,-1));
    
    if (len != length-END+START)
    {
        TEST_FAIL ("Sequence of characters isn't deleted",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_delete_text 
 * Params: GtkEditable *editable, gint start_pos,gint end_pos
 * Returns: void
 * Assertion: Deletes a sequence of characters.
 * Params Values: GtkEditable*, 1, 5
 * Expected: void  
 */
static void test_purpose_75()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define START 1
    #define END 5
    
    GtkWidget* widget;
    gchar* str;
    gint length;
    gint len;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    gtk_entry_set_text (GTK_ENTRY (widget),TEXT);
    
    length = strlen (TEXT);
    gtk_editable_delete_text (GTK_EDITABLE (widget),START,END);
    len = strlen (gtk_editable_get_chars(GTK_EDITABLE (widget),0,-1));
    
    if (len != length-END+START)
    {
        TEST_FAIL ("Sequence of characters isn't deleted",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_delete_text 
 * Params: GtkEditable *editable, gint start_pos,gint end_pos
 * Returns: void
 * Assertion: Deletes a sequence of characters.
 * Params Values: GtkEditable*, 1, strlen (TEXT)
 * Expected: void  
 */
static void test_purpose_76()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define START 1
    #define END strlen (TEXT)
    
    GtkWidget* widget;
    gchar* str;
    gint length;
    gint len;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    gtk_entry_set_text (GTK_ENTRY (widget),TEXT);
    
    length = strlen (TEXT);
    gtk_editable_delete_text (GTK_EDITABLE (widget),START,END);
    len = strlen (gtk_editable_get_chars(GTK_EDITABLE (widget),0,-1));
    
    if (len != length-END+START)
    {
        TEST_FAIL ("Sequence of characters isn't deleted",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_delete_text 
 * Params: GtkEditable *editable, gint start_pos,gint end_pos
 * Returns: void
 * Assertion: The characters that are deleted are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 0, 5
 * Expected: void  
 */
static void test_purpose_77()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define START 0
    #define END 5
    
    GtkWidget* widget;
    gchar* str;
    gchar* tmp;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    gtk_entry_set_text (GTK_ENTRY (widget),TEXT);
    
    str = gtk_editable_get_chars (GTK_EDITABLE (widget),END,END);
    
    gtk_editable_delete_text (GTK_EDITABLE (widget),START,END);
    
    tmp = gtk_editable_get_chars (GTK_EDITABLE (widget),START,START);
    if (strcmp (str,tmp))
    {
        TEST_FAIL ("The characters that are deleted including end_pos.",NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_delete_text 
 * Params: GtkEditable *editable, gint start_pos,gint end_pos
 * Returns: void
 * Assertion: The characters that are deleted are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 1, 5
 * Expected: void  
 */
static void test_purpose_78()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define START 1
    #define END 5
    
    GtkWidget* widget;
    gchar* str;
    gchar* tmp;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    gtk_entry_set_text (GTK_ENTRY (widget),TEXT);
    
    str = gtk_editable_get_chars (GTK_EDITABLE (widget),END,END);
    
    gtk_editable_delete_text (GTK_EDITABLE (widget),START,END);
    
    tmp = gtk_editable_get_chars (GTK_EDITABLE (widget),START,START);
    if (strcmp (str,tmp))
    {
        TEST_FAIL ("The characters that are deleted including end_pos.",NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_delete_text 
 * Params: GtkEditable *editable, gint start_pos,gint end_pos
 * Returns: void
 * Assertion: The characters that are deleted are those characters at positions from start_pos up to, but not including end_pos.
 * Params Values: GtkEditable*, 1, strlen (TEXT)
 * Expected: void  
 */
static void test_purpose_79()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define START 1
    #define END strlen (TEXT)
    
    GtkWidget* widget;
    gchar* str;
    gchar* tmp;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    gtk_entry_set_text (GTK_ENTRY (widget),TEXT);
    
    str = gtk_editable_get_chars (GTK_EDITABLE (widget),END,END);
    
    gtk_editable_delete_text (GTK_EDITABLE (widget),START,END);
    
    tmp = gtk_editable_get_chars (GTK_EDITABLE (widget),START,START);
    if (strcmp (str,tmp))
    {
        TEST_FAIL ("The characters that are deleted including end_pos.",NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_delete_text
 * Params: GtkEditable *editable, gint start_pos,gint end_pos
 * Returns: void
 * Assertion: If end_pos is negative, then the the characters deleted will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 0, -1
 * Expected: void  
 */
static void test_purpose_80()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define START 0
    #define END -1
    
    GtkWidget* widget;
    gint len;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    gtk_entry_set_text (GTK_ENTRY (widget),TEXT);
    
    gtk_editable_delete_text (GTK_EDITABLE (widget),START,END);
    len = strlen (gtk_editable_get_chars(GTK_EDITABLE (widget),0,-1));
    
    if (len != START)
    {
        TEST_FAIL ("The characters isn't deleted from start_pos to the end of the text.",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_delete_text
 * Params: GtkEditable *editable, gint start_pos,gint end_pos
 * Returns: void
 * Assertion: If end_pos is negative, then the the characters deleted will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 1, -10
 * Expected: void  
 */
static void test_purpose_81()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define START 1
    #define END -10
    
    GtkWidget* widget;
    gint len;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    gtk_entry_set_text (GTK_ENTRY (widget),TEXT);
    
    gtk_editable_delete_text (GTK_EDITABLE (widget),START,END);
    len = strlen (gtk_editable_get_chars(GTK_EDITABLE (widget),0,-1));
    
    if (len != START)
    {
        TEST_FAIL ("The characters isn't deleted from start_pos to the end of the text.",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_delete_text
 * Params: GtkEditable *editable, gint start_pos,gint end_pos
 * Returns: void
 * Assertion: If end_pos is negative, then the the characters deleted will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, 10, -100
 * Expected: void  
 */
static void test_purpose_82()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define START 10
    #define END -100
    
    GtkWidget* widget;
    gint len;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    gtk_entry_set_text (GTK_ENTRY (widget),TEXT);
    
    gtk_editable_delete_text (GTK_EDITABLE (widget),START,END);
    len = strlen (gtk_editable_get_chars(GTK_EDITABLE (widget),0,-1));
    
    if (len != START)
    {
        TEST_FAIL ("The characters isn't deleted from start_pos to the end of the text.",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_delete_text
 * Params: GtkEditable *editable, gint start_pos,gint end_pos
 * Returns: void
 * Assertion: If end_pos is negative, then the the characters deleted will be those characters from start_pos to the end of the text.
 * Params Values: GtkEditable*, strlen (TEXT), -100
 * Expected: void  
 */
static void test_purpose_83()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define START strlen (TEXT)
    #define END -100
    
    GtkWidget* widget;
    gint len;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    gtk_entry_set_text (GTK_ENTRY (widget),TEXT);
    
    gtk_editable_delete_text (GTK_EDITABLE (widget),START,END);
    len = strlen (gtk_editable_get_chars(GTK_EDITABLE (widget),0,-1));
    
    if (len != START)
    {
        TEST_FAIL ("The characters isn't deleted from start_pos to the end of the text.",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef START
    #undef END
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_cut_clipboard
 * Params: GtkEditable *editable
 * Returns: void
 * Assertion: Causes the characters in the current selection to be copied to the clipboard and then deleted from the widget.
 * Params Values: GtkEditable*
 * Expected: void  
 */
static void test_purpose_84()
{
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    widget = gtk_entry_new ();
    gtk_entry_set_text (GTK_ENTRY (widget),"Label");
    gtk_editable_select_region (GTK_EDITABLE (widget),0,4);
    
    g_signal_connect (G_OBJECT (widget), "cut_clipboard", 
                        GTK_SIGNAL_FUNC (global_emit_signal), NULL);
    gtk_editable_cut_clipboard (GTK_EDITABLE (widget));
    if (global_counter == 0)
    {
        TEST_FAIL ("GtkEditable widget should emit 'cut_clipboard' signal", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_copy_clipboard
 * Params: GtkEditable *editable
 * Returns: void
 * Assertion: Causes the characters in the current selection to be copied to the clipboard.
 * Params Values: GtkEditable*
 * Expected: void  
 */
static void test_purpose_85()
{
    GtkWidget* widget;
    gint len;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    widget = gtk_entry_new ();
    gtk_entry_set_text (GTK_ENTRY (widget),"Label");
    gtk_editable_select_region (GTK_EDITABLE (widget),0,4);
    
    g_signal_connect (G_OBJECT (widget), "copy_clipboard", 
                        GTK_SIGNAL_FUNC (global_emit_signal), NULL);
    gtk_editable_copy_clipboard (GTK_EDITABLE (widget));
    if (global_counter == 0)
    {
        TEST_FAIL ("GtkEditable widget should emit 'copy_clipboard' signal", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_paste_clipboard
 * Params: GtkEditable *editable
 * Returns: void
 * Assertion: Causes the contents of the clipboard to be pasted into the given widget at the current cursor position.
 * Params Values: GtkEditable*
 * Expected: void  
 */
static void test_purpose_86()
{
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    widget = gtk_entry_new ();
    gtk_entry_set_text (GTK_ENTRY (widget),"Label");
    gtk_editable_select_region (GTK_EDITABLE (widget),0,4);
    
    g_signal_connect (G_OBJECT (widget), "paste_clipboard", 
                        GTK_SIGNAL_FUNC (global_emit_signal), NULL);
    gtk_editable_paste_clipboard (GTK_EDITABLE (widget));
    if (global_counter == 0)
    {
        TEST_FAIL ("GtkEditable widget should emit 'paste_clipboard' signal", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_editable_delete_selection
 * Params: GtkEditable *editable
 * Returns: void
 * Assertion: Deletes the current contents of the widgets selection and disclaims the selection.
 * Params Values: GtkEditable*
 * Expected: void  
 */
static void test_purpose_87()
{
    GtkWidget* widget;
    gboolean res;
    gint start;
    gint end;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    gtk_entry_set_text (GTK_ENTRY (widget),"Label");
    gtk_editable_select_region (GTK_EDITABLE (widget),0,4);
    
    gtk_editable_delete_selection (GTK_EDITABLE (widget));
    
    res = gtk_editable_get_selection_bounds (GTK_EDITABLE (widget),&start,&end);
    if (res)
    {
        TEST_FAIL ("Selection isn't deleted",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkEditable ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {test_purpose_79, 1},
    {test_purpose_80, 1},
    {test_purpose_81, 1},
    {test_purpose_82, 1},
    {test_purpose_83, 1},
    {test_purpose_84, 1},
    {test_purpose_85, 1},
    {test_purpose_86, 1},
    {test_purpose_87, 1},
    {NULL,0}
};
